commit f063ae67d2cc09ded1c749ff81d001f926596932
Author: Leandro Lucarella <llucarella@integratech.com.ar>
Date:   Tue May 19 10:45:49 2009 -0300

    Don't add trailing spaces when generating a Doxyfile

diff --git a/src/config.h b/src/config.h
index f87b2ba..8ff2624 100644
--- a/src/config.h
+++ b/src/config.h
@@ -142,7 +142,7 @@ class ConfigList : public ConfigOption
         t << convertToComment(m_doc);
         t << endl;
       }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "= ";
+      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       writeStringList(t,m_value);
       t << "\n";
     }
@@ -183,7 +183,7 @@ class ConfigEnum : public ConfigOption
         t << convertToComment(m_doc);
         t << endl;
       }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "= ";
+      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       writeStringValue(t,m_value);
       t << "\n";
     }
@@ -225,7 +225,7 @@ class ConfigString : public ConfigOption
         t << convertToComment(m_doc);
         t << endl;
       }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "= ";
+      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       writeStringValue(t,m_value);
       t << "\n";
     }
@@ -269,7 +269,7 @@ class ConfigInt : public ConfigOption
         t << convertToComment(m_doc);
         t << endl;
       }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "= ";
+      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       if (upd && !m_valueString.isEmpty())
       {
         writeStringValue(t,m_valueString);
@@ -317,7 +317,7 @@ class ConfigBool : public ConfigOption
         t << convertToComment(m_doc);
         t << endl;
       }
-      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "= ";
+      t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       if (upd && !m_valueString.isEmpty())
       {
         writeStringValue(t,m_valueString);
diff --git a/src/config.l b/src/config.l
index 1f72fe6..92aa252 100644
--- a/src/config.l
+++ b/src/config.l
@@ -77,20 +77,27 @@ static QCString configStringRecode(
 
 /* -----------------------------------------------------------------
  */
-
+#include <iostream>
 QCString ConfigOption::convertToComment(const QCString &s)
 {
   QCString result;
   if (s.isEmpty()) return result;
   else
   {
-    result+="# ";
     QCString tmp=s.stripWhiteSpace();
     char *p=tmp.data();
     char c;
+    result+="#";
+    if (*p && *p!='\n')
+      result+=" ";
     while ((c=*p++))
     {
-      if (c=='\n') result+="\n# ";
+      if (c=='\n')
+      {
+        result+="\n#";
+        if (*p && *p!='\n')
+          result+=" ";
+      }
       else result+=c;
     }
     result+='\n';
@@ -100,12 +107,13 @@ QCString ConfigOption::convertToComment(const QCString &s)
 
 void ConfigOption::writeBoolValue(QTextStream &t,bool v)
 {
+  t << " ";
   if (v) t << "YES"; else t << "NO";
 }
 
 void ConfigOption::writeIntValue(QTextStream &t,int i)
 {
-  t << i;
+  t << " " << i;
 }
 
 void ConfigOption::writeStringValue(QTextStream &t,QCString &s)
@@ -117,6 +125,7 @@ void ConfigOption::writeStringValue(QTextStream &t,QCString &s)
   const char *p=se.data();
   if (p)
   {
+    t << " ";
     while ((c=*p++)!=0 && !needsEscaping) 
       needsEscaping = (c==' ' || c=='\n' || c=='\t' || c=='"' || c=='#');
     if (needsEscaping)
@@ -145,7 +154,10 @@ void ConfigOption::writeStringList(QTextStream &t,QStrList &l)
   while (p)
   {
     QCString s=p;
-    if (!first) t << "                         ";
+    if (first)
+      t << " ";
+    else
+      t << "                         ";
     first=FALSE;
     writeStringValue(t,s);
     p = l.next();
diff --git a/src/config.xml b/src/config.xml
index 9d6e144..329cb11 100644
--- a/src/config.xml
+++ b/src/config.xml
@@ -1,45 +1,45 @@
 <doxygenconfig>
   <group name='Project' docs='Project related configuration options'>
     <option type='string' id='DOXYFILE_ENCODING' format='string' docs='
-This tag specifies the encoding used for all characters in the config file 
-that follow. The default is UTF-8 which is also the encoding used for all 
-text before the first occurrence of this tag. Doxygen uses libiconv (or the 
-iconv built into libc) for the transcoding. See 
-http://www.gnu.org/software/libiconv for the list of possible encodings. 
+This tag specifies the encoding used for all characters in the config file
+that follow. The default is UTF-8 which is also the encoding used for all
+text before the first occurrence of this tag. Doxygen uses libiconv (or the
+iconv built into libc) for the transcoding. See
+http://www.gnu.org/software/libiconv for the list of possible encodings.
 ' defval='UTF-8'/>
     <option type='string' id='PROJECT_NAME' format='string' docs='
-The PROJECT_NAME tag is a single word (or a sequence of words surrounded 
+The PROJECT_NAME tag is a single word (or a sequence of words surrounded
 by quotes) that should identify the project. ' defval=''/>
     <option type='string' id='PROJECT_NUMBER' format='string' docs='
-The PROJECT_NUMBER tag can be used to enter a project or revision number. 
-This could be handy for archiving the generated documentation or 
-if some version control system is used. 
+The PROJECT_NUMBER tag can be used to enter a project or revision number.
+This could be handy for archiving the generated documentation or
+if some version control system is used.
 ' defval=''/>
     <option type='string' id='OUTPUT_DIRECTORY' format='dir' docs='
-The OUTPUT_DIRECTORY tag is used to specify the (relative or absolute) 
-base path where the generated documentation will be put. 
-If a relative path is entered, it will be relative to the location 
-where doxygen was started. If left blank the current directory will be used. 
+The OUTPUT_DIRECTORY tag is used to specify the (relative or absolute)
+base path where the generated documentation will be put.
+If a relative path is entered, it will be relative to the location
+where doxygen was started. If left blank the current directory will be used.
 ' defval=''/>
     <option type='bool' id='CREATE_SUBDIRS' docs='
-If the CREATE_SUBDIRS tag is set to YES, then doxygen will create 
-4096 sub-directories (in 2 levels) under the output directory of each output 
-format and will distribute the generated files over these directories. 
-Enabling this option can be useful when feeding doxygen a huge amount of 
-source files, where putting all generated files in the same directory would 
-otherwise cause performance problems for the file system. 
+If the CREATE_SUBDIRS tag is set to YES, then doxygen will create
+4096 sub-directories (in 2 levels) under the output directory of each output
+format and will distribute the generated files over these directories.
+Enabling this option can be useful when feeding doxygen a huge amount of
+source files, where putting all generated files in the same directory would
+otherwise cause performance problems for the file system.
 ' defval='0'/>
     <option type='enum' id='OUTPUT_LANGUAGE' defval='English' docs='
-The OUTPUT_LANGUAGE tag is used to specify the language in which all 
-documentation generated by doxygen is written. Doxygen will use this 
-information to generate all constant output in the proper language. 
-The default language is English, other supported languages are: 
-Afrikaans, Arabic, Brazilian, Catalan, Chinese, Chinese-Traditional, 
-Croatian, Czech, Danish, Dutch, Esperanto, Farsi, Finnish, French, German, 
-Greek, Hungarian, Italian, Japanese, Japanese-en (Japanese with English 
-messages), Korean, Korean-en, Lithuanian, Norwegian, Macedonian, Persian, 
-Polish, Portuguese, Romanian, Russian, Serbian, Serbian-Cyrilic, Slovak, 
-Slovene, Spanish, Swedish, Ukrainian, and Vietnamese. 
+The OUTPUT_LANGUAGE tag is used to specify the language in which all
+documentation generated by doxygen is written. Doxygen will use this
+information to generate all constant output in the proper language.
+The default language is English, other supported languages are:
+Afrikaans, Arabic, Brazilian, Catalan, Chinese, Chinese-Traditional,
+Croatian, Czech, Danish, Dutch, Esperanto, Farsi, Finnish, French, German,
+Greek, Hungarian, Italian, Japanese, Japanese-en (Japanese with English
+messages), Korean, Korean-en, Lithuanian, Norwegian, Macedonian, Persian,
+Polish, Portuguese, Romanian, Russian, Serbian, Serbian-Cyrilic, Slovak,
+Slovene, Spanish, Swedish, Ukrainian, and Vietnamese.
 '>
       <value name='Afrikaans'/>
       <value name='Arabic'/>
@@ -81,27 +81,27 @@ Slovene, Spanish, Swedish, Ukrainian, and Vietnamese.
       <value name='Vietnamese'/>
     </option>
     <option type='bool' id='BRIEF_MEMBER_DESC' docs='
-If the BRIEF_MEMBER_DESC tag is set to YES (the default) Doxygen will 
-include brief member descriptions after the members that are listed in 
-the file and class documentation (similar to JavaDoc). 
-Set to NO to disable this. 
+If the BRIEF_MEMBER_DESC tag is set to YES (the default) Doxygen will
+include brief member descriptions after the members that are listed in
+the file and class documentation (similar to JavaDoc).
+Set to NO to disable this.
 ' defval='1'/>
     <option type='bool' id='REPEAT_BRIEF' docs='
-If the REPEAT_BRIEF tag is set to YES (the default) Doxygen will prepend 
-the brief description of a member or function before the detailed description. 
-Note: if both HIDE_UNDOC_MEMBERS and BRIEF_MEMBER_DESC are set to NO, the 
-brief descriptions will be completely suppressed. 
+If the REPEAT_BRIEF tag is set to YES (the default) Doxygen will prepend
+the brief description of a member or function before the detailed description.
+Note: if both HIDE_UNDOC_MEMBERS and BRIEF_MEMBER_DESC are set to NO, the
+brief descriptions will be completely suppressed.
 ' defval='1'/>
     <option type='list' id='ABBREVIATE_BRIEF' format='string' docs='
-This tag implements a quasi-intelligent brief description abbreviator 
-that is used to form the text in various listings. Each string 
-in this list, if found as the leading text of the brief description, will be 
-stripped from the text and the result after processing the whole list, is 
-used as the annotated text. Otherwise, the brief description is used as-is. 
-If left blank, the following values are used (&quot;$name&quot; is automatically 
-replaced with the name of the entity): &quot;The $name class&quot; &quot;The $name widget&quot; 
-&quot;The $name file&quot; &quot;is&quot; &quot;provides&quot; &quot;specifies&quot; &quot;contains&quot; 
-&quot;represents&quot; &quot;a&quot; &quot;an&quot; &quot;the&quot; 
+This tag implements a quasi-intelligent brief description abbreviator
+that is used to form the text in various listings. Each string
+in this list, if found as the leading text of the brief description, will be
+stripped from the text and the result after processing the whole list, is
+used as the annotated text. Otherwise, the brief description is used as-is.
+If left blank, the following values are used (&quot;$name&quot; is automatically
+replaced with the name of the entity): &quot;The $name class&quot; &quot;The $name widget&quot;
+&quot;The $name file&quot; &quot;is&quot; &quot;provides&quot; &quot;specifies&quot; &quot;contains&quot;
+&quot;represents&quot; &quot;a&quot; &quot;an&quot; &quot;the&quot;
 '>
       <value name='The $name class'/>
       <value name='The $name widget'/>
@@ -116,429 +116,429 @@ replaced with the name of the entity): &quot;The $name class&quot; &quot;The $na
       <value name='the'/>
     </option>
     <option type='bool' id='ALWAYS_DETAILED_SEC' docs='
-If the ALWAYS_DETAILED_SEC and REPEAT_BRIEF tags are both set to YES then 
-Doxygen will generate a detailed section even if there is only a brief 
-description. 
+If the ALWAYS_DETAILED_SEC and REPEAT_BRIEF tags are both set to YES then
+Doxygen will generate a detailed section even if there is only a brief
+description.
 ' defval='0'/>
     <option type='bool' id='INLINE_INHERITED_MEMB' docs='
-If the INLINE_INHERITED_MEMB tag is set to YES, doxygen will show all 
-inherited members of a class in the documentation of that class as if those 
-members were ordinary class members. Constructors, destructors and assignment 
-operators of the base classes will not be shown. 
+If the INLINE_INHERITED_MEMB tag is set to YES, doxygen will show all
+inherited members of a class in the documentation of that class as if those
+members were ordinary class members. Constructors, destructors and assignment
+operators of the base classes will not be shown.
 ' defval='0'/>
     <option type='bool' id='FULL_PATH_NAMES' docs='
-If the FULL_PATH_NAMES tag is set to YES then Doxygen will prepend the full 
-path before files name in the file list and in the header files. If set 
-to NO the shortest path that makes the file name unique will be used. 
+If the FULL_PATH_NAMES tag is set to YES then Doxygen will prepend the full
+path before files name in the file list and in the header files. If set
+to NO the shortest path that makes the file name unique will be used.
 ' defval='1'/>
     <option type='list' id='STRIP_FROM_PATH' format='string' docs='
-If the FULL_PATH_NAMES tag is set to YES then the STRIP_FROM_PATH tag 
-can be used to strip a user-defined part of the path. Stripping is 
-only done if one of the specified strings matches the left-hand part of 
-the path. The tag can be used to show relative paths in the file list. 
-If left blank the directory from which doxygen is run is used as the 
-path to strip. 
+If the FULL_PATH_NAMES tag is set to YES then the STRIP_FROM_PATH tag
+can be used to strip a user-defined part of the path. Stripping is
+only done if one of the specified strings matches the left-hand part of
+the path. The tag can be used to show relative paths in the file list.
+If left blank the directory from which doxygen is run is used as the
+path to strip.
 ' depends='FULL_PATH_NAMES'>
       <value name='/Users/dimitri/doxygen/mail/1.5.7/doxywizard/'/>
     </option>
     <option type='list' id='STRIP_FROM_INC_PATH' format='string' docs='
-The STRIP_FROM_INC_PATH tag can be used to strip a user-defined part of 
-the path mentioned in the documentation of a class, which tells 
-the reader which header file to include in order to use a class. 
-If left blank only the name of the header file containing the class 
-definition is used. Otherwise one should specify the include paths that 
-are normally passed to the compiler using the -I flag. 
+The STRIP_FROM_INC_PATH tag can be used to strip a user-defined part of
+the path mentioned in the documentation of a class, which tells
+the reader which header file to include in order to use a class.
+If left blank only the name of the header file containing the class
+definition is used. Otherwise one should specify the include paths that
+are normally passed to the compiler using the -I flag.
 '>
     </option>
     <option type='bool' id='SHORT_NAMES' docs='
-If the SHORT_NAMES tag is set to YES, doxygen will generate much shorter 
-(but less readable) file names. This can be useful is your file systems 
-doesn&apos;t support long names like on DOS, Mac, or CD-ROM. 
+If the SHORT_NAMES tag is set to YES, doxygen will generate much shorter
+(but less readable) file names. This can be useful is your file systems
+doesn&apos;t support long names like on DOS, Mac, or CD-ROM.
 ' defval='0'/>
     <option type='bool' id='JAVADOC_AUTOBRIEF' docs='
-If the JAVADOC_AUTOBRIEF tag is set to YES then Doxygen 
-will interpret the first line (until the first dot) of a JavaDoc-style 
-comment as the brief description. If set to NO, the JavaDoc 
-comments will behave just like regular Qt-style comments 
-(thus requiring an explicit @brief command for a brief description.) 
+If the JAVADOC_AUTOBRIEF tag is set to YES then Doxygen
+will interpret the first line (until the first dot) of a JavaDoc-style
+comment as the brief description. If set to NO, the JavaDoc
+comments will behave just like regular Qt-style comments
+(thus requiring an explicit @brief command for a brief description.)
 ' defval='0'/>
     <option type='bool' id='QT_AUTOBRIEF' docs='
-If the QT_AUTOBRIEF tag is set to YES then Doxygen will 
-interpret the first line (until the first dot) of a Qt-style 
-comment as the brief description. If set to NO, the comments 
-will behave just like regular Qt-style comments (thus requiring 
-an explicit \brief command for a brief description.) 
+If the QT_AUTOBRIEF tag is set to YES then Doxygen will
+interpret the first line (until the first dot) of a Qt-style
+comment as the brief description. If set to NO, the comments
+will behave just like regular Qt-style comments (thus requiring
+an explicit \brief command for a brief description.)
 ' defval='0'/>
     <option type='bool' id='MULTILINE_CPP_IS_BRIEF' docs='
-The MULTILINE_CPP_IS_BRIEF tag can be set to YES to make Doxygen 
-treat a multi-line C++ special comment block (i.e. a block of //! or /// 
-comments) as a brief description. This used to be the default behaviour. 
-The new default is to treat a multi-line C++ comment block as a detailed 
-description. Set this tag to YES if you prefer the old behaviour instead. 
+The MULTILINE_CPP_IS_BRIEF tag can be set to YES to make Doxygen
+treat a multi-line C++ special comment block (i.e. a block of //! or ///
+comments) as a brief description. This used to be the default behaviour.
+The new default is to treat a multi-line C++ comment block as a detailed
+description. Set this tag to YES if you prefer the old behaviour instead.
 ' defval='0'/>
     <option type='bool' id='INHERIT_DOCS' docs='
-If the INHERIT_DOCS tag is set to YES (the default) then an undocumented 
-member inherits the documentation from any documented member that it 
-re-implements. 
+If the INHERIT_DOCS tag is set to YES (the default) then an undocumented
+member inherits the documentation from any documented member that it
+re-implements.
 ' defval='1'/>
     <option type='bool' id='SEPARATE_MEMBER_PAGES' docs='
-If the SEPARATE_MEMBER_PAGES tag is set to YES, then doxygen will produce 
-a new page for each member. If set to NO, the documentation of a member will 
-be part of the file/class/namespace that contains it. 
+If the SEPARATE_MEMBER_PAGES tag is set to YES, then doxygen will produce
+a new page for each member. If set to NO, the documentation of a member will
+be part of the file/class/namespace that contains it.
 ' defval='0'/>
     <option type='int' id='TAB_SIZE' docs='
-The TAB_SIZE tag can be used to set the number of spaces in a tab. 
-Doxygen uses this value to replace tabs by spaces in code fragments. 
+The TAB_SIZE tag can be used to set the number of spaces in a tab.
+Doxygen uses this value to replace tabs by spaces in code fragments.
 ' minval='1' maxval='16' defval='8'/>
     <option type='list' id='ALIASES' format='string' docs='
-This tag can be used to specify a number of aliases that acts 
-as commands in the documentation. An alias has the form &quot;name=value&quot;. 
-For example adding &quot;sideeffect=\par Side Effects:\n&quot; will allow you to 
-put the command \sideeffect (or @sideeffect) in the documentation, which 
-will result in a user-defined paragraph with heading &quot;Side Effects:&quot;. 
-You can put \n&apos;s in the value part of an alias to insert newlines. 
+This tag can be used to specify a number of aliases that acts
+as commands in the documentation. An alias has the form &quot;name=value&quot;.
+For example adding &quot;sideeffect=\par Side Effects:\n&quot; will allow you to
+put the command \sideeffect (or @sideeffect) in the documentation, which
+will result in a user-defined paragraph with heading &quot;Side Effects:&quot;.
+You can put \n&apos;s in the value part of an alias to insert newlines.
 '>
     </option>
     <option type='bool' id='OPTIMIZE_OUTPUT_FOR_C' docs='
-Set the OPTIMIZE_OUTPUT_FOR_C tag to YES if your project consists of C 
-sources only. Doxygen will then generate output that is more tailored for C. 
-For instance, some of the names that are used will be different. The list 
-of all members will be omitted, etc. 
+Set the OPTIMIZE_OUTPUT_FOR_C tag to YES if your project consists of C
+sources only. Doxygen will then generate output that is more tailored for C.
+For instance, some of the names that are used will be different. The list
+of all members will be omitted, etc.
 ' defval='0'/>
     <option type='bool' id='OPTIMIZE_OUTPUT_JAVA' docs='
-Set the OPTIMIZE_OUTPUT_JAVA tag to YES if your project consists of Java 
-sources only. Doxygen will then generate output that is more tailored for 
-Java. For instance, namespaces will be presented as packages, qualified 
-scopes will look different, etc. 
+Set the OPTIMIZE_OUTPUT_JAVA tag to YES if your project consists of Java
+sources only. Doxygen will then generate output that is more tailored for
+Java. For instance, namespaces will be presented as packages, qualified
+scopes will look different, etc.
 ' defval='0'/>
     <option type='bool' id='OPTIMIZE_FOR_FORTRAN' docs='
-Set the OPTIMIZE_FOR_FORTRAN tag to YES if your project consists of Fortran 
-sources only. Doxygen will then generate output that is more tailored for 
-Fortran. 
+Set the OPTIMIZE_FOR_FORTRAN tag to YES if your project consists of Fortran
+sources only. Doxygen will then generate output that is more tailored for
+Fortran.
 ' defval='0'/>
     <option type='bool' id='OPTIMIZE_OUTPUT_VHDL' docs='
-Set the OPTIMIZE_OUTPUT_VHDL tag to YES if your project consists of VHDL 
-sources. Doxygen will then generate output that is tailored for 
-VHDL. 
+Set the OPTIMIZE_OUTPUT_VHDL tag to YES if your project consists of VHDL
+sources. Doxygen will then generate output that is tailored for
+VHDL.
 ' defval='0'/>
     <option type='list' id='EXTENSION_MAPPING' format='string' docs='
-Doxygen selects the parser to use depending on the extension of the files it parses. 
-With this tag you can assign which parser to use for a given extension. 
-Doxygen has a built-in mapping, but you can override or extend it using this tag. 
-The format is ext=language, where ext is a file extension, and language is one of 
-the parsers supported by doxygen: IDL, Java, Javascript, C#, C, C++, D, PHP, 
-Objective-C, Python, Fortran, VHDL, C, C++. For instance to make doxygen treat 
-.inc files as Fortran files (default is PHP), and .f files as C (default is Fortran), 
+Doxygen selects the parser to use depending on the extension of the files it parses.
+With this tag you can assign which parser to use for a given extension.
+Doxygen has a built-in mapping, but you can override or extend it using this tag.
+The format is ext=language, where ext is a file extension, and language is one of
+the parsers supported by doxygen: IDL, Java, Javascript, C#, C, C++, D, PHP,
+Objective-C, Python, Fortran, VHDL, C, C++. For instance to make doxygen treat
+.inc files as Fortran files (default is PHP), and .f files as C (default is Fortran),
 use: inc=Fortran f=C. Note that for custom extensions you also need to set
 FILE_PATTERNS otherwise the files are not read by doxygen.
 '>
     </option>
     <option type='bool' id='BUILTIN_STL_SUPPORT' docs='
-If you use STL classes (i.e. std::string, std::vector, etc.) but do not want 
-to include (a tag file for) the STL sources as input, then you should 
-set this tag to YES in order to let doxygen match functions declarations and 
-definitions whose arguments contain STL classes (e.g. func(std::string); v.s. 
-func(std::string) {}). This also make the inheritance and collaboration 
-diagrams that involve STL classes more complete and accurate. 
+If you use STL classes (i.e. std::string, std::vector, etc.) but do not want
+to include (a tag file for) the STL sources as input, then you should
+set this tag to YES in order to let doxygen match functions declarations and
+definitions whose arguments contain STL classes (e.g. func(std::string); v.s.
+func(std::string) {}). This also make the inheritance and collaboration
+diagrams that involve STL classes more complete and accurate.
 ' defval='0'/>
     <option type='bool' id='CPP_CLI_SUPPORT' docs='
-If you use Microsoft&apos;s C++/CLI language, you should set this option to YES to 
-enable parsing support. 
+If you use Microsoft&apos;s C++/CLI language, you should set this option to YES to
+enable parsing support.
 ' defval='0'/>
     <option type='bool' id='SIP_SUPPORT' docs='
-Set the SIP_SUPPORT tag to YES if your project consists of sip sources only. 
-Doxygen will parse them like normal C++ but will assume all classes use public 
-instead of private inheritance when no explicit protection keyword is present. 
+Set the SIP_SUPPORT tag to YES if your project consists of sip sources only.
+Doxygen will parse them like normal C++ but will assume all classes use public
+instead of private inheritance when no explicit protection keyword is present.
 ' defval='0'/>
     <option type='bool' id='IDL_PROPERTY_SUPPORT' docs='
-For Microsoft&apos;s IDL there are propget and propput attributes to indicate getter 
-and setter methods for a property. Setting this option to YES (the default) 
-will make doxygen to replace the get and set methods by a property in the 
-documentation. This will only work if the methods are indeed getting or 
-setting a simple type. If this is not the case, or you want to show the 
-methods anyway, you should set this option to NO. 
+For Microsoft&apos;s IDL there are propget and propput attributes to indicate getter
+and setter methods for a property. Setting this option to YES (the default)
+will make doxygen to replace the get and set methods by a property in the
+documentation. This will only work if the methods are indeed getting or
+setting a simple type. If this is not the case, or you want to show the
+methods anyway, you should set this option to NO.
 ' defval='1'/>
     <option type='bool' id='DISTRIBUTE_GROUP_DOC' docs='
-If member grouping is used in the documentation and the DISTRIBUTE_GROUP_DOC 
-tag is set to YES, then doxygen will reuse the documentation of the first 
-member in the group (if any) for the other members of the group. By default 
-all members of a group must be documented explicitly. 
+If member grouping is used in the documentation and the DISTRIBUTE_GROUP_DOC
+tag is set to YES, then doxygen will reuse the documentation of the first
+member in the group (if any) for the other members of the group. By default
+all members of a group must be documented explicitly.
 ' defval='0'/>
     <option type='bool' id='SUBGROUPING' docs='
-Set the SUBGROUPING tag to YES (the default) to allow class member groups of 
-the same type (for instance a group of public functions) to be put as a 
-subgroup of that type (e.g. under the Public Functions section). Set it to 
-NO to prevent subgrouping. Alternatively, this can be done per class using 
-the \nosubgrouping command. 
+Set the SUBGROUPING tag to YES (the default) to allow class member groups of
+the same type (for instance a group of public functions) to be put as a
+subgroup of that type (e.g. under the Public Functions section). Set it to
+NO to prevent subgrouping. Alternatively, this can be done per class using
+the \nosubgrouping command.
 ' defval='1'/>
     <option type='bool' id='TYPEDEF_HIDES_STRUCT' docs='
-When TYPEDEF_HIDES_STRUCT is enabled, a typedef of a struct, union, or enum 
-is documented as struct, union, or enum with the name of the typedef. So 
-typedef struct TypeS {} TypeT, will appear in the documentation as a struct 
-with name TypeT. When disabled the typedef will appear as a member of a file, 
-namespace, or class. And the struct will be named TypeS. This can typically 
-be useful for C code in case the coding convention dictates that all compound 
-types are typedef&apos;ed and only the typedef is referenced, never the tag name. 
+When TYPEDEF_HIDES_STRUCT is enabled, a typedef of a struct, union, or enum
+is documented as struct, union, or enum with the name of the typedef. So
+typedef struct TypeS {} TypeT, will appear in the documentation as a struct
+with name TypeT. When disabled the typedef will appear as a member of a file,
+namespace, or class. And the struct will be named TypeS. This can typically
+be useful for C code in case the coding convention dictates that all compound
+types are typedef&apos;ed and only the typedef is referenced, never the tag name.
 ' defval='0'/>
     <option type='int' id='SYMBOL_CACHE_SIZE' docs='
-The SYMBOL_CACHE_SIZE determines the size of the internal cache use to 
-determine which symbols to keep in memory and which to flush to disk. 
-When the cache is full, less often used symbols will be written to disk. 
-For small to medium size projects (&lt;1000 input files) the default value is 
-probably good enough. For larger projects a too small cache size can cause 
-doxygen to be busy swapping symbols to and from disk most of the time 
-causing a significant performance penality. 
-If the system has enough physical memory increasing the cache will improve the 
-performance by keeping more symbols in memory. Note that the value works on 
-a logarithmic scale so increasing the size by one will rougly double the 
-memory usage. The cache size is given by this formula: 
-2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0, 
-corresponding to a cache size of 2^16 = 65536 symbols 
+The SYMBOL_CACHE_SIZE determines the size of the internal cache use to
+determine which symbols to keep in memory and which to flush to disk.
+When the cache is full, less often used symbols will be written to disk.
+For small to medium size projects (&lt;1000 input files) the default value is
+probably good enough. For larger projects a too small cache size can cause
+doxygen to be busy swapping symbols to and from disk most of the time
+causing a significant performance penality.
+If the system has enough physical memory increasing the cache will improve the
+performance by keeping more symbols in memory. Note that the value works on
+a logarithmic scale so increasing the size by one will rougly double the
+memory usage. The cache size is given by this formula:
+2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0,
+corresponding to a cache size of 2^16 = 65536 symbols
 ' minval='0' maxval='9' defval='0'/>
   </group>
   <group name='Build' docs='Build related configuration options'>
     <option type='bool' id='EXTRACT_ALL' docs='
-If the EXTRACT_ALL tag is set to YES doxygen will assume all entities in 
-documentation are documented, even if no documentation was available. 
-Private class members and static file members will be hidden unless 
-the EXTRACT_PRIVATE and EXTRACT_STATIC tags are set to YES 
+If the EXTRACT_ALL tag is set to YES doxygen will assume all entities in
+documentation are documented, even if no documentation was available.
+Private class members and static file members will be hidden unless
+the EXTRACT_PRIVATE and EXTRACT_STATIC tags are set to YES
 ' defval='0'/>
     <option type='bool' id='EXTRACT_PRIVATE' docs='
-If the EXTRACT_PRIVATE tag is set to YES all private members of a class 
-will be included in the documentation. 
+If the EXTRACT_PRIVATE tag is set to YES all private members of a class
+will be included in the documentation.
 ' defval='0'/>
     <option type='bool' id='EXTRACT_STATIC' docs='
-If the EXTRACT_STATIC tag is set to YES all static members of a file 
-will be included in the documentation. 
+If the EXTRACT_STATIC tag is set to YES all static members of a file
+will be included in the documentation.
 ' defval='0'/>
     <option type='bool' id='EXTRACT_LOCAL_CLASSES' docs='
-If the EXTRACT_LOCAL_CLASSES tag is set to YES classes (and structs) 
-defined locally in source files will be included in the documentation. 
-If set to NO only classes defined in header files are included. 
+If the EXTRACT_LOCAL_CLASSES tag is set to YES classes (and structs)
+defined locally in source files will be included in the documentation.
+If set to NO only classes defined in header files are included.
 ' defval='1'/>
     <option type='bool' id='EXTRACT_LOCAL_METHODS' docs='
-This flag is only useful for Objective-C code. When set to YES local 
-methods, which are defined in the implementation section but not in 
-the interface are included in the documentation. 
-If set to NO (the default) only methods in the interface are included. 
+This flag is only useful for Objective-C code. When set to YES local
+methods, which are defined in the implementation section but not in
+the interface are included in the documentation.
+If set to NO (the default) only methods in the interface are included.
 ' defval='0'/>
     <option type='bool' id='EXTRACT_ANON_NSPACES' docs='
-If this flag is set to YES, the members of anonymous namespaces will be 
-extracted and appear in the documentation as a namespace called 
-&apos;anonymous_namespace{file}&apos;, where file will be replaced with the base 
-name of the file that contains the anonymous namespace. By default 
-anonymous namespace are hidden. 
+If this flag is set to YES, the members of anonymous namespaces will be
+extracted and appear in the documentation as a namespace called
+&apos;anonymous_namespace{file}&apos;, where file will be replaced with the base
+name of the file that contains the anonymous namespace. By default
+anonymous namespace are hidden.
 ' defval='0'/>
     <option type='bool' id='HIDE_UNDOC_MEMBERS' docs='
-If the HIDE_UNDOC_MEMBERS tag is set to YES, Doxygen will hide all 
-undocumented members of documented classes, files or namespaces. 
-If set to NO (the default) these members will be included in the 
-various overviews, but no documentation section is generated. 
-This option has no effect if EXTRACT_ALL is enabled. 
+If the HIDE_UNDOC_MEMBERS tag is set to YES, Doxygen will hide all
+undocumented members of documented classes, files or namespaces.
+If set to NO (the default) these members will be included in the
+various overviews, but no documentation section is generated.
+This option has no effect if EXTRACT_ALL is enabled.
 ' defval='0'/>
     <option type='bool' id='HIDE_UNDOC_CLASSES' docs='
-If the HIDE_UNDOC_CLASSES tag is set to YES, Doxygen will hide all 
-undocumented classes that are normally visible in the class hierarchy. 
-If set to NO (the default) these classes will be included in the various 
-overviews. This option has no effect if EXTRACT_ALL is enabled. 
+If the HIDE_UNDOC_CLASSES tag is set to YES, Doxygen will hide all
+undocumented classes that are normally visible in the class hierarchy.
+If set to NO (the default) these classes will be included in the various
+overviews. This option has no effect if EXTRACT_ALL is enabled.
 ' defval='0'/>
     <option type='bool' id='HIDE_FRIEND_COMPOUNDS' docs='
-If the HIDE_FRIEND_COMPOUNDS tag is set to YES, Doxygen will hide all 
-friend (class|struct|union) declarations. 
-If set to NO (the default) these declarations will be included in the 
-documentation. 
+If the HIDE_FRIEND_COMPOUNDS tag is set to YES, Doxygen will hide all
+friend (class|struct|union) declarations.
+If set to NO (the default) these declarations will be included in the
+documentation.
 ' defval='0'/>
     <option type='bool' id='HIDE_IN_BODY_DOCS' docs='
-If the HIDE_IN_BODY_DOCS tag is set to YES, Doxygen will hide any 
-documentation blocks found inside the body of a function. 
-If set to NO (the default) these blocks will be appended to the 
-function&apos;s detailed documentation block. 
+If the HIDE_IN_BODY_DOCS tag is set to YES, Doxygen will hide any
+documentation blocks found inside the body of a function.
+If set to NO (the default) these blocks will be appended to the
+function&apos;s detailed documentation block.
 ' defval='0'/>
     <option type='bool' id='INTERNAL_DOCS' docs='
-The INTERNAL_DOCS tag determines if documentation 
-that is typed after a \internal command is included. If the tag is set 
-to NO (the default) then the documentation will be excluded. 
-Set it to YES to include the internal documentation. 
+The INTERNAL_DOCS tag determines if documentation
+that is typed after a \internal command is included. If the tag is set
+to NO (the default) then the documentation will be excluded.
+Set it to YES to include the internal documentation.
 ' defval='0'/>
     <option type='bool' id='CASE_SENSE_NAMES' docs='
-If the CASE_SENSE_NAMES tag is set to NO then Doxygen will only generate 
-file names in lower-case letters. If set to YES upper-case letters are also 
-allowed. This is useful if you have classes or files whose names only differ 
-in case and if your file system supports case sensitive file names. Windows 
-and Mac users are advised to set this option to NO. 
+If the CASE_SENSE_NAMES tag is set to NO then Doxygen will only generate
+file names in lower-case letters. If set to YES upper-case letters are also
+allowed. This is useful if you have classes or files whose names only differ
+in case and if your file system supports case sensitive file names. Windows
+and Mac users are advised to set this option to NO.
 ' defval='0' altdefval='portable_fileSystemIsCaseSensitive()'/>
     <option type='bool' id='HIDE_SCOPE_NAMES' docs='
-If the HIDE_SCOPE_NAMES tag is set to NO (the default) then Doxygen 
-will show members with their full class and namespace scopes in the 
-documentation. If set to YES the scope will be hidden. 
+If the HIDE_SCOPE_NAMES tag is set to NO (the default) then Doxygen
+will show members with their full class and namespace scopes in the
+documentation. If set to YES the scope will be hidden.
 ' defval='0'/>
     <option type='bool' id='SHOW_INCLUDE_FILES' docs='
-If the SHOW_INCLUDE_FILES tag is set to YES (the default) then Doxygen 
-will put a list of the files that are included by a file in the documentation 
-of that file. 
+If the SHOW_INCLUDE_FILES tag is set to YES (the default) then Doxygen
+will put a list of the files that are included by a file in the documentation
+of that file.
 ' defval='1'/>
     <option type='bool' id='INLINE_INFO' docs='
-If the INLINE_INFO tag is set to YES (the default) then a tag [inline] 
-is inserted in the documentation for inline members. 
+If the INLINE_INFO tag is set to YES (the default) then a tag [inline]
+is inserted in the documentation for inline members.
 ' defval='1'/>
     <option type='bool' id='SORT_MEMBER_DOCS' docs='
-If the SORT_MEMBER_DOCS tag is set to YES (the default) then doxygen 
-will sort the (detailed) documentation of file and class members 
-alphabetically by member name. If set to NO the members will appear in 
-declaration order. 
+If the SORT_MEMBER_DOCS tag is set to YES (the default) then doxygen
+will sort the (detailed) documentation of file and class members
+alphabetically by member name. If set to NO the members will appear in
+declaration order.
 ' defval='1'/>
     <option type='bool' id='SORT_BRIEF_DOCS' docs='
-If the SORT_BRIEF_DOCS tag is set to YES then doxygen will sort the 
-brief documentation of file, namespace and class members alphabetically 
-by member name. If set to NO (the default) the members will appear in 
-declaration order. 
+If the SORT_BRIEF_DOCS tag is set to YES then doxygen will sort the
+brief documentation of file, namespace and class members alphabetically
+by member name. If set to NO (the default) the members will appear in
+declaration order.
 ' defval='0'/>
     <option type='bool' id='SORT_GROUP_NAMES' docs='
-If the SORT_GROUP_NAMES tag is set to YES then doxygen will sort the 
-hierarchy of group names into alphabetical order. If set to NO (the default) 
-the group names will appear in their defined order. 
+If the SORT_GROUP_NAMES tag is set to YES then doxygen will sort the
+hierarchy of group names into alphabetical order. If set to NO (the default)
+the group names will appear in their defined order.
 ' defval='0'/>
     <option type='bool' id='SORT_BY_SCOPE_NAME' docs='
-If the SORT_BY_SCOPE_NAME tag is set to YES, the class list will be 
-sorted by fully-qualified names, including namespaces. If set to 
-NO (the default), the class list will be sorted only by class name, 
-not including the namespace part. 
-Note: This option is not very useful if HIDE_SCOPE_NAMES is set to YES. 
-Note: This option applies only to the class list, not to the 
-alphabetical list. 
+If the SORT_BY_SCOPE_NAME tag is set to YES, the class list will be
+sorted by fully-qualified names, including namespaces. If set to
+NO (the default), the class list will be sorted only by class name,
+not including the namespace part.
+Note: This option is not very useful if HIDE_SCOPE_NAMES is set to YES.
+Note: This option applies only to the class list, not to the
+alphabetical list.
 ' defval='0'/>
     <option type='bool' id='GENERATE_TODOLIST' docs='
-The GENERATE_TODOLIST tag can be used to enable (YES) or 
-disable (NO) the todo list. This list is created by putting \todo 
-commands in the documentation. 
+The GENERATE_TODOLIST tag can be used to enable (YES) or
+disable (NO) the todo list. This list is created by putting \todo
+commands in the documentation.
 ' defval='1'/>
     <option type='bool' id='GENERATE_TESTLIST' docs='
-The GENERATE_TESTLIST tag can be used to enable (YES) or 
-disable (NO) the test list. This list is created by putting \test 
-commands in the documentation. 
+The GENERATE_TESTLIST tag can be used to enable (YES) or
+disable (NO) the test list. This list is created by putting \test
+commands in the documentation.
 ' defval='1'/>
     <option type='bool' id='GENERATE_BUGLIST' docs='
-The GENERATE_BUGLIST tag can be used to enable (YES) or 
-disable (NO) the bug list. This list is created by putting \bug 
-commands in the documentation. 
+The GENERATE_BUGLIST tag can be used to enable (YES) or
+disable (NO) the bug list. This list is created by putting \bug
+commands in the documentation.
 ' defval='1'/>
     <option type='bool' id='GENERATE_DEPRECATEDLIST' docs='
-The GENERATE_DEPRECATEDLIST tag can be used to enable (YES) or 
-disable (NO) the deprecated list. This list is created by putting 
-\deprecated commands in the documentation. 
+The GENERATE_DEPRECATEDLIST tag can be used to enable (YES) or
+disable (NO) the deprecated list. This list is created by putting
+\deprecated commands in the documentation.
 ' defval='1'/>
     <option type='list' id='ENABLED_SECTIONS' format='string' docs='
-The ENABLED_SECTIONS tag can be used to enable conditional 
-documentation sections, marked by \if sectionname ... \endif. 
+The ENABLED_SECTIONS tag can be used to enable conditional
+documentation sections, marked by \if sectionname ... \endif.
 '>
     </option>
     <option type='int' id='MAX_INITIALIZER_LINES' docs='
-The MAX_INITIALIZER_LINES tag determines the maximum number of lines 
-the initial value of a variable or define consists of for it to appear in 
-the documentation. If the initializer consists of more lines than specified 
-here it will be hidden. Use a value of 0 to hide initializers completely. 
-The appearance of the initializer of individual variables and defines in the 
-documentation can be controlled using \showinitializer or \hideinitializer 
-command in the documentation regardless of this setting. 
+The MAX_INITIALIZER_LINES tag determines the maximum number of lines
+the initial value of a variable or define consists of for it to appear in
+the documentation. If the initializer consists of more lines than specified
+here it will be hidden. Use a value of 0 to hide initializers completely.
+The appearance of the initializer of individual variables and defines in the
+documentation can be controlled using \showinitializer or \hideinitializer
+command in the documentation regardless of this setting.
 ' minval='0' maxval='10000' defval='30'/>
     <option type='bool' id='SHOW_DIRECTORIES' docs='
-If the sources in your project are distributed over multiple directories 
-then setting the SHOW_DIRECTORIES tag to YES will show the directory hierarchy 
-in the documentation. The default is NO. 
+If the sources in your project are distributed over multiple directories
+then setting the SHOW_DIRECTORIES tag to YES will show the directory hierarchy
+in the documentation. The default is NO.
 ' defval='0'/>
     <option type='bool' id='SHOW_FILES' docs='
-Set the SHOW_FILES tag to NO to disable the generation of the Files page. 
-This will remove the Files entry from the Quick Index and from the 
-Folder Tree View (if specified). The default is YES. 
+Set the SHOW_FILES tag to NO to disable the generation of the Files page.
+This will remove the Files entry from the Quick Index and from the
+Folder Tree View (if specified). The default is YES.
 ' defval='1'/>
     <option type='bool' id='SHOW_NAMESPACES' docs='
-Set the SHOW_NAMESPACES tag to NO to disable the generation of the 
-Namespaces page.  This will remove the Namespaces entry from the Quick Index 
-and from the Folder Tree View (if specified). The default is YES. 
+Set the SHOW_NAMESPACES tag to NO to disable the generation of the
+Namespaces page.  This will remove the Namespaces entry from the Quick Index
+and from the Folder Tree View (if specified). The default is YES.
 ' defval='1'/>
     <option type='string' id='FILE_VERSION_FILTER' format='file' docs='
-The FILE_VERSION_FILTER tag can be used to specify a program or script that 
-doxygen should invoke to get the current version for each file (typically from 
-the version control system). Doxygen will invoke the program by executing (via 
-popen()) the command &lt;command&gt; &lt;input-file&gt;, where &lt;command&gt; is the value of 
-the FILE_VERSION_FILTER tag, and &lt;input-file&gt; is the name of an input file 
-provided by doxygen. Whatever the program writes to standard output 
-is used as the file version. See the manual for examples. 
+The FILE_VERSION_FILTER tag can be used to specify a program or script that
+doxygen should invoke to get the current version for each file (typically from
+the version control system). Doxygen will invoke the program by executing (via
+popen()) the command &lt;command&gt; &lt;input-file&gt;, where &lt;command&gt; is the value of
+the FILE_VERSION_FILTER tag, and &lt;input-file&gt; is the name of an input file
+provided by doxygen. Whatever the program writes to standard output
+is used as the file version. See the manual for examples.
 ' defval=''/>
     <option type='string' id='LAYOUT_FILE' format='file' docs='
-The LAYOUT_FILE tag can be used to specify a layout file which will be parsed by 
-doxygen. The layout file controls the global structure of the generated output files 
-in an output format independent way. The create the layout file that represents 
-doxygen&apos;s defaults, run doxygen with the -l option. You can optionally specify a 
-file name after the option, if omitted DoxygenLayout.xml will be used as the name 
-of the layout file. 
+The LAYOUT_FILE tag can be used to specify a layout file which will be parsed by
+doxygen. The layout file controls the global structure of the generated output files
+in an output format independent way. The create the layout file that represents
+doxygen&apos;s defaults, run doxygen with the -l option. You can optionally specify a
+file name after the option, if omitted DoxygenLayout.xml will be used as the name
+of the layout file.
 ' defval=''/>
   </group>
   <group name='Messages' docs='configuration options related to warning and progress messages'>
     <option type='bool' id='QUIET' docs='
-The QUIET tag can be used to turn on/off the messages that are generated 
-by doxygen. Possible values are YES and NO. If left blank NO is used. 
+The QUIET tag can be used to turn on/off the messages that are generated
+by doxygen. Possible values are YES and NO. If left blank NO is used.
 ' defval='0'/>
     <option type='bool' id='WARNINGS' docs='
-The WARNINGS tag can be used to turn on/off the warning messages that are 
-generated by doxygen. Possible values are YES and NO. If left blank 
-NO is used. 
+The WARNINGS tag can be used to turn on/off the warning messages that are
+generated by doxygen. Possible values are YES and NO. If left blank
+NO is used.
 ' defval='1'/>
     <option type='bool' id='WARN_IF_UNDOCUMENTED' docs='
-If WARN_IF_UNDOCUMENTED is set to YES, then doxygen will generate warnings 
-for undocumented members. If EXTRACT_ALL is set to YES then this flag will 
-automatically be disabled. 
+If WARN_IF_UNDOCUMENTED is set to YES, then doxygen will generate warnings
+for undocumented members. If EXTRACT_ALL is set to YES then this flag will
+automatically be disabled.
 ' defval='1'/>
     <option type='bool' id='WARN_IF_DOC_ERROR' docs='
-If WARN_IF_DOC_ERROR is set to YES, doxygen will generate warnings for 
-potential errors in the documentation, such as not documenting some 
-parameters in a documented function, or documenting parameters that 
-don&apos;t exist or using markup commands wrongly. 
+If WARN_IF_DOC_ERROR is set to YES, doxygen will generate warnings for
+potential errors in the documentation, such as not documenting some
+parameters in a documented function, or documenting parameters that
+don&apos;t exist or using markup commands wrongly.
 ' defval='1'/>
     <option type='bool' id='WARN_NO_PARAMDOC' docs='
-This WARN_NO_PARAMDOC option can be abled to get warnings for 
-functions that are documented, but have no documentation for their parameters 
-or return value. If set to NO (the default) doxygen will only warn about 
-wrong or incomplete parameter documentation, but not about the absence of 
-documentation. 
+This WARN_NO_PARAMDOC option can be abled to get warnings for
+functions that are documented, but have no documentation for their parameters
+or return value. If set to NO (the default) doxygen will only warn about
+wrong or incomplete parameter documentation, but not about the absence of
+documentation.
 ' defval='0'/>
     <option type='string' id='WARN_FORMAT' format='string' docs='
-The WARN_FORMAT tag determines the format of the warning messages that 
-doxygen can produce. The string should contain the $file, $line, and $text 
-tags, which will be replaced by the file and line number from which the 
-warning originated and the warning text. Optionally the format may contain 
-$version, which will be replaced by the version of the file (if it could 
-be obtained via FILE_VERSION_FILTER) 
+The WARN_FORMAT tag determines the format of the warning messages that
+doxygen can produce. The string should contain the $file, $line, and $text
+tags, which will be replaced by the file and line number from which the
+warning originated and the warning text. Optionally the format may contain
+$version, which will be replaced by the version of the file (if it could
+be obtained via FILE_VERSION_FILTER)
 ' defval='$file:$line: $text'/>
     <option type='string' id='WARN_LOGFILE' format='file' docs='
-The WARN_LOGFILE tag can be used to specify a file to which warning 
-and error messages should be written. If left blank the output is written 
-to stderr. 
+The WARN_LOGFILE tag can be used to specify a file to which warning
+and error messages should be written. If left blank the output is written
+to stderr.
 ' defval=''/>
   </group>
   <group name='Input' docs='configuration options related to the input files'>
     <option type='list' id='INPUT' format='filedir' docs='
-The INPUT tag can be used to specify the files and/or directories that contain 
-documented source files. You may enter file names like &quot;myfile.cpp&quot; or 
-directories like &quot;/usr/src/myproject&quot;. Separate the files or directories 
-with spaces. 
+The INPUT tag can be used to specify the files and/or directories that contain
+documented source files. You may enter file names like &quot;myfile.cpp&quot; or
+directories like &quot;/usr/src/myproject&quot;. Separate the files or directories
+with spaces.
 '>
       <value name='/Users/dimitri/doxygen/mail/1.5.7/doxywizard'/>
     </option>
     <option type='string' id='INPUT_ENCODING' format='string' docs='
-This tag can be used to specify the character encoding of the source files 
-that doxygen parses. Internally doxygen uses the UTF-8 encoding, which is 
-also the default input encoding. Doxygen uses libiconv (or the iconv built 
-into libc) for the transcoding. See http://www.gnu.org/software/libiconv for 
-the list of possible encodings. 
+This tag can be used to specify the character encoding of the source files
+that doxygen parses. Internally doxygen uses the UTF-8 encoding, which is
+also the default input encoding. Doxygen uses libiconv (or the iconv built
+into libc) for the transcoding. See http://www.gnu.org/software/libiconv for
+the list of possible encodings.
 ' defval='UTF-8'/>
     <option type='list' id='FILE_PATTERNS' format='string' docs='
-If the value of the INPUT tag contains directories, you can use the 
-FILE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp 
-and *.h) to filter out the source-files in the directories. If left 
-blank the following patterns are tested: 
-*.c *.cc *.cxx *.cpp *.c++ *.java *.ii *.ixx *.ipp *.i++ *.inl *.h *.hh *.hxx 
-*.hpp *.h++ *.idl *.odl *.cs *.php *.php3 *.inc *.m *.mm *.py *.f90 
+If the value of the INPUT tag contains directories, you can use the
+FILE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp
+and *.h) to filter out the source-files in the directories. If left
+blank the following patterns are tested:
+*.c *.cc *.cxx *.cpp *.c++ *.java *.ii *.ixx *.ipp *.i++ *.inl *.h *.hh *.hxx
+*.hpp *.h++ *.idl *.odl *.cs *.php *.php3 *.inc *.m *.mm *.py *.f90
 '>
       <value name='*.c'/>
       <value name='*.cc'/>
@@ -573,321 +573,321 @@ blank the following patterns are tested:
       <value name='*.vhdl'/>
     </option>
     <option type='bool' id='RECURSIVE' docs='
-The RECURSIVE tag can be used to turn specify whether or not subdirectories 
-should be searched for input files as well. Possible values are YES and NO. 
-If left blank NO is used. 
+The RECURSIVE tag can be used to turn specify whether or not subdirectories
+should be searched for input files as well. Possible values are YES and NO.
+If left blank NO is used.
 ' defval='0'/>
     <option type='list' id='EXCLUDE' format='filedir' docs='
-The EXCLUDE tag can be used to specify files and/or directories that should 
-excluded from the INPUT source files. This way you can easily exclude a 
-subdirectory from a directory tree whose root is specified with the INPUT tag. 
+The EXCLUDE tag can be used to specify files and/or directories that should
+excluded from the INPUT source files. This way you can easily exclude a
+subdirectory from a directory tree whose root is specified with the INPUT tag.
 '>
     </option>
     <option type='bool' id='EXCLUDE_SYMLINKS' docs='
-The EXCLUDE_SYMLINKS tag can be used select whether or not files or 
-directories that are symbolic links (a Unix filesystem feature) are excluded 
-from the input. 
+The EXCLUDE_SYMLINKS tag can be used select whether or not files or
+directories that are symbolic links (a Unix filesystem feature) are excluded
+from the input.
 ' defval='0'/>
     <option type='list' id='EXCLUDE_PATTERNS' format='string' docs='
-If the value of the INPUT tag contains directories, you can use the 
-EXCLUDE_PATTERNS tag to specify one or more wildcard patterns to exclude 
-certain files from those directories. Note that the wildcards are matched 
-against the file with absolute path, so to exclude all test directories 
-for example use the pattern */test/* 
+If the value of the INPUT tag contains directories, you can use the
+EXCLUDE_PATTERNS tag to specify one or more wildcard patterns to exclude
+certain files from those directories. Note that the wildcards are matched
+against the file with absolute path, so to exclude all test directories
+for example use the pattern */test/*
 '>
     </option>
     <option type='list' id='EXCLUDE_SYMBOLS' format='string' docs='
-The EXCLUDE_SYMBOLS tag can be used to specify one or more symbol names 
-(namespaces, classes, functions, etc.) that should be excluded from the 
-output. The symbol name can be a fully qualified name, a word, or if the 
-wildcard * is used, a substring. Examples: ANamespace, AClass, 
-AClass::ANamespace, ANamespace::*Test 
+The EXCLUDE_SYMBOLS tag can be used to specify one or more symbol names
+(namespaces, classes, functions, etc.) that should be excluded from the
+output. The symbol name can be a fully qualified name, a word, or if the
+wildcard * is used, a substring. Examples: ANamespace, AClass,
+AClass::ANamespace, ANamespace::*Test
 '>
     </option>
     <option type='list' id='EXAMPLE_PATH' format='dir' docs='
-The EXAMPLE_PATH tag can be used to specify one or more files or 
-directories that contain example code fragments that are included (see 
-the \include command). 
+The EXAMPLE_PATH tag can be used to specify one or more files or
+directories that contain example code fragments that are included (see
+the \include command).
 '>
     </option>
     <option type='list' id='EXAMPLE_PATTERNS' format='string' docs='
-If the value of the EXAMPLE_PATH tag contains directories, you can use the 
-EXAMPLE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp 
-and *.h) to filter out the source-files in the directories. If left 
-blank all files are included. 
+If the value of the EXAMPLE_PATH tag contains directories, you can use the
+EXAMPLE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp
+and *.h) to filter out the source-files in the directories. If left
+blank all files are included.
 '>
       <value name='*'/>
     </option>
     <option type='bool' id='EXAMPLE_RECURSIVE' docs='
-If the EXAMPLE_RECURSIVE tag is set to YES then subdirectories will be 
-searched for input files to be used with the \include or \dontinclude 
-commands irrespective of the value of the RECURSIVE tag. 
-Possible values are YES and NO. If left blank NO is used. 
+If the EXAMPLE_RECURSIVE tag is set to YES then subdirectories will be
+searched for input files to be used with the \include or \dontinclude
+commands irrespective of the value of the RECURSIVE tag.
+Possible values are YES and NO. If left blank NO is used.
 ' defval='0'/>
     <option type='list' id='IMAGE_PATH' format='dir' docs='
-The IMAGE_PATH tag can be used to specify one or more files or 
-directories that contain image that are included in the documentation (see 
-the \image command). 
+The IMAGE_PATH tag can be used to specify one or more files or
+directories that contain image that are included in the documentation (see
+the \image command).
 '>
     </option>
     <option type='string' id='INPUT_FILTER' format='file' docs='
-The INPUT_FILTER tag can be used to specify a program that doxygen should 
-invoke to filter for each input file. Doxygen will invoke the filter program 
-by executing (via popen()) the command &lt;filter&gt; &lt;input-file&gt;, where &lt;filter&gt; 
-is the value of the INPUT_FILTER tag, and &lt;input-file&gt; is the name of an 
-input file. Doxygen will then use the output that the filter program writes 
-to standard output.  If FILTER_PATTERNS is specified, this tag will be 
-ignored. 
+The INPUT_FILTER tag can be used to specify a program that doxygen should
+invoke to filter for each input file. Doxygen will invoke the filter program
+by executing (via popen()) the command &lt;filter&gt; &lt;input-file&gt;, where &lt;filter&gt;
+is the value of the INPUT_FILTER tag, and &lt;input-file&gt; is the name of an
+input file. Doxygen will then use the output that the filter program writes
+to standard output.  If FILTER_PATTERNS is specified, this tag will be
+ignored.
 ' defval=''/>
     <option type='list' id='FILTER_PATTERNS' format='file' docs='
-The FILTER_PATTERNS tag can be used to specify filters on a per file pattern 
-basis.  Doxygen will compare the file name with each pattern and apply the 
-filter if there is a match.  The filters are a list of the form: 
-pattern=filter (like *.cpp=my_cpp_filter). See INPUT_FILTER for further 
-info on how filters are used. If FILTER_PATTERNS is empty, INPUT_FILTER 
-is applied to all files. 
+The FILTER_PATTERNS tag can be used to specify filters on a per file pattern
+basis.  Doxygen will compare the file name with each pattern and apply the
+filter if there is a match.  The filters are a list of the form:
+pattern=filter (like *.cpp=my_cpp_filter). See INPUT_FILTER for further
+info on how filters are used. If FILTER_PATTERNS is empty, INPUT_FILTER
+is applied to all files.
 '>
     </option>
     <option type='bool' id='FILTER_SOURCE_FILES' docs='
-If the FILTER_SOURCE_FILES tag is set to YES, the input filter (if set using 
-INPUT_FILTER) will be used to filter the input files when producing source 
-files to browse (i.e. when SOURCE_BROWSER is set to YES). 
+If the FILTER_SOURCE_FILES tag is set to YES, the input filter (if set using
+INPUT_FILTER) will be used to filter the input files when producing source
+files to browse (i.e. when SOURCE_BROWSER is set to YES).
 ' defval='0'/>
   </group>
   <group name='Source Browser' docs='configuration options related to source browsing'>
     <option type='bool' id='SOURCE_BROWSER' docs='
-If the SOURCE_BROWSER tag is set to YES then a list of source files will 
-be generated. Documented entities will be cross-referenced with these sources. 
-Note: To get rid of all source code in the generated output, make sure also 
-VERBATIM_HEADERS is set to NO. 
+If the SOURCE_BROWSER tag is set to YES then a list of source files will
+be generated. Documented entities will be cross-referenced with these sources.
+Note: To get rid of all source code in the generated output, make sure also
+VERBATIM_HEADERS is set to NO.
 ' defval='0'/>
     <option type='bool' id='INLINE_SOURCES' docs='
-Setting the INLINE_SOURCES tag to YES will include the body 
-of functions and classes directly in the documentation. 
+Setting the INLINE_SOURCES tag to YES will include the body
+of functions and classes directly in the documentation.
 ' defval='0'/>
     <option type='bool' id='STRIP_CODE_COMMENTS' docs='
-Setting the STRIP_CODE_COMMENTS tag to YES (the default) will instruct 
-doxygen to hide any special comment blocks from generated source code 
-fragments. Normal C and C++ comments will always remain visible. 
+Setting the STRIP_CODE_COMMENTS tag to YES (the default) will instruct
+doxygen to hide any special comment blocks from generated source code
+fragments. Normal C and C++ comments will always remain visible.
 ' defval='1'/>
     <option type='bool' id='REFERENCED_BY_RELATION' docs='
-If the REFERENCED_BY_RELATION tag is set to YES 
-then for each documented function all documented 
-functions referencing it will be listed. 
+If the REFERENCED_BY_RELATION tag is set to YES
+then for each documented function all documented
+functions referencing it will be listed.
 ' defval='0'/>
     <option type='bool' id='REFERENCES_RELATION' docs='
-If the REFERENCES_RELATION tag is set to YES 
-then for each documented function all documented entities 
-called/used by that function will be listed. 
+If the REFERENCES_RELATION tag is set to YES
+then for each documented function all documented entities
+called/used by that function will be listed.
 ' defval='0'/>
     <option type='bool' id='REFERENCES_LINK_SOURCE' docs='
-If the REFERENCES_LINK_SOURCE tag is set to YES (the default) 
-and SOURCE_BROWSER tag is set to YES, then the hyperlinks from 
-functions in REFERENCES_RELATION and REFERENCED_BY_RELATION lists will 
-link to the source code.  Otherwise they will link to the documentation. 
+If the REFERENCES_LINK_SOURCE tag is set to YES (the default)
+and SOURCE_BROWSER tag is set to YES, then the hyperlinks from
+functions in REFERENCES_RELATION and REFERENCED_BY_RELATION lists will
+link to the source code.  Otherwise they will link to the documentation.
 ' defval='1'/>
     <option type='bool' id='USE_HTAGS' docs='
-If the USE_HTAGS tag is set to YES then the references to source code 
-will point to the HTML generated by the htags(1) tool instead of doxygen 
-built-in source browser. The htags tool is part of GNU&apos;s global source 
-tagging system (see http://www.gnu.org/software/global/global.html). You 
-will need version 4.8.6 or higher. 
+If the USE_HTAGS tag is set to YES then the references to source code
+will point to the HTML generated by the htags(1) tool instead of doxygen
+built-in source browser. The htags tool is part of GNU&apos;s global source
+tagging system (see http://www.gnu.org/software/global/global.html). You
+will need version 4.8.6 or higher.
 ' defval='0' depends='SOURCE_BROWSER'/>
     <option type='bool' id='VERBATIM_HEADERS' docs='
-If the VERBATIM_HEADERS tag is set to YES (the default) then Doxygen 
-will generate a verbatim copy of the header file for each class for 
-which an include is specified. Set to NO to disable this. 
+If the VERBATIM_HEADERS tag is set to YES (the default) then Doxygen
+will generate a verbatim copy of the header file for each class for
+which an include is specified. Set to NO to disable this.
 ' defval='1'/>
   </group>
   <group name='Index' docs='configuration options related to the alphabetical class index'>
     <option type='bool' id='ALPHABETICAL_INDEX' docs='
-If the ALPHABETICAL_INDEX tag is set to YES, an alphabetical index 
-of all compounds will be generated. Enable this if the project 
-contains a lot of classes, structs, unions or interfaces. 
+If the ALPHABETICAL_INDEX tag is set to YES, an alphabetical index
+of all compounds will be generated. Enable this if the project
+contains a lot of classes, structs, unions or interfaces.
 ' defval='0'/>
     <option type='int' id='COLS_IN_ALPHA_INDEX' docs='
-If the alphabetical index is enabled (see ALPHABETICAL_INDEX) then 
-the COLS_IN_ALPHA_INDEX tag can be used to specify the number of columns 
-in which this list will be split (can be a number in the range [1..20]) 
+If the alphabetical index is enabled (see ALPHABETICAL_INDEX) then
+the COLS_IN_ALPHA_INDEX tag can be used to specify the number of columns
+in which this list will be split (can be a number in the range [1..20])
 ' minval='1' maxval='20' defval='5'/>
     <option type='list' id='IGNORE_PREFIX' format='string' docs='
-In case all classes in a project start with a common prefix, all 
-classes will be put under the same header in the alphabetical index. 
-The IGNORE_PREFIX tag can be used to specify one or more prefixes that 
-should be ignored while generating the index headers. 
+In case all classes in a project start with a common prefix, all
+classes will be put under the same header in the alphabetical index.
+The IGNORE_PREFIX tag can be used to specify one or more prefixes that
+should be ignored while generating the index headers.
 '>
     </option>
   </group>
   <group name='HTML' docs='configuration options related to the HTML output'>
     <option type='bool' id='GENERATE_HTML' docs='
-If the GENERATE_HTML tag is set to YES (the default) Doxygen will 
-generate HTML output. 
+If the GENERATE_HTML tag is set to YES (the default) Doxygen will
+generate HTML output.
 ' defval='1'/>
     <option type='string' id='HTML_OUTPUT' format='dir' docs='
-The HTML_OUTPUT tag is used to specify where the HTML docs will be put. 
-If a relative path is entered the value of OUTPUT_DIRECTORY will be 
-put in front of it. If left blank `html&apos; will be used as the default path. 
+The HTML_OUTPUT tag is used to specify where the HTML docs will be put.
+If a relative path is entered the value of OUTPUT_DIRECTORY will be
+put in front of it. If left blank `html&apos; will be used as the default path.
 ' defval='html' depends='GENERATE_HTML'/>
     <option type='string' id='HTML_FILE_EXTENSION' format='string' docs='
-The HTML_FILE_EXTENSION tag can be used to specify the file extension for 
-each generated HTML page (for example: .htm,.php,.asp). If it is left blank 
-doxygen will generate files with .html extension. 
+The HTML_FILE_EXTENSION tag can be used to specify the file extension for
+each generated HTML page (for example: .htm,.php,.asp). If it is left blank
+doxygen will generate files with .html extension.
 ' defval='.html' depends='GENERATE_HTML'/>
     <option type='string' id='HTML_HEADER' format='file' docs='
-The HTML_HEADER tag can be used to specify a personal HTML header for 
-each generated HTML page. If it is left blank doxygen will generate a 
-standard header. 
+The HTML_HEADER tag can be used to specify a personal HTML header for
+each generated HTML page. If it is left blank doxygen will generate a
+standard header.
 ' defval='' depends='GENERATE_HTML'/>
     <option type='string' id='HTML_FOOTER' format='file' docs='
-The HTML_FOOTER tag can be used to specify a personal HTML footer for 
-each generated HTML page. If it is left blank doxygen will generate a 
-standard footer. 
+The HTML_FOOTER tag can be used to specify a personal HTML footer for
+each generated HTML page. If it is left blank doxygen will generate a
+standard footer.
 ' defval='' depends='GENERATE_HTML'/>
     <option type='string' id='HTML_STYLESHEET' format='file' docs='
-The HTML_STYLESHEET tag can be used to specify a user-defined cascading 
-style sheet that is used by each HTML page. It can be used to 
-fine-tune the look of the HTML output. If the tag is left blank doxygen 
-will generate a default style sheet. Note that doxygen will try to copy 
-the style sheet file to the HTML output directory, so don&apos;t put your own 
-stylesheet in the HTML output directory as well, or it will be erased! 
+The HTML_STYLESHEET tag can be used to specify a user-defined cascading
+style sheet that is used by each HTML page. It can be used to
+fine-tune the look of the HTML output. If the tag is left blank doxygen
+will generate a default style sheet. Note that doxygen will try to copy
+the style sheet file to the HTML output directory, so don&apos;t put your own
+stylesheet in the HTML output directory as well, or it will be erased!
 ' defval='' depends='GENERATE_HTML'/>
     <option type='bool' id='HTML_ALIGN_MEMBERS' docs='
-If the HTML_ALIGN_MEMBERS tag is set to YES, the members of classes, 
-files or namespaces will be aligned in HTML using tables. If set to 
-NO a bullet list will be used. 
+If the HTML_ALIGN_MEMBERS tag is set to YES, the members of classes,
+files or namespaces will be aligned in HTML using tables. If set to
+NO a bullet list will be used.
 ' defval='1' depends='GENERATE_HTML'/>
     <option type='bool' id='HTML_DYNAMIC_SECTIONS' docs='
-If the HTML_DYNAMIC_SECTIONS tag is set to YES then the generated HTML 
-documentation will contain sections that can be hidden and shown after the 
-page has loaded. For this to work a browser that supports 
-JavaScript and DHTML is required (for instance Mozilla 1.0+, Firefox 
-Netscape 6.0+, Internet explorer 5.0+, Konqueror, or Safari). 
+If the HTML_DYNAMIC_SECTIONS tag is set to YES then the generated HTML
+documentation will contain sections that can be hidden and shown after the
+page has loaded. For this to work a browser that supports
+JavaScript and DHTML is required (for instance Mozilla 1.0+, Firefox
+Netscape 6.0+, Internet explorer 5.0+, Konqueror, or Safari).
 ' defval='0' depends='GENERATE_HTML'/>
     <option type='bool' id='GENERATE_DOCSET' docs='
-If the GENERATE_DOCSET tag is set to YES, additional index files 
-will be generated that can be used as input for Apple&apos;s Xcode 3 
-integrated development environment, introduced with OSX 10.5 (Leopard). 
-To create a documentation set, doxygen will generate a Makefile in the 
-HTML output directory. Running make will produce the docset in that 
-directory and running &quot;make install&quot; will install the docset in 
-~/Library/Developer/Shared/Documentation/DocSets so that Xcode will find 
-it at startup. 
-See http://developer.apple.com/tools/creatingdocsetswithdoxygen.html for more information. 
+If the GENERATE_DOCSET tag is set to YES, additional index files
+will be generated that can be used as input for Apple&apos;s Xcode 3
+integrated development environment, introduced with OSX 10.5 (Leopard).
+To create a documentation set, doxygen will generate a Makefile in the
+HTML output directory. Running make will produce the docset in that
+directory and running &quot;make install&quot; will install the docset in
+~/Library/Developer/Shared/Documentation/DocSets so that Xcode will find
+it at startup.
+See http://developer.apple.com/tools/creatingdocsetswithdoxygen.html for more information.
 ' defval='0' depends='GENERATE_HTML'/>
     <option type='string' id='DOCSET_FEEDNAME' format='string' docs='
-When GENERATE_DOCSET tag is set to YES, this tag determines the name of the 
-feed. A documentation feed provides an umbrella under which multiple 
-documentation sets from a single provider (such as a company or product suite) 
-can be grouped. 
+When GENERATE_DOCSET tag is set to YES, this tag determines the name of the
+feed. A documentation feed provides an umbrella under which multiple
+documentation sets from a single provider (such as a company or product suite)
+can be grouped.
 ' defval='Doxygen generated docs' depends='GENERATE_DOCSET'/>
     <option type='string' id='DOCSET_BUNDLE_ID' format='string' docs='
-When GENERATE_DOCSET tag is set to YES, this tag specifies a string that 
-should uniquely identify the documentation set bundle. This should be a 
-reverse domain-name style string, e.g. com.mycompany.MyDocSet. Doxygen 
-will append .docset to the name. 
+When GENERATE_DOCSET tag is set to YES, this tag specifies a string that
+should uniquely identify the documentation set bundle. This should be a
+reverse domain-name style string, e.g. com.mycompany.MyDocSet. Doxygen
+will append .docset to the name.
 ' defval='org.doxygen.Project' depends='GENERATE_DOCSET'/>
     <option type='bool' id='GENERATE_HTMLHELP' docs='
-If the GENERATE_HTMLHELP tag is set to YES, additional index files 
-will be generated that can be used as input for tools like the 
-Microsoft HTML help workshop to generate a compiled HTML help file (.chm) 
-of the generated HTML documentation. 
+If the GENERATE_HTMLHELP tag is set to YES, additional index files
+will be generated that can be used as input for tools like the
+Microsoft HTML help workshop to generate a compiled HTML help file (.chm)
+of the generated HTML documentation.
 ' defval='0' depends='GENERATE_HTML'/>
     <option type='string' id='CHM_FILE' format='file' docs='
-If the GENERATE_HTMLHELP tag is set to YES, the CHM_FILE tag can 
-be used to specify the file name of the resulting .chm file. You 
-can add a path in front of the file if the result should not be 
-written to the html output directory. 
+If the GENERATE_HTMLHELP tag is set to YES, the CHM_FILE tag can
+be used to specify the file name of the resulting .chm file. You
+can add a path in front of the file if the result should not be
+written to the html output directory.
 ' defval='' depends='GENERATE_HTMLHELP'/>
     <option type='string' id='HHC_LOCATION' format='file' docs='
-If the GENERATE_HTMLHELP tag is set to YES, the HHC_LOCATION tag can 
-be used to specify the location (absolute path including file name) of 
-the HTML help compiler (hhc.exe). If non-empty doxygen will try to run 
-the HTML help compiler on the generated index.hhp. 
+If the GENERATE_HTMLHELP tag is set to YES, the HHC_LOCATION tag can
+be used to specify the location (absolute path including file name) of
+the HTML help compiler (hhc.exe). If non-empty doxygen will try to run
+the HTML help compiler on the generated index.hhp.
 ' defval='' depends='GENERATE_HTMLHELP'/>
     <option type='bool' id='GENERATE_CHI' docs='
-If the GENERATE_HTMLHELP tag is set to YES, the GENERATE_CHI flag 
-controls if a separate .chi index file is generated (YES) or that 
-it should be included in the master .chm file (NO). 
+If the GENERATE_HTMLHELP tag is set to YES, the GENERATE_CHI flag
+controls if a separate .chi index file is generated (YES) or that
+it should be included in the master .chm file (NO).
 ' defval='0' depends='GENERATE_HTMLHELP'/>
     <option type='string' id='CHM_INDEX_ENCODING' format='string' docs='
-If the GENERATE_HTMLHELP tag is set to YES, the CHM_INDEX_ENCODING 
-is used to encode HtmlHelp index (hhk), content (hhc) and project file 
-content. 
+If the GENERATE_HTMLHELP tag is set to YES, the CHM_INDEX_ENCODING
+is used to encode HtmlHelp index (hhk), content (hhc) and project file
+content.
 ' defval='' depends='GENERATE_HTMLHELP'/>
     <option type='bool' id='BINARY_TOC' docs='
-If the GENERATE_HTMLHELP tag is set to YES, the BINARY_TOC flag 
-controls whether a binary table of contents is generated (YES) or a 
-normal table of contents (NO) in the .chm file. 
+If the GENERATE_HTMLHELP tag is set to YES, the BINARY_TOC flag
+controls whether a binary table of contents is generated (YES) or a
+normal table of contents (NO) in the .chm file.
 ' defval='0' depends='GENERATE_HTMLHELP'/>
     <option type='bool' id='TOC_EXPAND' docs='
-The TOC_EXPAND flag can be set to YES to add extra items for group members 
-to the contents of the HTML help documentation and to the tree view. 
+The TOC_EXPAND flag can be set to YES to add extra items for group members
+to the contents of the HTML help documentation and to the tree view.
 ' defval='0' depends='GENERATE_HTMLHELP'/>
     <option type='bool' id='GENERATE_QHP' docs='
-If the GENERATE_QHP tag is set to YES and both QHP_NAMESPACE and QHP_VIRTUAL_FOLDER 
-are set, an additional index file will be generated that can be used as input for 
-Qt&apos;s qhelpgenerator to generate a Qt Compressed Help (.qch) of the generated 
-HTML documentation. 
+If the GENERATE_QHP tag is set to YES and both QHP_NAMESPACE and QHP_VIRTUAL_FOLDER
+are set, an additional index file will be generated that can be used as input for
+Qt&apos;s qhelpgenerator to generate a Qt Compressed Help (.qch) of the generated
+HTML documentation.
 ' defval='0' depends='GENERATE_HTML'/>
     <option type='string' id='QCH_FILE' format='file' docs='
-If the QHG_LOCATION tag is specified, the QCH_FILE tag can 
-be used to specify the file name of the resulting .qch file. 
-The path specified is relative to the HTML output folder. 
+If the QHG_LOCATION tag is specified, the QCH_FILE tag can
+be used to specify the file name of the resulting .qch file.
+The path specified is relative to the HTML output folder.
 ' defval='' depends='GENERATE_QHP'/>
     <option type='string' id='QHP_NAMESPACE' format='string' docs='
-The QHP_NAMESPACE tag specifies the namespace to use when generating 
-Qt Help Project output. For more information please see 
-http://doc.trolltech.com/qthelpproject.html#namespace 
+The QHP_NAMESPACE tag specifies the namespace to use when generating
+Qt Help Project output. For more information please see
+http://doc.trolltech.com/qthelpproject.html#namespace
 ' defval='' depends='GENERATE_QHP'/>
     <option type='string' id='QHP_VIRTUAL_FOLDER' format='string' docs='
-The QHP_VIRTUAL_FOLDER tag specifies the namespace to use when generating 
-Qt Help Project output. For more information please see 
-http://doc.trolltech.com/qthelpproject.html#virtual-folders 
+The QHP_VIRTUAL_FOLDER tag specifies the namespace to use when generating
+Qt Help Project output. For more information please see
+http://doc.trolltech.com/qthelpproject.html#virtual-folders
 ' defval='doc' depends='GENERATE_QHP'/>
     <option type='string' id='QHP_CUST_FILTER_NAME' format='string' docs='
-If QHP_CUST_FILTER_NAME is set, it specifies the name of a custom filter to add. 
-For more information please see 
-http://doc.trolltech.com/qthelpproject.html#custom-filters 
+If QHP_CUST_FILTER_NAME is set, it specifies the name of a custom filter to add.
+For more information please see
+http://doc.trolltech.com/qthelpproject.html#custom-filters
 ' defval='' depends='GENERATE_QHP'/>
     <option type='string' id='QHP_CUST_FILTER_ATTRS' format='string' docs='
-The QHP_CUST_FILT_ATTRS tag specifies the list of the attributes of the custom filter to add.For more information please see 
-&lt;a href=&quot;http://doc.trolltech.com/qthelpproject.html#custom-filters&quot;&gt;Qt Help Project / Custom Filters&lt;/a&gt;. 
+The QHP_CUST_FILT_ATTRS tag specifies the list of the attributes of the custom filter to add.For more information please see
+&lt;a href=&quot;http://doc.trolltech.com/qthelpproject.html#custom-filters&quot;&gt;Qt Help Project / Custom Filters&lt;/a&gt;.
 ' defval='' depends='GENERATE_QHP'/>
     <option type='string' id='QHP_SECT_FILTER_ATTRS' format='string' docs='
-The QHP_SECT_FILTER_ATTRS tag specifies the list of the attributes this project&apos;s 
-filter section matches. 
-&lt;a href=&quot;http://doc.trolltech.com/qthelpproject.html#filter-attributes&quot;&gt;Qt Help Project / Filter Attributes&lt;/a&gt;. 
+The QHP_SECT_FILTER_ATTRS tag specifies the list of the attributes this project&apos;s
+filter section matches.
+&lt;a href=&quot;http://doc.trolltech.com/qthelpproject.html#filter-attributes&quot;&gt;Qt Help Project / Filter Attributes&lt;/a&gt;.
 ' defval='' depends='GENERATE_QHP'/>
     <option type='string' id='QHG_LOCATION' format='file' docs='
-If the GENERATE_QHP tag is set to YES, the QHG_LOCATION tag can 
-be used to specify the location of Qt&apos;s qhelpgenerator. 
-If non-empty doxygen will try to run qhelpgenerator on the generated 
-.qhp file. 
+If the GENERATE_QHP tag is set to YES, the QHG_LOCATION tag can
+be used to specify the location of Qt&apos;s qhelpgenerator.
+If non-empty doxygen will try to run qhelpgenerator on the generated
+.qhp file.
 ' defval='' depends='GENERATE_QHP'/>
     <option type='bool' id='DISABLE_INDEX' docs='
-The DISABLE_INDEX tag can be used to turn on/off the condensed index at 
-top of each HTML page. The value NO (the default) enables the index and 
-the value YES disables it. 
+The DISABLE_INDEX tag can be used to turn on/off the condensed index at
+top of each HTML page. The value NO (the default) enables the index and
+the value YES disables it.
 ' defval='0' depends='GENERATE_HTML'/>
     <option type='int' id='ENUM_VALUES_PER_LINE' docs='
-This tag can be used to set the number of enum values (range [1..20]) 
-that doxygen will group on one line in the generated HTML documentation. 
+This tag can be used to set the number of enum values (range [1..20])
+that doxygen will group on one line in the generated HTML documentation.
 ' minval='1' maxval='20' defval='4' depends='GENERATE_HTML'/>
     <option type='enum' id='GENERATE_TREEVIEW' defval='NONE' docs='
-The GENERATE_TREEVIEW tag is used to specify whether a tree-like index 
-structure should be generated to display hierarchical information. 
-If the tag value is set to FRAME, a side panel will be generated 
-containing a tree-like index structure (just like the one that 
-is generated for HTML Help). For this to work a browser that supports 
-JavaScript, DHTML, CSS and frames is required (for instance Mozilla 1.0+, 
-Netscape 6.0+, Internet explorer 5.0+, or Konqueror). Windows users are 
-probably better off using the HTML help feature. Other possible values 
-for this tag are: HIERARCHIES, which will generate the Groups, Directories, 
-and Class Hierarchy pages using a tree view instead of an ordered list; 
-ALL, which combines the behavior of FRAME and HIERARCHIES; and NONE, which 
-disables this behavior completely. For backwards compatibility with previous 
-releases of Doxygen, the values YES and NO are equivalent to FRAME and NONE 
-respectively. 
+The GENERATE_TREEVIEW tag is used to specify whether a tree-like index
+structure should be generated to display hierarchical information.
+If the tag value is set to FRAME, a side panel will be generated
+containing a tree-like index structure (just like the one that
+is generated for HTML Help). For this to work a browser that supports
+JavaScript, DHTML, CSS and frames is required (for instance Mozilla 1.0+,
+Netscape 6.0+, Internet explorer 5.0+, or Konqueror). Windows users are
+probably better off using the HTML help feature. Other possible values
+for this tag are: HIERARCHIES, which will generate the Groups, Directories,
+and Class Hierarchy pages using a tree view instead of an ordered list;
+ALL, which combines the behavior of FRAME and HIERARCHIES; and NONE, which
+disables this behavior completely. For backwards compatibility with previous
+releases of Doxygen, the values YES and NO are equivalent to FRAME and NONE
+respectively.
 ' depends='GENERATE_HTML'>
       <value name='NONE'/>
       <value name='FRAME'/>
@@ -895,46 +895,46 @@ respectively.
       <value name='ALL'/>
     </option>
     <option type='int' id='TREEVIEW_WIDTH' docs='
-If the treeview is enabled (see GENERATE_TREEVIEW) then this tag can be 
-used to set the initial width (in pixels) of the frame in which the tree 
-is shown. 
+If the treeview is enabled (see GENERATE_TREEVIEW) then this tag can be
+used to set the initial width (in pixels) of the frame in which the tree
+is shown.
 ' minval='0' maxval='1500' defval='250' depends='GENERATE_HTML'/>
     <option type='int' id='FORMULA_FONTSIZE' docs='
-Use this tag to change the font size of Latex formulas included 
-as images in the HTML documentation. The default is 10. Note that 
-when you change the font size after a successful doxygen run you need 
-to manually remove any form_*.png images from the HTML output directory 
-to force them to be regenerated. 
+Use this tag to change the font size of Latex formulas included
+as images in the HTML documentation. The default is 10. Note that
+when you change the font size after a successful doxygen run you need
+to manually remove any form_*.png images from the HTML output directory
+to force them to be regenerated.
 ' minval='8' maxval='50' defval='10' depends='GENERATE_HTML'/>
   </group>
   <group name='LaTeX' docs='configuration options related to the LaTeX output'>
     <option type='bool' id='GENERATE_LATEX' docs='
-If the GENERATE_LATEX tag is set to YES (the default) Doxygen will 
-generate Latex output. 
+If the GENERATE_LATEX tag is set to YES (the default) Doxygen will
+generate Latex output.
 ' defval='1'/>
     <option type='string' id='LATEX_OUTPUT' format='dir' docs='
-The LATEX_OUTPUT tag is used to specify where the LaTeX docs will be put. 
-If a relative path is entered the value of OUTPUT_DIRECTORY will be 
-put in front of it. If left blank `latex&apos; will be used as the default path. 
+The LATEX_OUTPUT tag is used to specify where the LaTeX docs will be put.
+If a relative path is entered the value of OUTPUT_DIRECTORY will be
+put in front of it. If left blank `latex&apos; will be used as the default path.
 ' defval='latex' depends='GENERATE_LATEX'/>
     <option type='string' id='LATEX_CMD_NAME' format='file' docs='
-The LATEX_CMD_NAME tag can be used to specify the LaTeX command name to be 
-invoked. If left blank `latex&apos; will be used as the default command name. 
+The LATEX_CMD_NAME tag can be used to specify the LaTeX command name to be
+invoked. If left blank `latex&apos; will be used as the default command name.
 ' defval='latex' depends='GENERATE_LATEX'/>
     <option type='string' id='MAKEINDEX_CMD_NAME' format='file' docs='
-The MAKEINDEX_CMD_NAME tag can be used to specify the command name to 
-generate index for LaTeX. If left blank `makeindex&apos; will be used as the 
-default command name. 
+The MAKEINDEX_CMD_NAME tag can be used to specify the command name to
+generate index for LaTeX. If left blank `makeindex&apos; will be used as the
+default command name.
 ' defval='makeindex' depends='GENERATE_LATEX'/>
     <option type='bool' id='COMPACT_LATEX' docs='
-If the COMPACT_LATEX tag is set to YES Doxygen generates more compact 
-LaTeX documents. This may be useful for small projects and may help to 
-save some trees in general. 
+If the COMPACT_LATEX tag is set to YES Doxygen generates more compact
+LaTeX documents. This may be useful for small projects and may help to
+save some trees in general.
 ' defval='0' depends='GENERATE_LATEX'/>
     <option type='enum' id='PAPER_TYPE' defval='a4wide' docs='
-The PAPER_TYPE tag can be used to set the paper type that is used 
-by the printer. Possible values are: a4, a4wide, letter, legal and 
-executive. If left blank a4wide will be used. 
+The PAPER_TYPE tag can be used to set the paper type that is used
+by the printer. Possible values are: a4, a4wide, letter, legal and
+executive. If left blank a4wide will be used.
 ' depends='GENERATE_LATEX'>
       <value name='a4'/>
       <value name='a4wide'/>
@@ -943,37 +943,37 @@ executive. If left blank a4wide will be used.
       <value name='executive'/>
     </option>
     <option type='list' id='EXTRA_PACKAGES' format='string' docs='
-The EXTRA_PACKAGES tag can be to specify one or more names of LaTeX 
-packages that should be included in the LaTeX output. 
+The EXTRA_PACKAGES tag can be to specify one or more names of LaTeX
+packages that should be included in the LaTeX output.
 ' depends='GENERATE_LATEX'>
     </option>
     <option type='string' id='LATEX_HEADER' format='file' docs='
-The LATEX_HEADER tag can be used to specify a personal LaTeX header for 
-the generated latex document. The header should contain everything until 
-the first chapter. If it is left blank doxygen will generate a 
-standard header. Notice: only use this tag if you know what you are doing! 
+The LATEX_HEADER tag can be used to specify a personal LaTeX header for
+the generated latex document. The header should contain everything until
+the first chapter. If it is left blank doxygen will generate a
+standard header. Notice: only use this tag if you know what you are doing!
 ' defval='' depends='GENERATE_LATEX'/>
     <option type='bool' id='PDF_HYPERLINKS' docs='
-If the PDF_HYPERLINKS tag is set to YES, the LaTeX that is generated 
-is prepared for conversion to pdf (using ps2pdf). The pdf file will 
-contain links (just like the HTML output) instead of page references 
-This makes the output suitable for online browsing using a pdf viewer. 
+If the PDF_HYPERLINKS tag is set to YES, the LaTeX that is generated
+is prepared for conversion to pdf (using ps2pdf). The pdf file will
+contain links (just like the HTML output) instead of page references
+This makes the output suitable for online browsing using a pdf viewer.
 ' defval='1' depends='GENERATE_LATEX'/>
     <option type='bool' id='USE_PDFLATEX' docs='
-If the USE_PDFLATEX tag is set to YES, pdflatex will be used instead of 
-plain latex in the generated Makefile. Set this option to YES to get a 
-higher quality PDF documentation. 
+If the USE_PDFLATEX tag is set to YES, pdflatex will be used instead of
+plain latex in the generated Makefile. Set this option to YES to get a
+higher quality PDF documentation.
 ' defval='1' depends='GENERATE_LATEX'/>
     <option type='bool' id='LATEX_BATCHMODE' docs='
-If the LATEX_BATCHMODE tag is set to YES, doxygen will add the \\batchmode. 
-command to the generated LaTeX files. This will instruct LaTeX to keep 
-running if errors occur, instead of asking the user for help. 
-This option is also used when generating formulas in HTML. 
+If the LATEX_BATCHMODE tag is set to YES, doxygen will add the \\batchmode.
+command to the generated LaTeX files. This will instruct LaTeX to keep
+running if errors occur, instead of asking the user for help.
+This option is also used when generating formulas in HTML.
 ' defval='0' depends='GENERATE_LATEX'/>
     <option type='bool' id='LATEX_HIDE_INDICES' docs='
-If LATEX_HIDE_INDICES is set to YES then doxygen will not 
-include the index chapters (such as File Index, Compound Index, etc.) 
-in the output. 
+If LATEX_HIDE_INDICES is set to YES then doxygen will not
+include the index chapters (such as File Index, Compound Index, etc.)
+in the output.
 ' defval='0' depends='GENERATE_LATEX'/>
     <option type='bool' id='LATEX_SOURCE_CODE' docs='
 If LATEX_SOURCE_CODE is set to YES then doxygen will include
@@ -984,393 +984,393 @@ such as SOURCE_BROWSER.
   </group>
   <group name='RTF' docs='configuration options related to the RTF output'>
     <option type='bool' id='GENERATE_RTF' docs='
-If the GENERATE_RTF tag is set to YES Doxygen will generate RTF output 
-The RTF output is optimized for Word 97 and may not look very pretty with 
-other RTF readers or editors. 
+If the GENERATE_RTF tag is set to YES Doxygen will generate RTF output
+The RTF output is optimized for Word 97 and may not look very pretty with
+other RTF readers or editors.
 ' defval='0'/>
     <option type='string' id='RTF_OUTPUT' format='dir' docs='
-The RTF_OUTPUT tag is used to specify where the RTF docs will be put. 
-If a relative path is entered the value of OUTPUT_DIRECTORY will be 
-put in front of it. If left blank `rtf&apos; will be used as the default path. 
+The RTF_OUTPUT tag is used to specify where the RTF docs will be put.
+If a relative path is entered the value of OUTPUT_DIRECTORY will be
+put in front of it. If left blank `rtf&apos; will be used as the default path.
 ' defval='rtf' depends='GENERATE_RTF'/>
     <option type='bool' id='COMPACT_RTF' docs='
-If the COMPACT_RTF tag is set to YES Doxygen generates more compact 
-RTF documents. This may be useful for small projects and may help to 
-save some trees in general. 
+If the COMPACT_RTF tag is set to YES Doxygen generates more compact
+RTF documents. This may be useful for small projects and may help to
+save some trees in general.
 ' defval='0' depends='GENERATE_RTF'/>
     <option type='bool' id='RTF_HYPERLINKS' docs='
-If the RTF_HYPERLINKS tag is set to YES, the RTF that is generated 
-will contain hyperlink fields. The RTF file will 
-contain links (just like the HTML output) instead of page references. 
-This makes the output suitable for online browsing using WORD or other 
-programs which support those fields. 
-Note: wordpad (write) and others do not support links. 
+If the RTF_HYPERLINKS tag is set to YES, the RTF that is generated
+will contain hyperlink fields. The RTF file will
+contain links (just like the HTML output) instead of page references.
+This makes the output suitable for online browsing using WORD or other
+programs which support those fields.
+Note: wordpad (write) and others do not support links.
 ' defval='0' depends='GENERATE_RTF'/>
     <option type='string' id='RTF_STYLESHEET_FILE' format='file' docs='
-Load stylesheet definitions from file. Syntax is similar to doxygen&apos;s 
-config file, i.e. a series of assignments. You only have to provide 
-replacements, missing definitions are set to their default value. 
+Load stylesheet definitions from file. Syntax is similar to doxygen&apos;s
+config file, i.e. a series of assignments. You only have to provide
+replacements, missing definitions are set to their default value.
 ' defval='' depends='GENERATE_RTF'/>
     <option type='string' id='RTF_EXTENSIONS_FILE' format='file' docs='
-Set optional variables used in the generation of an rtf document. 
-Syntax is similar to doxygen&apos;s config file. 
+Set optional variables used in the generation of an rtf document.
+Syntax is similar to doxygen&apos;s config file.
 ' defval='' depends='GENERATE_RTF'/>
   </group>
   <group name='Man' docs='configuration options related to the man page output'>
     <option type='bool' id='GENERATE_MAN' docs='
-If the GENERATE_MAN tag is set to YES (the default) Doxygen will 
-generate man pages 
+If the GENERATE_MAN tag is set to YES (the default) Doxygen will
+generate man pages
 ' defval='0'/>
     <option type='string' id='MAN_OUTPUT' format='dir' docs='
-The MAN_OUTPUT tag is used to specify where the man pages will be put. 
-If a relative path is entered the value of OUTPUT_DIRECTORY will be 
-put in front of it. If left blank `man&apos; will be used as the default path. 
+The MAN_OUTPUT tag is used to specify where the man pages will be put.
+If a relative path is entered the value of OUTPUT_DIRECTORY will be
+put in front of it. If left blank `man&apos; will be used as the default path.
 ' defval='man' depends='GENERATE_MAN'/>
     <option type='string' id='MAN_EXTENSION' format='string' docs='
-The MAN_EXTENSION tag determines the extension that is added to 
-the generated man pages (default is the subroutine&apos;s section .3) 
+The MAN_EXTENSION tag determines the extension that is added to
+the generated man pages (default is the subroutine&apos;s section .3)
 ' defval='.3' depends='GENERATE_MAN'/>
     <option type='bool' id='MAN_LINKS' docs='
-If the MAN_LINKS tag is set to YES and Doxygen generates man output, 
-then it will generate one additional man file for each entity 
-documented in the real man page(s). These additional files 
-only source the real man page, but without them the man command 
-would be unable to find the correct page. The default is NO. 
+If the MAN_LINKS tag is set to YES and Doxygen generates man output,
+then it will generate one additional man file for each entity
+documented in the real man page(s). These additional files
+only source the real man page, but without them the man command
+would be unable to find the correct page. The default is NO.
 ' defval='0' depends='GENERATE_MAN'/>
   </group>
   <group name='XML' docs='configuration options related to the XML output'>
     <option type='bool' id='GENERATE_XML' docs='
-If the GENERATE_XML tag is set to YES Doxygen will 
-generate an XML file that captures the structure of 
-the code including all documentation. 
+If the GENERATE_XML tag is set to YES Doxygen will
+generate an XML file that captures the structure of
+the code including all documentation.
 ' defval='0'/>
     <option type='string' id='XML_OUTPUT' format='dir' docs='
-The XML_OUTPUT tag is used to specify where the XML pages will be put. 
-If a relative path is entered the value of OUTPUT_DIRECTORY will be 
-put in front of it. If left blank `xml&apos; will be used as the default path. 
+The XML_OUTPUT tag is used to specify where the XML pages will be put.
+If a relative path is entered the value of OUTPUT_DIRECTORY will be
+put in front of it. If left blank `xml&apos; will be used as the default path.
 ' defval='xml' depends='GENERATE_XML'/>
     <option type='string' id='XML_SCHEMA' format='string' docs='
-The XML_SCHEMA tag can be used to specify an XML schema, 
-which can be used by a validating XML parser to check the 
-syntax of the XML files. 
+The XML_SCHEMA tag can be used to specify an XML schema,
+which can be used by a validating XML parser to check the
+syntax of the XML files.
 ' defval='' depends='GENERATE_XML'/>
     <option type='string' id='XML_DTD' format='string' docs='
-The XML_DTD tag can be used to specify an XML DTD, 
-which can be used by a validating XML parser to check the 
-syntax of the XML files. 
+The XML_DTD tag can be used to specify an XML DTD,
+which can be used by a validating XML parser to check the
+syntax of the XML files.
 ' defval='' depends='GENERATE_XML'/>
     <option type='bool' id='XML_PROGRAMLISTING' docs='
-If the XML_PROGRAMLISTING tag is set to YES Doxygen will 
-dump the program listings (including syntax highlighting 
-and cross-referencing information) to the XML output. Note that 
-enabling this will significantly increase the size of the XML output. 
+If the XML_PROGRAMLISTING tag is set to YES Doxygen will
+dump the program listings (including syntax highlighting
+and cross-referencing information) to the XML output. Note that
+enabling this will significantly increase the size of the XML output.
 ' defval='1' depends='GENERATE_XML'/>
   </group>
   <group name='DEF' docs='configuration options for the AutoGen Definitions output'>
     <option type='bool' id='GENERATE_AUTOGEN_DEF' docs='
-If the GENERATE_AUTOGEN_DEF tag is set to YES Doxygen will 
-generate an AutoGen Definitions (see autogen.sf.net) file 
-that captures the structure of the code including all 
-documentation. Note that this feature is still experimental 
-and incomplete at the moment. 
+If the GENERATE_AUTOGEN_DEF tag is set to YES Doxygen will
+generate an AutoGen Definitions (see autogen.sf.net) file
+that captures the structure of the code including all
+documentation. Note that this feature is still experimental
+and incomplete at the moment.
 ' defval='0'/>
   </group>
   <group name='PerlMod' docs='configuration options related to the Perl module output'>
     <option type='bool' id='GENERATE_PERLMOD' docs='
-If the GENERATE_PERLMOD tag is set to YES Doxygen will 
-generate a Perl module file that captures the structure of 
-the code including all documentation. Note that this 
-feature is still experimental and incomplete at the 
-moment. 
+If the GENERATE_PERLMOD tag is set to YES Doxygen will
+generate a Perl module file that captures the structure of
+the code including all documentation. Note that this
+feature is still experimental and incomplete at the
+moment.
 ' defval='0'/>
     <option type='bool' id='PERLMOD_LATEX' docs='
-If the PERLMOD_LATEX tag is set to YES Doxygen will generate 
-the necessary Makefile rules, Perl scripts and LaTeX code to be able 
-to generate PDF and DVI output from the Perl module output. 
+If the PERLMOD_LATEX tag is set to YES Doxygen will generate
+the necessary Makefile rules, Perl scripts and LaTeX code to be able
+to generate PDF and DVI output from the Perl module output.
 ' defval='0' depends='GENERATE_PERLMOD'/>
     <option type='bool' id='PERLMOD_PRETTY' docs='
-If the PERLMOD_PRETTY tag is set to YES the Perl module output will be 
-nicely formatted so it can be parsed by a human reader.  This is useful 
-if you want to understand what is going on.  On the other hand, if this 
-tag is set to NO the size of the Perl module output will be much smaller 
-and Perl will parse it just the same. 
+If the PERLMOD_PRETTY tag is set to YES the Perl module output will be
+nicely formatted so it can be parsed by a human reader.  This is useful
+if you want to understand what is going on.  On the other hand, if this
+tag is set to NO the size of the Perl module output will be much smaller
+and Perl will parse it just the same.
 ' defval='1' depends='GENERATE_PERLMOD'/>
     <option type='string' id='PERLMOD_MAKEVAR_PREFIX' format='string' docs='
-The names of the make variables in the generated doxyrules.make file 
-are prefixed with the string contained in PERLMOD_MAKEVAR_PREFIX. 
-This is useful so different doxyrules.make files included by the same 
+The names of the make variables in the generated doxyrules.make file
+are prefixed with the string contained in PERLMOD_MAKEVAR_PREFIX.
+This is useful so different doxyrules.make files included by the same
 Makefile don&apos;t overwrite each other&apos;s variables.' defval='' depends='GENERATE_PERLMOD'/>
   </group>
   <group name='Preprocessor' docs='Configuration options related to the preprocessor   '>
     <option type='bool' id='ENABLE_PREPROCESSING' docs='
-If the ENABLE_PREPROCESSING tag is set to YES (the default) Doxygen will 
-evaluate all C-preprocessor directives found in the sources and include 
-files. 
+If the ENABLE_PREPROCESSING tag is set to YES (the default) Doxygen will
+evaluate all C-preprocessor directives found in the sources and include
+files.
 ' defval='1'/>
     <option type='bool' id='MACRO_EXPANSION' docs='
-If the MACRO_EXPANSION tag is set to YES Doxygen will expand all macro 
-names in the source code. If set to NO (the default) only conditional 
-compilation will be performed. Macro expansion can be done in a controlled 
-way by setting EXPAND_ONLY_PREDEF to YES. 
+If the MACRO_EXPANSION tag is set to YES Doxygen will expand all macro
+names in the source code. If set to NO (the default) only conditional
+compilation will be performed. Macro expansion can be done in a controlled
+way by setting EXPAND_ONLY_PREDEF to YES.
 ' defval='0' depends='ENABLE_PREPROCESSING'/>
     <option type='bool' id='EXPAND_ONLY_PREDEF' docs='
-If the EXPAND_ONLY_PREDEF and MACRO_EXPANSION tags are both set to YES 
-then the macro expansion is limited to the macros specified with the 
-PREDEFINED and EXPAND_AS_DEFINED tags. 
+If the EXPAND_ONLY_PREDEF and MACRO_EXPANSION tags are both set to YES
+then the macro expansion is limited to the macros specified with the
+PREDEFINED and EXPAND_AS_DEFINED tags.
 ' defval='0' depends='ENABLE_PREPROCESSING'/>
     <option type='bool' id='SEARCH_INCLUDES' docs='
-If the SEARCH_INCLUDES tag is set to YES (the default) the includes files 
-in the INCLUDE_PATH (see below) will be search if a #include is found. 
+If the SEARCH_INCLUDES tag is set to YES (the default) the includes files
+in the INCLUDE_PATH (see below) will be search if a #include is found.
 ' defval='1' depends='ENABLE_PREPROCESSING'/>
     <option type='list' id='INCLUDE_PATH' format='dir' docs='
-The INCLUDE_PATH tag can be used to specify one or more directories that 
-contain include files that are not input files but should be processed by 
-the preprocessor. 
+The INCLUDE_PATH tag can be used to specify one or more directories that
+contain include files that are not input files but should be processed by
+the preprocessor.
 ' depends='ENABLE_PREPROCESSING'>
     </option>
     <option type='list' id='INCLUDE_FILE_PATTERNS' format='string' docs='
-You can use the INCLUDE_FILE_PATTERNS tag to specify one or more wildcard 
-patterns (like *.h and *.hpp) to filter out the header-files in the 
-directories. If left blank, the patterns specified with FILE_PATTERNS will 
-be used. 
+You can use the INCLUDE_FILE_PATTERNS tag to specify one or more wildcard
+patterns (like *.h and *.hpp) to filter out the header-files in the
+directories. If left blank, the patterns specified with FILE_PATTERNS will
+be used.
 ' depends='ENABLE_PREPROCESSING'>
     </option>
     <option type='list' id='PREDEFINED' format='string' docs='
-The PREDEFINED tag can be used to specify one or more macro names that 
-are defined before the preprocessor is started (similar to the -D option of 
-gcc). The argument of the tag is a list of macros of the form: name 
-or name=definition (no spaces). If the definition and the = are 
-omitted =1 is assumed. To prevent a macro definition from being 
-undefined via #undef or recursively expanded use the := operator 
-instead of the = operator. 
+The PREDEFINED tag can be used to specify one or more macro names that
+are defined before the preprocessor is started (similar to the -D option of
+gcc). The argument of the tag is a list of macros of the form: name
+or name=definition (no spaces). If the definition and the = are
+omitted =1 is assumed. To prevent a macro definition from being
+undefined via #undef or recursively expanded use the := operator
+instead of the = operator.
 ' depends='ENABLE_PREPROCESSING'>
     </option>
     <option type='list' id='EXPAND_AS_DEFINED' format='string' docs='
-If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then 
-this tag can be used to specify a list of macro names that should be expanded. 
-The macro definition that is found in the sources will be used. 
-Use the PREDEFINED tag if you want to use a different macro definition. 
+If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then
+this tag can be used to specify a list of macro names that should be expanded.
+The macro definition that is found in the sources will be used.
+Use the PREDEFINED tag if you want to use a different macro definition.
 ' depends='ENABLE_PREPROCESSING'>
     </option>
     <option type='bool' id='SKIP_FUNCTION_MACROS' docs='
-If the SKIP_FUNCTION_MACROS tag is set to YES (the default) then 
-doxygen&apos;s preprocessor will remove all function-like macros that are alone 
-on a line, have an all uppercase name, and do not end with a semicolon. Such 
-function macros are typically used for boiler-plate code, and will confuse 
-the parser if not removed. 
+If the SKIP_FUNCTION_MACROS tag is set to YES (the default) then
+doxygen&apos;s preprocessor will remove all function-like macros that are alone
+on a line, have an all uppercase name, and do not end with a semicolon. Such
+function macros are typically used for boiler-plate code, and will confuse
+the parser if not removed.
 ' defval='1' depends='ENABLE_PREPROCESSING'/>
   </group>
   <group name='External' docs='Configuration::additions related to external references   '>
     <option type='list' id='TAGFILES' format='file' docs='
-The TAGFILES option can be used to specify one or more tagfiles. 
-Optionally an initial location of the external documentation 
-can be added for each tagfile. The format of a tag file without 
-this location is as follows: 
-  TAGFILES = file1 file2 ... 
-Adding location for the tag files is done as follows: 
-  TAGFILES = file1=loc1 &quot;file2 = loc2&quot; ... 
-where &quot;loc1&quot; and &quot;loc2&quot; can be relative or absolute paths or 
-URLs. If a location is present for each tag, the installdox tool 
-does not have to be run to correct the links. 
-Note that each tag file must have a unique name 
-(where the name does NOT include the path) 
-If a tag file is not located in the directory in which doxygen 
-is run, you must also specify the path to the tagfile here. 
+The TAGFILES option can be used to specify one or more tagfiles.
+Optionally an initial location of the external documentation
+can be added for each tagfile. The format of a tag file without
+this location is as follows:
+  TAGFILES = file1 file2 ...
+Adding location for the tag files is done as follows:
+  TAGFILES = file1=loc1 &quot;file2 = loc2&quot; ...
+where &quot;loc1&quot; and &quot;loc2&quot; can be relative or absolute paths or
+URLs. If a location is present for each tag, the installdox tool
+does not have to be run to correct the links.
+Note that each tag file must have a unique name
+(where the name does NOT include the path)
+If a tag file is not located in the directory in which doxygen
+is run, you must also specify the path to the tagfile here.
 '>
     </option>
     <option type='string' id='GENERATE_TAGFILE' format='file' docs='
-When a file name is specified after GENERATE_TAGFILE, doxygen will create 
-a tag file that is based on the input files it reads. 
+When a file name is specified after GENERATE_TAGFILE, doxygen will create
+a tag file that is based on the input files it reads.
 ' defval=''/>
     <option type='bool' id='ALLEXTERNALS' docs='
-If the ALLEXTERNALS tag is set to YES all external classes will be listed 
-in the class index. If set to NO only the inherited external classes 
-will be listed. 
+If the ALLEXTERNALS tag is set to YES all external classes will be listed
+in the class index. If set to NO only the inherited external classes
+will be listed.
 ' defval='0'/>
     <option type='bool' id='EXTERNAL_GROUPS' docs='
-If the EXTERNAL_GROUPS tag is set to YES all external groups will be listed 
-in the modules index. If set to NO, only the current project&apos;s groups will 
-be listed. 
+If the EXTERNAL_GROUPS tag is set to YES all external groups will be listed
+in the modules index. If set to NO, only the current project&apos;s groups will
+be listed.
 ' defval='1'/>
     <option type='string' id='PERL_PATH' format='dir' docs='
-The PERL_PATH should be the absolute path and name of the perl script 
-interpreter (i.e. the result of `which perl&apos;). 
+The PERL_PATH should be the absolute path and name of the perl script
+interpreter (i.e. the result of `which perl&apos;).
 ' defval='/usr/bin/perl'/>
   </group>
   <group name='Dot' docs='Configuration options related to the dot tool   '>
     <option type='bool' id='CLASS_DIAGRAMS' docs='
-If the CLASS_DIAGRAMS tag is set to YES (the default) Doxygen will 
-generate a inheritance diagram (in HTML, RTF and LaTeX) for classes with base 
-or super classes. Setting the tag to NO turns the diagrams off. Note that 
-this option is superseded by the HAVE_DOT option below. This is only a 
-fallback. It is recommended to install and use dot, since it yields more 
-powerful graphs. 
+If the CLASS_DIAGRAMS tag is set to YES (the default) Doxygen will
+generate a inheritance diagram (in HTML, RTF and LaTeX) for classes with base
+or super classes. Setting the tag to NO turns the diagrams off. Note that
+this option is superseded by the HAVE_DOT option below. This is only a
+fallback. It is recommended to install and use dot, since it yields more
+powerful graphs.
 ' defval='1'/>
     <option type='string' id='MSCGEN_PATH' format='string' docs='
-You can define message sequence charts within doxygen comments using the \msc 
-command. Doxygen will then run the mscgen tool (see 
-http://www.mcternan.me.uk/mscgen/) to produce the chart and insert it in the 
-documentation. The MSCGEN_PATH tag allows you to specify the directory where 
-the mscgen tool resides. If left empty the tool is assumed to be found in the 
-default search path. 
+You can define message sequence charts within doxygen comments using the \msc
+command. Doxygen will then run the mscgen tool (see
+http://www.mcternan.me.uk/mscgen/) to produce the chart and insert it in the
+documentation. The MSCGEN_PATH tag allows you to specify the directory where
+the mscgen tool resides. If left empty the tool is assumed to be found in the
+default search path.
 ' defval=''/>
     <option type='bool' id='HIDE_UNDOC_RELATIONS' docs='
-If set to YES, the inheritance and collaboration graphs will hide 
-inheritance and usage relations if the target is undocumented 
-or is not a class. 
+If set to YES, the inheritance and collaboration graphs will hide
+inheritance and usage relations if the target is undocumented
+or is not a class.
 ' defval='1'/>
     <option type='bool' id='HAVE_DOT' docs='
-If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is 
-available from the path. This tool is part of Graphviz, a graph visualization 
-toolkit from AT&amp;T and Lucent Bell Labs. The other options in this section 
-have no effect if this option is set to NO (the default) 
+If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is
+available from the path. This tool is part of Graphviz, a graph visualization
+toolkit from AT&amp;T and Lucent Bell Labs. The other options in this section
+have no effect if this option is set to NO (the default)
 ' defval='0'/>
     <option type='string' id='DOT_FONTNAME' format='string' docs='
-By default doxygen will write a font called FreeSans.ttf to the output 
-directory and reference it in all dot files that doxygen generates. This 
-font does not include all possible unicode characters however, so when you need 
-these (or just want a differently looking font) you can specify the font name 
-using DOT_FONTNAME. You need need to make sure dot is able to find the font, 
-which can be done by putting it in a standard location or by setting the 
-DOTFONTPATH environment variable or by setting DOT_FONTPATH to the directory 
-containing the font. 
+By default doxygen will write a font called FreeSans.ttf to the output
+directory and reference it in all dot files that doxygen generates. This
+font does not include all possible unicode characters however, so when you need
+these (or just want a differently looking font) you can specify the font name
+using DOT_FONTNAME. You need need to make sure dot is able to find the font,
+which can be done by putting it in a standard location or by setting the
+DOTFONTPATH environment variable or by setting DOT_FONTPATH to the directory
+containing the font.
 ' defval='FreeSans' depends='HAVE_DOT'/>
     <option type='int' id='DOT_FONTSIZE' docs='
-The DOT_FONTSIZE tag can be used to set the size of the font of dot graphs. 
-The default size is 10pt. 
+The DOT_FONTSIZE tag can be used to set the size of the font of dot graphs.
+The default size is 10pt.
 ' minval='4' maxval='24' defval='10' depends='HAVE_DOT'/>
     <option type='string' id='DOT_FONTPATH' format='string' docs='
-By default doxygen will tell dot to use the output directory to look for the 
-FreeSans.ttf font (which doxygen will put there itself). If you specify a 
-different font using DOT_FONTNAME you can set the path where dot 
-can find it using this tag. 
+By default doxygen will tell dot to use the output directory to look for the
+FreeSans.ttf font (which doxygen will put there itself). If you specify a
+different font using DOT_FONTNAME you can set the path where dot
+can find it using this tag.
 ' defval='' depends='HAVE_DOT'/>
     <option type='bool' id='CLASS_GRAPH' docs='
-If the CLASS_GRAPH and HAVE_DOT tags are set to YES then doxygen 
-will generate a graph for each documented class showing the direct and 
-indirect inheritance relations. Setting this tag to YES will force the 
-the CLASS_DIAGRAMS tag to NO. 
+If the CLASS_GRAPH and HAVE_DOT tags are set to YES then doxygen
+will generate a graph for each documented class showing the direct and
+indirect inheritance relations. Setting this tag to YES will force the
+the CLASS_DIAGRAMS tag to NO.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='COLLABORATION_GRAPH' docs='
-If the COLLABORATION_GRAPH and HAVE_DOT tags are set to YES then doxygen 
-will generate a graph for each documented class showing the direct and 
-indirect implementation dependencies (inheritance, containment, and 
-class references variables) of the class with other documented classes. 
+If the COLLABORATION_GRAPH and HAVE_DOT tags are set to YES then doxygen
+will generate a graph for each documented class showing the direct and
+indirect implementation dependencies (inheritance, containment, and
+class references variables) of the class with other documented classes.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='GROUP_GRAPHS' docs='
-If the GROUP_GRAPHS and HAVE_DOT tags are set to YES then doxygen 
-will generate a graph for groups, showing the direct groups dependencies 
+If the GROUP_GRAPHS and HAVE_DOT tags are set to YES then doxygen
+will generate a graph for groups, showing the direct groups dependencies
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='UML_LOOK' docs='
-If the UML_LOOK tag is set to YES doxygen will generate inheritance and 
-collaboration diagrams in a style similar to the OMG&apos;s Unified Modeling 
-Language. 
+If the UML_LOOK tag is set to YES doxygen will generate inheritance and
+collaboration diagrams in a style similar to the OMG&apos;s Unified Modeling
+Language.
 ' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='TEMPLATE_RELATIONS' docs='
-If set to YES, the inheritance and collaboration graphs will show the 
-relations between templates and their instances. 
+If set to YES, the inheritance and collaboration graphs will show the
+relations between templates and their instances.
 ' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='INCLUDE_GRAPH' docs='
-If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDE_GRAPH, and HAVE_DOT 
-tags are set to YES then doxygen will generate a graph for each documented 
-file showing the direct and indirect include dependencies of the file with 
-other documented files. 
+If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDE_GRAPH, and HAVE_DOT
+tags are set to YES then doxygen will generate a graph for each documented
+file showing the direct and indirect include dependencies of the file with
+other documented files.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='INCLUDED_BY_GRAPH' docs='
-If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDED_BY_GRAPH, and 
-HAVE_DOT tags are set to YES then doxygen will generate a graph for each 
-documented header file showing the documented files that directly or 
-indirectly include this file. 
+If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDED_BY_GRAPH, and
+HAVE_DOT tags are set to YES then doxygen will generate a graph for each
+documented header file showing the documented files that directly or
+indirectly include this file.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='CALL_GRAPH' docs='
-If the CALL_GRAPH and HAVE_DOT options are set to YES then 
-doxygen will generate a call dependency graph for every global function 
-or class method. Note that enabling this option will significantly increase 
-the time of a run. So in most cases it will be better to enable call graphs 
-for selected functions only using the \callgraph command. 
+If the CALL_GRAPH and HAVE_DOT options are set to YES then
+doxygen will generate a call dependency graph for every global function
+or class method. Note that enabling this option will significantly increase
+the time of a run. So in most cases it will be better to enable call graphs
+for selected functions only using the \callgraph command.
 ' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='CALLER_GRAPH' docs='
-If the CALLER_GRAPH and HAVE_DOT tags are set to YES then 
-doxygen will generate a caller dependency graph for every global function 
-or class method. Note that enabling this option will significantly increase 
-the time of a run. So in most cases it will be better to enable caller 
-graphs for selected functions only using the \callergraph command. 
+If the CALLER_GRAPH and HAVE_DOT tags are set to YES then
+doxygen will generate a caller dependency graph for every global function
+or class method. Note that enabling this option will significantly increase
+the time of a run. So in most cases it will be better to enable caller
+graphs for selected functions only using the \callergraph command.
 ' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='GRAPHICAL_HIERARCHY' docs='
-If the GRAPHICAL_HIERARCHY and HAVE_DOT tags are set to YES then doxygen 
-will graphical hierarchy of all classes instead of a textual one. 
+If the GRAPHICAL_HIERARCHY and HAVE_DOT tags are set to YES then doxygen
+will graphical hierarchy of all classes instead of a textual one.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='DIRECTORY_GRAPH' docs='
-If the DIRECTORY_GRAPH, SHOW_DIRECTORIES and HAVE_DOT tags are set to YES 
-then doxygen will show the dependencies a directory has on other directories 
-in a graphical way. The dependency relations are determined by the #include 
-relations between the files in the directories. 
+If the DIRECTORY_GRAPH, SHOW_DIRECTORIES and HAVE_DOT tags are set to YES
+then doxygen will show the dependencies a directory has on other directories
+in a graphical way. The dependency relations are determined by the #include
+relations between the files in the directories.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='enum' id='DOT_IMAGE_FORMAT' defval='png' docs='
-The DOT_IMAGE_FORMAT tag can be used to set the image format of the images 
-generated by dot. Possible values are png, jpg, or gif 
-If left blank png will be used. 
+The DOT_IMAGE_FORMAT tag can be used to set the image format of the images
+generated by dot. Possible values are png, jpg, or gif
+If left blank png will be used.
 ' depends='HAVE_DOT'>
       <value name='png'/>
       <value name='jpg'/>
       <value name='gif'/>
     </option>
     <option type='string' id='DOT_PATH' format='dir' docs='
-The tag DOT_PATH can be used to specify the path where the dot tool can be 
-found. If left blank, it is assumed the dot tool can be found in the path. 
+The tag DOT_PATH can be used to specify the path where the dot tool can be
+found. If left blank, it is assumed the dot tool can be found in the path.
 ' defval='' depends='HAVE_DOT'/>
     <option type='list' id='DOTFILE_DIRS' format='dir' docs='
-The DOTFILE_DIRS tag can be used to specify one or more directories that 
-contain dot files that are included in the documentation (see the 
-\dotfile command). 
+The DOTFILE_DIRS tag can be used to specify one or more directories that
+contain dot files that are included in the documentation (see the
+\dotfile command).
 ' depends='HAVE_DOT'>
     </option>
     <option type='int' id='DOT_GRAPH_MAX_NODES' docs='
-The DOT_GRAPH_MAX_NODES tag can be used to set the maximum number of 
-nodes that will be shown in the graph. If the number of nodes in a graph 
-becomes larger than this value, doxygen will truncate the graph, which is 
-visualized by representing a node as a red box. Note that doxygen if the 
-number of direct children of the root node in a graph is already larger than 
-DOT_GRAPH_MAX_NODES then the graph will not be shown at all. Also note 
-that the size of a graph can be further restricted by MAX_DOT_GRAPH_DEPTH. 
+The DOT_GRAPH_MAX_NODES tag can be used to set the maximum number of
+nodes that will be shown in the graph. If the number of nodes in a graph
+becomes larger than this value, doxygen will truncate the graph, which is
+visualized by representing a node as a red box. Note that doxygen if the
+number of direct children of the root node in a graph is already larger than
+DOT_GRAPH_MAX_NODES then the graph will not be shown at all. Also note
+that the size of a graph can be further restricted by MAX_DOT_GRAPH_DEPTH.
 ' minval='0' maxval='10000' defval='50' depends='HAVE_DOT'/>
     <option type='int' id='MAX_DOT_GRAPH_DEPTH' docs='
-The MAX_DOT_GRAPH_DEPTH tag can be used to set the maximum depth of the 
-graphs generated by dot. A depth value of 3 means that only nodes reachable 
-from the root by following a path via at most 3 edges will be shown. Nodes 
-that lay further from the root node will be omitted. Note that setting this 
-option to 1 or 2 may greatly reduce the computation time needed for large 
-code bases. Also note that the size of a graph can be further restricted by 
-DOT_GRAPH_MAX_NODES. Using a depth of 0 means no depth restriction. 
+The MAX_DOT_GRAPH_DEPTH tag can be used to set the maximum depth of the
+graphs generated by dot. A depth value of 3 means that only nodes reachable
+from the root by following a path via at most 3 edges will be shown. Nodes
+that lay further from the root node will be omitted. Note that setting this
+option to 1 or 2 may greatly reduce the computation time needed for large
+code bases. Also note that the size of a graph can be further restricted by
+DOT_GRAPH_MAX_NODES. Using a depth of 0 means no depth restriction.
 ' minval='0' maxval='1000' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='DOT_TRANSPARENT' docs='
-Set the DOT_TRANSPARENT tag to YES to generate images with a transparent 
-background. This is disabled by default, because dot on Windows does not 
-seem to support this out of the box. Warning: Depending on the platform used, 
-enabling this option may lead to badly anti-aliased labels on the edges of 
-a graph (i.e. they become hard to read). 
+Set the DOT_TRANSPARENT tag to YES to generate images with a transparent
+background. This is disabled by default, because dot on Windows does not
+seem to support this out of the box. Warning: Depending on the platform used,
+enabling this option may lead to badly anti-aliased labels on the edges of
+a graph (i.e. they become hard to read).
 ' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='DOT_MULTI_TARGETS' docs='
-Set the DOT_MULTI_TARGETS tag to YES allow dot to generate multiple output 
-files in one run (i.e. multiple -o and -T options on the command line). This 
-makes dot run faster, but since only newer versions of dot (&gt;1.8.10) 
-support this, this feature is disabled by default. 
+Set the DOT_MULTI_TARGETS tag to YES allow dot to generate multiple output
+files in one run (i.e. multiple -o and -T options on the command line). This
+makes dot run faster, but since only newer versions of dot (&gt;1.8.10)
+support this, this feature is disabled by default.
 ' defval='0' depends='HAVE_DOT'/>
     <option type='bool' id='GENERATE_LEGEND' docs='
-If the GENERATE_LEGEND tag is set to YES (the default) Doxygen will 
-generate a legend page explaining the meaning of the various boxes and 
-arrows in the dot generated graphs. 
+If the GENERATE_LEGEND tag is set to YES (the default) Doxygen will
+generate a legend page explaining the meaning of the various boxes and
+arrows in the dot generated graphs.
 ' defval='1' depends='HAVE_DOT'/>
     <option type='bool' id='DOT_CLEANUP' docs='
-If the DOT_CLEANUP tag is set to YES (the default) Doxygen will 
-remove the intermediate dot files that are used to generate 
-the various graphs. 
+If the DOT_CLEANUP tag is set to YES (the default) Doxygen will
+remove the intermediate dot files that are used to generate
+the various graphs.
 ' defval='1' depends='HAVE_DOT'/>
   </group>
   <group name='Search' docs='Options related to the search engine'>
     <option type='bool' id='SEARCHENGINE' docs='
-The SEARCHENGINE tag specifies whether or not a search engine should be 
-used. If set to NO the values of all tags below this one will be ignored. 
+The SEARCHENGINE tag specifies whether or not a search engine should be
+used. If set to NO the values of all tags below this one will be ignored.
 ' defval='0'/>
     <option type='obsolete' id='SHOW_USED_FILES'/>
     <option type='obsolete' id='USE_WINDOWS_ENCODING'/>
diff --git a/src/configoptions.cpp b/src/configoptions.cpp
index f95b834..cb10082 100644
--- a/src/configoptions.cpp
+++ b/src/configoptions.cpp
@@ -22,58 +22,58 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "DOXYFILE_ENCODING",
-                 "This tag specifies the encoding used for all characters in the config file \n"
-                 "that follow. The default is UTF-8 which is also the encoding used for all \n"
-                 "text before the first occurrence of this tag. Doxygen uses libiconv (or the \n"
-                 "iconv built into libc) for the transcoding. See \n"
+                 "This tag specifies the encoding used for all characters in the config file\n"
+                 "that follow. The default is UTF-8 which is also the encoding used for all\n"
+                 "text before the first occurrence of this tag. Doxygen uses libiconv (or the\n"
+                 "iconv built into libc) for the transcoding. See\n"
                  "http://www.gnu.org/software/libiconv for the list of possible encodings."
                 );
   cs->setDefaultValue("UTF-8");
   //----
   cs = cfg->addString(
                  "PROJECT_NAME",
-                 "The PROJECT_NAME tag is a single word (or a sequence of words surrounded \n"
+                 "The PROJECT_NAME tag is a single word (or a sequence of words surrounded\n"
                  "by quotes) that should identify the project."
                 );
   //----
   cs = cfg->addString(
                  "PROJECT_NUMBER",
-                 "The PROJECT_NUMBER tag can be used to enter a project or revision number. \n"
-                 "This could be handy for archiving the generated documentation or \n"
+                 "The PROJECT_NUMBER tag can be used to enter a project or revision number.\n"
+                 "This could be handy for archiving the generated documentation or\n"
                  "if some version control system is used."
                 );
   //----
   cs = cfg->addString(
                  "OUTPUT_DIRECTORY",
-                 "The OUTPUT_DIRECTORY tag is used to specify the (relative or absolute) \n"
-                 "base path where the generated documentation will be put. \n"
-                 "If a relative path is entered, it will be relative to the location \n"
+                 "The OUTPUT_DIRECTORY tag is used to specify the (relative or absolute)\n"
+                 "base path where the generated documentation will be put.\n"
+                 "If a relative path is entered, it will be relative to the location\n"
                  "where doxygen was started. If left blank the current directory will be used."
                 );
   cs->setWidgetType(ConfigString::Dir);
   //----
   cb = cfg->addBool(
                  "CREATE_SUBDIRS",
-                 "If the CREATE_SUBDIRS tag is set to YES, then doxygen will create \n"
-                 "4096 sub-directories (in 2 levels) under the output directory of each output \n"
-                 "format and will distribute the generated files over these directories. \n"
-                 "Enabling this option can be useful when feeding doxygen a huge amount of \n"
-                 "source files, where putting all generated files in the same directory would \n"
+                 "If the CREATE_SUBDIRS tag is set to YES, then doxygen will create\n"
+                 "4096 sub-directories (in 2 levels) under the output directory of each output\n"
+                 "format and will distribute the generated files over these directories.\n"
+                 "Enabling this option can be useful when feeding doxygen a huge amount of\n"
+                 "source files, where putting all generated files in the same directory would\n"
                  "otherwise cause performance problems for the file system.",
                  FALSE
                 );
   //----
   ce = cfg->addEnum(
                  "OUTPUT_LANGUAGE",
-                 "The OUTPUT_LANGUAGE tag is used to specify the language in which all \n"
-                 "documentation generated by doxygen is written. Doxygen will use this \n"
-                 "information to generate all constant output in the proper language. \n"
-                 "The default language is English, other supported languages are: \n"
-                 "Afrikaans, Arabic, Brazilian, Catalan, Chinese, Chinese-Traditional, \n"
-                 "Croatian, Czech, Danish, Dutch, Esperanto, Farsi, Finnish, French, German, \n"
-                 "Greek, Hungarian, Italian, Japanese, Japanese-en (Japanese with English \n"
-                 "messages), Korean, Korean-en, Lithuanian, Norwegian, Macedonian, Persian, \n"
-                 "Polish, Portuguese, Romanian, Russian, Serbian, Serbian-Cyrilic, Slovak, \n"
+                 "The OUTPUT_LANGUAGE tag is used to specify the language in which all\n"
+                 "documentation generated by doxygen is written. Doxygen will use this\n"
+                 "information to generate all constant output in the proper language.\n"
+                 "The default language is English, other supported languages are:\n"
+                 "Afrikaans, Arabic, Brazilian, Catalan, Chinese, Chinese-Traditional,\n"
+                 "Croatian, Czech, Danish, Dutch, Esperanto, Farsi, Finnish, French, German,\n"
+                 "Greek, Hungarian, Italian, Japanese, Japanese-en (Japanese with English\n"
+                 "messages), Korean, Korean-en, Lithuanian, Norwegian, Macedonian, Persian,\n"
+                 "Polish, Portuguese, Romanian, Russian, Serbian, Serbian-Cyrilic, Slovak,\n"
                  "Slovene, Spanish, Swedish, Ukrainian, and Vietnamese.",
                  "English"
                 );
@@ -118,32 +118,32 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "BRIEF_MEMBER_DESC",
-                 "If the BRIEF_MEMBER_DESC tag is set to YES (the default) Doxygen will \n"
-                 "include brief member descriptions after the members that are listed in \n"
-                 "the file and class documentation (similar to JavaDoc). \n"
+                 "If the BRIEF_MEMBER_DESC tag is set to YES (the default) Doxygen will\n"
+                 "include brief member descriptions after the members that are listed in\n"
+                 "the file and class documentation (similar to JavaDoc).\n"
                  "Set to NO to disable this.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "REPEAT_BRIEF",
-                 "If the REPEAT_BRIEF tag is set to YES (the default) Doxygen will prepend \n"
-                 "the brief description of a member or function before the detailed description. \n"
-                 "Note: if both HIDE_UNDOC_MEMBERS and BRIEF_MEMBER_DESC are set to NO, the \n"
+                 "If the REPEAT_BRIEF tag is set to YES (the default) Doxygen will prepend\n"
+                 "the brief description of a member or function before the detailed description.\n"
+                 "Note: if both HIDE_UNDOC_MEMBERS and BRIEF_MEMBER_DESC are set to NO, the\n"
                  "brief descriptions will be completely suppressed.",
                  TRUE
                 );
   //----
   cl = cfg->addList(
                  "ABBREVIATE_BRIEF",
-                 "This tag implements a quasi-intelligent brief description abbreviator \n"
-                 "that is used to form the text in various listings. Each string \n"
-                 "in this list, if found as the leading text of the brief description, will be \n"
-                 "stripped from the text and the result after processing the whole list, is \n"
-                 "used as the annotated text. Otherwise, the brief description is used as-is. \n"
-                 "If left blank, the following values are used (\"$name\" is automatically \n"
-                 "replaced with the name of the entity): \"The $name class\" \"The $name widget\" \n"
-                 "\"The $name file\" \"is\" \"provides\" \"specifies\" \"contains\" \n"
+                 "This tag implements a quasi-intelligent brief description abbreviator\n"
+                 "that is used to form the text in various listings. Each string\n"
+                 "in this list, if found as the leading text of the brief description, will be\n"
+                 "stripped from the text and the result after processing the whole list, is\n"
+                 "used as the annotated text. Otherwise, the brief description is used as-is.\n"
+                 "If left blank, the following values are used (\"$name\" is automatically\n"
+                 "replaced with the name of the entity): \"The $name class\" \"The $name widget\"\n"
+                 "\"The $name file\" \"is\" \"provides\" \"specifies\" \"contains\"\n"
                  "\"represents\" \"a\" \"an\" \"the\""
                 );
   cl->addValue("The $name class");
@@ -160,36 +160,36 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "ALWAYS_DETAILED_SEC",
-                 "If the ALWAYS_DETAILED_SEC and REPEAT_BRIEF tags are both set to YES then \n"
-                 "Doxygen will generate a detailed section even if there is only a brief \n"
+                 "If the ALWAYS_DETAILED_SEC and REPEAT_BRIEF tags are both set to YES then\n"
+                 "Doxygen will generate a detailed section even if there is only a brief\n"
                  "description.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "INLINE_INHERITED_MEMB",
-                 "If the INLINE_INHERITED_MEMB tag is set to YES, doxygen will show all \n"
-                 "inherited members of a class in the documentation of that class as if those \n"
-                 "members were ordinary class members. Constructors, destructors and assignment \n"
+                 "If the INLINE_INHERITED_MEMB tag is set to YES, doxygen will show all\n"
+                 "inherited members of a class in the documentation of that class as if those\n"
+                 "members were ordinary class members. Constructors, destructors and assignment\n"
                  "operators of the base classes will not be shown.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "FULL_PATH_NAMES",
-                 "If the FULL_PATH_NAMES tag is set to YES then Doxygen will prepend the full \n"
-                 "path before files name in the file list and in the header files. If set \n"
+                 "If the FULL_PATH_NAMES tag is set to YES then Doxygen will prepend the full\n"
+                 "path before files name in the file list and in the header files. If set\n"
                  "to NO the shortest path that makes the file name unique will be used.",
                  TRUE
                 );
   //----
   cl = cfg->addList(
                  "STRIP_FROM_PATH",
-                 "If the FULL_PATH_NAMES tag is set to YES then the STRIP_FROM_PATH tag \n"
-                 "can be used to strip a user-defined part of the path. Stripping is \n"
-                 "only done if one of the specified strings matches the left-hand part of \n"
-                 "the path. The tag can be used to show relative paths in the file list. \n"
-                 "If left blank the directory from which doxygen is run is used as the \n"
+                 "If the FULL_PATH_NAMES tag is set to YES then the STRIP_FROM_PATH tag\n"
+                 "can be used to strip a user-defined part of the path. Stripping is\n"
+                 "only done if one of the specified strings matches the left-hand part of\n"
+                 "the path. The tag can be used to show relative paths in the file list.\n"
+                 "If left blank the directory from which doxygen is run is used as the\n"
                  "path to strip."
                 );
   cl->addValue("/Users/dimitri/doxygen/mail/1.5.7/doxywizard/");
@@ -197,213 +197,213 @@ void addConfigOptions(Config *cfg)
   //----
   cl = cfg->addList(
                  "STRIP_FROM_INC_PATH",
-                 "The STRIP_FROM_INC_PATH tag can be used to strip a user-defined part of \n"
-                 "the path mentioned in the documentation of a class, which tells \n"
-                 "the reader which header file to include in order to use a class. \n"
-                 "If left blank only the name of the header file containing the class \n"
-                 "definition is used. Otherwise one should specify the include paths that \n"
+                 "The STRIP_FROM_INC_PATH tag can be used to strip a user-defined part of\n"
+                 "the path mentioned in the documentation of a class, which tells\n"
+                 "the reader which header file to include in order to use a class.\n"
+                 "If left blank only the name of the header file containing the class\n"
+                 "definition is used. Otherwise one should specify the include paths that\n"
                  "are normally passed to the compiler using the -I flag."
                 );
   //----
   cb = cfg->addBool(
                  "SHORT_NAMES",
-                 "If the SHORT_NAMES tag is set to YES, doxygen will generate much shorter \n"
-                 "(but less readable) file names. This can be useful is your file systems \n"
+                 "If the SHORT_NAMES tag is set to YES, doxygen will generate much shorter\n"
+                 "(but less readable) file names. This can be useful is your file systems\n"
                  "doesn't support long names like on DOS, Mac, or CD-ROM.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "JAVADOC_AUTOBRIEF",
-                 "If the JAVADOC_AUTOBRIEF tag is set to YES then Doxygen \n"
-                 "will interpret the first line (until the first dot) of a JavaDoc-style \n"
-                 "comment as the brief description. If set to NO, the JavaDoc \n"
-                 "comments will behave just like regular Qt-style comments \n"
+                 "If the JAVADOC_AUTOBRIEF tag is set to YES then Doxygen\n"
+                 "will interpret the first line (until the first dot) of a JavaDoc-style\n"
+                 "comment as the brief description. If set to NO, the JavaDoc\n"
+                 "comments will behave just like regular Qt-style comments\n"
                  "(thus requiring an explicit @brief command for a brief description.)",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "QT_AUTOBRIEF",
-                 "If the QT_AUTOBRIEF tag is set to YES then Doxygen will \n"
-                 "interpret the first line (until the first dot) of a Qt-style \n"
-                 "comment as the brief description. If set to NO, the comments \n"
-                 "will behave just like regular Qt-style comments (thus requiring \n"
+                 "If the QT_AUTOBRIEF tag is set to YES then Doxygen will\n"
+                 "interpret the first line (until the first dot) of a Qt-style\n"
+                 "comment as the brief description. If set to NO, the comments\n"
+                 "will behave just like regular Qt-style comments (thus requiring\n"
                  "an explicit \\brief command for a brief description.)",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "MULTILINE_CPP_IS_BRIEF",
-                 "The MULTILINE_CPP_IS_BRIEF tag can be set to YES to make Doxygen \n"
-                 "treat a multi-line C++ special comment block (i.e. a block of //! or /// \n"
-                 "comments) as a brief description. This used to be the default behaviour. \n"
-                 "The new default is to treat a multi-line C++ comment block as a detailed \n"
+                 "The MULTILINE_CPP_IS_BRIEF tag can be set to YES to make Doxygen\n"
+                 "treat a multi-line C++ special comment block (i.e. a block of //! or ///\n"
+                 "comments) as a brief description. This used to be the default behaviour.\n"
+                 "The new default is to treat a multi-line C++ comment block as a detailed\n"
                  "description. Set this tag to YES if you prefer the old behaviour instead.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "INHERIT_DOCS",
-                 "If the INHERIT_DOCS tag is set to YES (the default) then an undocumented \n"
-                 "member inherits the documentation from any documented member that it \n"
+                 "If the INHERIT_DOCS tag is set to YES (the default) then an undocumented\n"
+                 "member inherits the documentation from any documented member that it\n"
                  "re-implements.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "SEPARATE_MEMBER_PAGES",
-                 "If the SEPARATE_MEMBER_PAGES tag is set to YES, then doxygen will produce \n"
-                 "a new page for each member. If set to NO, the documentation of a member will \n"
+                 "If the SEPARATE_MEMBER_PAGES tag is set to YES, then doxygen will produce\n"
+                 "a new page for each member. If set to NO, the documentation of a member will\n"
                  "be part of the file/class/namespace that contains it.",
                  FALSE
                 );
   //----
   ci = cfg->addInt(
                  "TAB_SIZE",
-                 "The TAB_SIZE tag can be used to set the number of spaces in a tab. \n"
+                 "The TAB_SIZE tag can be used to set the number of spaces in a tab.\n"
                  "Doxygen uses this value to replace tabs by spaces in code fragments.",
                  1,16,8
                 );
   //----
   cl = cfg->addList(
                  "ALIASES",
-                 "This tag can be used to specify a number of aliases that acts \n"
-                 "as commands in the documentation. An alias has the form \"name=value\". \n"
-                 "For example adding \"sideeffect=\\par Side Effects:\\n\" will allow you to \n"
-                 "put the command \\sideeffect (or @sideeffect) in the documentation, which \n"
-                 "will result in a user-defined paragraph with heading \"Side Effects:\". \n"
+                 "This tag can be used to specify a number of aliases that acts\n"
+                 "as commands in the documentation. An alias has the form \"name=value\".\n"
+                 "For example adding \"sideeffect=\\par Side Effects:\\n\" will allow you to\n"
+                 "put the command \\sideeffect (or @sideeffect) in the documentation, which\n"
+                 "will result in a user-defined paragraph with heading \"Side Effects:\".\n"
                  "You can put \\n's in the value part of an alias to insert newlines."
                 );
   //----
   cb = cfg->addBool(
                  "OPTIMIZE_OUTPUT_FOR_C",
-                 "Set the OPTIMIZE_OUTPUT_FOR_C tag to YES if your project consists of C \n"
-                 "sources only. Doxygen will then generate output that is more tailored for C. \n"
-                 "For instance, some of the names that are used will be different. The list \n"
+                 "Set the OPTIMIZE_OUTPUT_FOR_C tag to YES if your project consists of C\n"
+                 "sources only. Doxygen will then generate output that is more tailored for C.\n"
+                 "For instance, some of the names that are used will be different. The list\n"
                  "of all members will be omitted, etc.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "OPTIMIZE_OUTPUT_JAVA",
-                 "Set the OPTIMIZE_OUTPUT_JAVA tag to YES if your project consists of Java \n"
-                 "sources only. Doxygen will then generate output that is more tailored for \n"
-                 "Java. For instance, namespaces will be presented as packages, qualified \n"
+                 "Set the OPTIMIZE_OUTPUT_JAVA tag to YES if your project consists of Java\n"
+                 "sources only. Doxygen will then generate output that is more tailored for\n"
+                 "Java. For instance, namespaces will be presented as packages, qualified\n"
                  "scopes will look different, etc.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "OPTIMIZE_FOR_FORTRAN",
-                 "Set the OPTIMIZE_FOR_FORTRAN tag to YES if your project consists of Fortran \n"
-                 "sources only. Doxygen will then generate output that is more tailored for \n"
+                 "Set the OPTIMIZE_FOR_FORTRAN tag to YES if your project consists of Fortran\n"
+                 "sources only. Doxygen will then generate output that is more tailored for\n"
                  "Fortran.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "OPTIMIZE_OUTPUT_VHDL",
-                 "Set the OPTIMIZE_OUTPUT_VHDL tag to YES if your project consists of VHDL \n"
-                 "sources. Doxygen will then generate output that is tailored for \n"
+                 "Set the OPTIMIZE_OUTPUT_VHDL tag to YES if your project consists of VHDL\n"
+                 "sources. Doxygen will then generate output that is tailored for\n"
                  "VHDL.",
                  FALSE
                 );
   //----
   cl = cfg->addList(
                  "EXTENSION_MAPPING",
-                 "Doxygen selects the parser to use depending on the extension of the files it parses. \n"
-                 "With this tag you can assign which parser to use for a given extension. \n"
-                 "Doxygen has a built-in mapping, but you can override or extend it using this tag. \n"
-                 "The format is ext=language, where ext is a file extension, and language is one of \n"
-                 "the parsers supported by doxygen: IDL, Java, Javascript, C#, C, C++, D, PHP, \n"
-                 "Objective-C, Python, Fortran, VHDL, C, C++. For instance to make doxygen treat \n"
-                 ".inc files as Fortran files (default is PHP), and .f files as C (default is Fortran), \n"
+                 "Doxygen selects the parser to use depending on the extension of the files it parses.\n"
+                 "With this tag you can assign which parser to use for a given extension.\n"
+                 "Doxygen has a built-in mapping, but you can override or extend it using this tag.\n"
+                 "The format is ext=language, where ext is a file extension, and language is one of\n"
+                 "the parsers supported by doxygen: IDL, Java, Javascript, C#, C, C++, D, PHP,\n"
+                 "Objective-C, Python, Fortran, VHDL, C, C++. For instance to make doxygen treat\n"
+                 ".inc files as Fortran files (default is PHP), and .f files as C (default is Fortran),\n"
                  "use: inc=Fortran f=C. Note that for custom extensions you also need to set FILE_PATTERNS otherwise the files are not read by doxygen."
                 );
   //----
   cb = cfg->addBool(
                  "BUILTIN_STL_SUPPORT",
-                 "If you use STL classes (i.e. std::string, std::vector, etc.) but do not want \n"
-                 "to include (a tag file for) the STL sources as input, then you should \n"
-                 "set this tag to YES in order to let doxygen match functions declarations and \n"
-                 "definitions whose arguments contain STL classes (e.g. func(std::string); v.s. \n"
-                 "func(std::string) {}). This also make the inheritance and collaboration \n"
+                 "If you use STL classes (i.e. std::string, std::vector, etc.) but do not want\n"
+                 "to include (a tag file for) the STL sources as input, then you should\n"
+                 "set this tag to YES in order to let doxygen match functions declarations and\n"
+                 "definitions whose arguments contain STL classes (e.g. func(std::string); v.s.\n"
+                 "func(std::string) {}). This also make the inheritance and collaboration\n"
                  "diagrams that involve STL classes more complete and accurate.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "CPP_CLI_SUPPORT",
-                 "If you use Microsoft's C++/CLI language, you should set this option to YES to \n"
+                 "If you use Microsoft's C++/CLI language, you should set this option to YES to\n"
                  "enable parsing support.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "SIP_SUPPORT",
-                 "Set the SIP_SUPPORT tag to YES if your project consists of sip sources only. \n"
-                 "Doxygen will parse them like normal C++ but will assume all classes use public \n"
+                 "Set the SIP_SUPPORT tag to YES if your project consists of sip sources only.\n"
+                 "Doxygen will parse them like normal C++ but will assume all classes use public\n"
                  "instead of private inheritance when no explicit protection keyword is present.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "IDL_PROPERTY_SUPPORT",
-                 "For Microsoft's IDL there are propget and propput attributes to indicate getter \n"
-                 "and setter methods for a property. Setting this option to YES (the default) \n"
-                 "will make doxygen to replace the get and set methods by a property in the \n"
-                 "documentation. This will only work if the methods are indeed getting or \n"
-                 "setting a simple type. If this is not the case, or you want to show the \n"
+                 "For Microsoft's IDL there are propget and propput attributes to indicate getter\n"
+                 "and setter methods for a property. Setting this option to YES (the default)\n"
+                 "will make doxygen to replace the get and set methods by a property in the\n"
+                 "documentation. This will only work if the methods are indeed getting or\n"
+                 "setting a simple type. If this is not the case, or you want to show the\n"
                  "methods anyway, you should set this option to NO.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "DISTRIBUTE_GROUP_DOC",
-                 "If member grouping is used in the documentation and the DISTRIBUTE_GROUP_DOC \n"
-                 "tag is set to YES, then doxygen will reuse the documentation of the first \n"
-                 "member in the group (if any) for the other members of the group. By default \n"
+                 "If member grouping is used in the documentation and the DISTRIBUTE_GROUP_DOC\n"
+                 "tag is set to YES, then doxygen will reuse the documentation of the first\n"
+                 "member in the group (if any) for the other members of the group. By default\n"
                  "all members of a group must be documented explicitly.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "SUBGROUPING",
-                 "Set the SUBGROUPING tag to YES (the default) to allow class member groups of \n"
-                 "the same type (for instance a group of public functions) to be put as a \n"
-                 "subgroup of that type (e.g. under the Public Functions section). Set it to \n"
-                 "NO to prevent subgrouping. Alternatively, this can be done per class using \n"
+                 "Set the SUBGROUPING tag to YES (the default) to allow class member groups of\n"
+                 "the same type (for instance a group of public functions) to be put as a\n"
+                 "subgroup of that type (e.g. under the Public Functions section). Set it to\n"
+                 "NO to prevent subgrouping. Alternatively, this can be done per class using\n"
                  "the \\nosubgrouping command.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "TYPEDEF_HIDES_STRUCT",
-                 "When TYPEDEF_HIDES_STRUCT is enabled, a typedef of a struct, union, or enum \n"
-                 "is documented as struct, union, or enum with the name of the typedef. So \n"
-                 "typedef struct TypeS {} TypeT, will appear in the documentation as a struct \n"
-                 "with name TypeT. When disabled the typedef will appear as a member of a file, \n"
-                 "namespace, or class. And the struct will be named TypeS. This can typically \n"
-                 "be useful for C code in case the coding convention dictates that all compound \n"
+                 "When TYPEDEF_HIDES_STRUCT is enabled, a typedef of a struct, union, or enum\n"
+                 "is documented as struct, union, or enum with the name of the typedef. So\n"
+                 "typedef struct TypeS {} TypeT, will appear in the documentation as a struct\n"
+                 "with name TypeT. When disabled the typedef will appear as a member of a file,\n"
+                 "namespace, or class. And the struct will be named TypeS. This can typically\n"
+                 "be useful for C code in case the coding convention dictates that all compound\n"
                  "types are typedef'ed and only the typedef is referenced, never the tag name.",
                  FALSE
                 );
   //----
   ci = cfg->addInt(
                  "SYMBOL_CACHE_SIZE",
-                 "The SYMBOL_CACHE_SIZE determines the size of the internal cache use to \n"
-                 "determine which symbols to keep in memory and which to flush to disk. \n"
-                 "When the cache is full, less often used symbols will be written to disk. \n"
-                 "For small to medium size projects (<1000 input files) the default value is \n"
-                 "probably good enough. For larger projects a too small cache size can cause \n"
-                 "doxygen to be busy swapping symbols to and from disk most of the time \n"
-                 "causing a significant performance penality. \n"
-                 "If the system has enough physical memory increasing the cache will improve the \n"
-                 "performance by keeping more symbols in memory. Note that the value works on \n"
-                 "a logarithmic scale so increasing the size by one will rougly double the \n"
-                 "memory usage. The cache size is given by this formula: \n"
-                 "2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0, \n"
+                 "The SYMBOL_CACHE_SIZE determines the size of the internal cache use to\n"
+                 "determine which symbols to keep in memory and which to flush to disk.\n"
+                 "When the cache is full, less often used symbols will be written to disk.\n"
+                 "For small to medium size projects (<1000 input files) the default value is\n"
+                 "probably good enough. For larger projects a too small cache size can cause\n"
+                 "doxygen to be busy swapping symbols to and from disk most of the time\n"
+                 "causing a significant performance penality.\n"
+                 "If the system has enough physical memory increasing the cache will improve the\n"
+                 "performance by keeping more symbols in memory. Note that the value works on\n"
+                 "a logarithmic scale so increasing the size by one will rougly double the\n"
+                 "memory usage. The cache size is given by this formula:\n"
+                 "2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0,\n"
                  "corresponding to a cache size of 2^16 = 65536 symbols",
                  0,9,0
                 );
@@ -414,273 +414,273 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "EXTRACT_ALL",
-                 "If the EXTRACT_ALL tag is set to YES doxygen will assume all entities in \n"
-                 "documentation are documented, even if no documentation was available. \n"
-                 "Private class members and static file members will be hidden unless \n"
+                 "If the EXTRACT_ALL tag is set to YES doxygen will assume all entities in\n"
+                 "documentation are documented, even if no documentation was available.\n"
+                 "Private class members and static file members will be hidden unless\n"
                  "the EXTRACT_PRIVATE and EXTRACT_STATIC tags are set to YES",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "EXTRACT_PRIVATE",
-                 "If the EXTRACT_PRIVATE tag is set to YES all private members of a class \n"
+                 "If the EXTRACT_PRIVATE tag is set to YES all private members of a class\n"
                  "will be included in the documentation.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "EXTRACT_STATIC",
-                 "If the EXTRACT_STATIC tag is set to YES all static members of a file \n"
+                 "If the EXTRACT_STATIC tag is set to YES all static members of a file\n"
                  "will be included in the documentation.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "EXTRACT_LOCAL_CLASSES",
-                 "If the EXTRACT_LOCAL_CLASSES tag is set to YES classes (and structs) \n"
-                 "defined locally in source files will be included in the documentation. \n"
+                 "If the EXTRACT_LOCAL_CLASSES tag is set to YES classes (and structs)\n"
+                 "defined locally in source files will be included in the documentation.\n"
                  "If set to NO only classes defined in header files are included.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "EXTRACT_LOCAL_METHODS",
-                 "This flag is only useful for Objective-C code. When set to YES local \n"
-                 "methods, which are defined in the implementation section but not in \n"
-                 "the interface are included in the documentation. \n"
+                 "This flag is only useful for Objective-C code. When set to YES local\n"
+                 "methods, which are defined in the implementation section but not in\n"
+                 "the interface are included in the documentation.\n"
                  "If set to NO (the default) only methods in the interface are included.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "EXTRACT_ANON_NSPACES",
-                 "If this flag is set to YES, the members of anonymous namespaces will be \n"
-                 "extracted and appear in the documentation as a namespace called \n"
-                 "'anonymous_namespace{file}', where file will be replaced with the base \n"
-                 "name of the file that contains the anonymous namespace. By default \n"
+                 "If this flag is set to YES, the members of anonymous namespaces will be\n"
+                 "extracted and appear in the documentation as a namespace called\n"
+                 "'anonymous_namespace{file}', where file will be replaced with the base\n"
+                 "name of the file that contains the anonymous namespace. By default\n"
                  "anonymous namespace are hidden.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "HIDE_UNDOC_MEMBERS",
-                 "If the HIDE_UNDOC_MEMBERS tag is set to YES, Doxygen will hide all \n"
-                 "undocumented members of documented classes, files or namespaces. \n"
-                 "If set to NO (the default) these members will be included in the \n"
-                 "various overviews, but no documentation section is generated. \n"
+                 "If the HIDE_UNDOC_MEMBERS tag is set to YES, Doxygen will hide all\n"
+                 "undocumented members of documented classes, files or namespaces.\n"
+                 "If set to NO (the default) these members will be included in the\n"
+                 "various overviews, but no documentation section is generated.\n"
                  "This option has no effect if EXTRACT_ALL is enabled.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "HIDE_UNDOC_CLASSES",
-                 "If the HIDE_UNDOC_CLASSES tag is set to YES, Doxygen will hide all \n"
-                 "undocumented classes that are normally visible in the class hierarchy. \n"
-                 "If set to NO (the default) these classes will be included in the various \n"
+                 "If the HIDE_UNDOC_CLASSES tag is set to YES, Doxygen will hide all\n"
+                 "undocumented classes that are normally visible in the class hierarchy.\n"
+                 "If set to NO (the default) these classes will be included in the various\n"
                  "overviews. This option has no effect if EXTRACT_ALL is enabled.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "HIDE_FRIEND_COMPOUNDS",
-                 "If the HIDE_FRIEND_COMPOUNDS tag is set to YES, Doxygen will hide all \n"
-                 "friend (class|struct|union) declarations. \n"
-                 "If set to NO (the default) these declarations will be included in the \n"
+                 "If the HIDE_FRIEND_COMPOUNDS tag is set to YES, Doxygen will hide all\n"
+                 "friend (class|struct|union) declarations.\n"
+                 "If set to NO (the default) these declarations will be included in the\n"
                  "documentation.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "HIDE_IN_BODY_DOCS",
-                 "If the HIDE_IN_BODY_DOCS tag is set to YES, Doxygen will hide any \n"
-                 "documentation blocks found inside the body of a function. \n"
-                 "If set to NO (the default) these blocks will be appended to the \n"
+                 "If the HIDE_IN_BODY_DOCS tag is set to YES, Doxygen will hide any\n"
+                 "documentation blocks found inside the body of a function.\n"
+                 "If set to NO (the default) these blocks will be appended to the\n"
                  "function's detailed documentation block.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "INTERNAL_DOCS",
-                 "The INTERNAL_DOCS tag determines if documentation \n"
-                 "that is typed after a \\internal command is included. If the tag is set \n"
-                 "to NO (the default) then the documentation will be excluded. \n"
+                 "The INTERNAL_DOCS tag determines if documentation\n"
+                 "that is typed after a \\internal command is included. If the tag is set\n"
+                 "to NO (the default) then the documentation will be excluded.\n"
                  "Set it to YES to include the internal documentation.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "CASE_SENSE_NAMES",
-                 "If the CASE_SENSE_NAMES tag is set to NO then Doxygen will only generate \n"
-                 "file names in lower-case letters. If set to YES upper-case letters are also \n"
-                 "allowed. This is useful if you have classes or files whose names only differ \n"
-                 "in case and if your file system supports case sensitive file names. Windows \n"
+                 "If the CASE_SENSE_NAMES tag is set to NO then Doxygen will only generate\n"
+                 "file names in lower-case letters. If set to YES upper-case letters are also\n"
+                 "allowed. This is useful if you have classes or files whose names only differ\n"
+                 "in case and if your file system supports case sensitive file names. Windows\n"
                  "and Mac users are advised to set this option to NO.",
                  portable_fileSystemIsCaseSensitive()
                 );
   //----
   cb = cfg->addBool(
                  "HIDE_SCOPE_NAMES",
-                 "If the HIDE_SCOPE_NAMES tag is set to NO (the default) then Doxygen \n"
-                 "will show members with their full class and namespace scopes in the \n"
+                 "If the HIDE_SCOPE_NAMES tag is set to NO (the default) then Doxygen\n"
+                 "will show members with their full class and namespace scopes in the\n"
                  "documentation. If set to YES the scope will be hidden.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "SHOW_INCLUDE_FILES",
-                 "If the SHOW_INCLUDE_FILES tag is set to YES (the default) then Doxygen \n"
-                 "will put a list of the files that are included by a file in the documentation \n"
+                 "If the SHOW_INCLUDE_FILES tag is set to YES (the default) then Doxygen\n"
+                 "will put a list of the files that are included by a file in the documentation\n"
                  "of that file.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "INLINE_INFO",
-                 "If the INLINE_INFO tag is set to YES (the default) then a tag [inline] \n"
+                 "If the INLINE_INFO tag is set to YES (the default) then a tag [inline]\n"
                  "is inserted in the documentation for inline members.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "SORT_MEMBER_DOCS",
-                 "If the SORT_MEMBER_DOCS tag is set to YES (the default) then doxygen \n"
-                 "will sort the (detailed) documentation of file and class members \n"
-                 "alphabetically by member name. If set to NO the members will appear in \n"
+                 "If the SORT_MEMBER_DOCS tag is set to YES (the default) then doxygen\n"
+                 "will sort the (detailed) documentation of file and class members\n"
+                 "alphabetically by member name. If set to NO the members will appear in\n"
                  "declaration order.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "SORT_BRIEF_DOCS",
-                 "If the SORT_BRIEF_DOCS tag is set to YES then doxygen will sort the \n"
-                 "brief documentation of file, namespace and class members alphabetically \n"
-                 "by member name. If set to NO (the default) the members will appear in \n"
+                 "If the SORT_BRIEF_DOCS tag is set to YES then doxygen will sort the\n"
+                 "brief documentation of file, namespace and class members alphabetically\n"
+                 "by member name. If set to NO (the default) the members will appear in\n"
                  "declaration order.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "SORT_GROUP_NAMES",
-                 "If the SORT_GROUP_NAMES tag is set to YES then doxygen will sort the \n"
-                 "hierarchy of group names into alphabetical order. If set to NO (the default) \n"
+                 "If the SORT_GROUP_NAMES tag is set to YES then doxygen will sort the\n"
+                 "hierarchy of group names into alphabetical order. If set to NO (the default)\n"
                  "the group names will appear in their defined order.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "SORT_BY_SCOPE_NAME",
-                 "If the SORT_BY_SCOPE_NAME tag is set to YES, the class list will be \n"
-                 "sorted by fully-qualified names, including namespaces. If set to \n"
-                 "NO (the default), the class list will be sorted only by class name, \n"
-                 "not including the namespace part. \n"
-                 "Note: This option is not very useful if HIDE_SCOPE_NAMES is set to YES. \n"
-                 "Note: This option applies only to the class list, not to the \n"
+                 "If the SORT_BY_SCOPE_NAME tag is set to YES, the class list will be\n"
+                 "sorted by fully-qualified names, including namespaces. If set to\n"
+                 "NO (the default), the class list will be sorted only by class name,\n"
+                 "not including the namespace part.\n"
+                 "Note: This option is not very useful if HIDE_SCOPE_NAMES is set to YES.\n"
+                 "Note: This option applies only to the class list, not to the\n"
                  "alphabetical list.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "GENERATE_TODOLIST",
-                 "The GENERATE_TODOLIST tag can be used to enable (YES) or \n"
-                 "disable (NO) the todo list. This list is created by putting \\todo \n"
+                 "The GENERATE_TODOLIST tag can be used to enable (YES) or\n"
+                 "disable (NO) the todo list. This list is created by putting \\todo\n"
                  "commands in the documentation.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "GENERATE_TESTLIST",
-                 "The GENERATE_TESTLIST tag can be used to enable (YES) or \n"
-                 "disable (NO) the test list. This list is created by putting \\test \n"
+                 "The GENERATE_TESTLIST tag can be used to enable (YES) or\n"
+                 "disable (NO) the test list. This list is created by putting \\test\n"
                  "commands in the documentation.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "GENERATE_BUGLIST",
-                 "The GENERATE_BUGLIST tag can be used to enable (YES) or \n"
-                 "disable (NO) the bug list. This list is created by putting \\bug \n"
+                 "The GENERATE_BUGLIST tag can be used to enable (YES) or\n"
+                 "disable (NO) the bug list. This list is created by putting \\bug\n"
                  "commands in the documentation.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "GENERATE_DEPRECATEDLIST",
-                 "The GENERATE_DEPRECATEDLIST tag can be used to enable (YES) or \n"
-                 "disable (NO) the deprecated list. This list is created by putting \n"
+                 "The GENERATE_DEPRECATEDLIST tag can be used to enable (YES) or\n"
+                 "disable (NO) the deprecated list. This list is created by putting\n"
                  "\\deprecated commands in the documentation.",
                  TRUE
                 );
   //----
   cl = cfg->addList(
                  "ENABLED_SECTIONS",
-                 "The ENABLED_SECTIONS tag can be used to enable conditional \n"
+                 "The ENABLED_SECTIONS tag can be used to enable conditional\n"
                  "documentation sections, marked by \\if sectionname ... \\endif."
                 );
   //----
   ci = cfg->addInt(
                  "MAX_INITIALIZER_LINES",
-                 "The MAX_INITIALIZER_LINES tag determines the maximum number of lines \n"
-                 "the initial value of a variable or define consists of for it to appear in \n"
-                 "the documentation. If the initializer consists of more lines than specified \n"
-                 "here it will be hidden. Use a value of 0 to hide initializers completely. \n"
-                 "The appearance of the initializer of individual variables and defines in the \n"
-                 "documentation can be controlled using \\showinitializer or \\hideinitializer \n"
+                 "The MAX_INITIALIZER_LINES tag determines the maximum number of lines\n"
+                 "the initial value of a variable or define consists of for it to appear in\n"
+                 "the documentation. If the initializer consists of more lines than specified\n"
+                 "here it will be hidden. Use a value of 0 to hide initializers completely.\n"
+                 "The appearance of the initializer of individual variables and defines in the\n"
+                 "documentation can be controlled using \\showinitializer or \\hideinitializer\n"
                  "command in the documentation regardless of this setting.",
                  0,10000,30
                 );
   //----
   cb = cfg->addBool(
                  "SHOW_USED_FILES",
-                 "Set the SHOW_USED_FILES tag to NO to disable the list of files generated \n"
-                 "at the bottom of the documentation of classes and structs. If set to YES the \n"
+                 "Set the SHOW_USED_FILES tag to NO to disable the list of files generated\n"
+                 "at the bottom of the documentation of classes and structs. If set to YES the\n"
                  "list will mention the files that were used to generate the documentation.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "SHOW_DIRECTORIES",
-                 "If the sources in your project are distributed over multiple directories \n"
-                 "then setting the SHOW_DIRECTORIES tag to YES will show the directory hierarchy \n"
+                 "If the sources in your project are distributed over multiple directories\n"
+                 "then setting the SHOW_DIRECTORIES tag to YES will show the directory hierarchy\n"
                  "in the documentation. The default is NO.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "SHOW_FILES",
-                 "Set the SHOW_FILES tag to NO to disable the generation of the Files page. \n"
-                 "This will remove the Files entry from the Quick Index and from the \n"
+                 "Set the SHOW_FILES tag to NO to disable the generation of the Files page.\n"
+                 "This will remove the Files entry from the Quick Index and from the\n"
                  "Folder Tree View (if specified). The default is YES.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "SHOW_NAMESPACES",
-                 "Set the SHOW_NAMESPACES tag to NO to disable the generation of the \n"
-                 "Namespaces page. \n"
-                 "This will remove the Namespaces entry from the Quick Index \n"
+                 "Set the SHOW_NAMESPACES tag to NO to disable the generation of the\n"
+                 "Namespaces page.\n"
+                 "This will remove the Namespaces entry from the Quick Index\n"
                  "and from the Folder Tree View (if specified). The default is YES.",
                  TRUE
                 );
   //----
   cs = cfg->addString(
                  "FILE_VERSION_FILTER",
-                 "The FILE_VERSION_FILTER tag can be used to specify a program or script that \n"
-                 "doxygen should invoke to get the current version for each file (typically from \n"
-                 "the version control system). Doxygen will invoke the program by executing (via \n"
-                 "popen()) the command <command> <input-file>, where <command> is the value of \n"
-                 "the FILE_VERSION_FILTER tag, and <input-file> is the name of an input file \n"
-                 "provided by doxygen. Whatever the program writes to standard output \n"
+                 "The FILE_VERSION_FILTER tag can be used to specify a program or script that\n"
+                 "doxygen should invoke to get the current version for each file (typically from\n"
+                 "the version control system). Doxygen will invoke the program by executing (via\n"
+                 "popen()) the command <command> <input-file>, where <command> is the value of\n"
+                 "the FILE_VERSION_FILTER tag, and <input-file> is the name of an input file\n"
+                 "provided by doxygen. Whatever the program writes to standard output\n"
                  "is used as the file version. See the manual for examples."
                 );
   cs->setWidgetType(ConfigString::File);
   //----
   cs = cfg->addString(
                  "LAYOUT_FILE",
-                 "The LAYOUT_FILE tag can be used to specify a layout file which will be parsed by \n"
-                 "doxygen. The layout file controls the global structure of the generated output files \n"
-                 "in an output format independent way. The create the layout file that represents \n"
-                 "doxygen's defaults, run doxygen with the -l option. You can optionally specify a \n"
-                 "file name after the option, if omitted DoxygenLayout.xml will be used as the name \n"
+                 "The LAYOUT_FILE tag can be used to specify a layout file which will be parsed by\n"
+                 "doxygen. The layout file controls the global structure of the generated output files\n"
+                 "in an output format independent way. The create the layout file that represents\n"
+                 "doxygen's defaults, run doxygen with the -l option. You can optionally specify a\n"
+                 "file name after the option, if omitted DoxygenLayout.xml will be used as the name\n"
                  "of the layout file."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -691,61 +691,61 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "QUIET",
-                 "The QUIET tag can be used to turn on/off the messages that are generated \n"
+                 "The QUIET tag can be used to turn on/off the messages that are generated\n"
                  "by doxygen. Possible values are YES and NO. If left blank NO is used.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "WARNINGS",
-                 "The WARNINGS tag can be used to turn on/off the warning messages that are \n"
-                 "generated by doxygen. Possible values are YES and NO. If left blank \n"
+                 "The WARNINGS tag can be used to turn on/off the warning messages that are\n"
+                 "generated by doxygen. Possible values are YES and NO. If left blank\n"
                  "NO is used.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "WARN_IF_UNDOCUMENTED",
-                 "If WARN_IF_UNDOCUMENTED is set to YES, then doxygen will generate warnings \n"
-                 "for undocumented members. If EXTRACT_ALL is set to YES then this flag will \n"
+                 "If WARN_IF_UNDOCUMENTED is set to YES, then doxygen will generate warnings\n"
+                 "for undocumented members. If EXTRACT_ALL is set to YES then this flag will\n"
                  "automatically be disabled.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "WARN_IF_DOC_ERROR",
-                 "If WARN_IF_DOC_ERROR is set to YES, doxygen will generate warnings for \n"
-                 "potential errors in the documentation, such as not documenting some \n"
-                 "parameters in a documented function, or documenting parameters that \n"
+                 "If WARN_IF_DOC_ERROR is set to YES, doxygen will generate warnings for\n"
+                 "potential errors in the documentation, such as not documenting some\n"
+                 "parameters in a documented function, or documenting parameters that\n"
                  "don't exist or using markup commands wrongly.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "WARN_NO_PARAMDOC",
-                 "This WARN_NO_PARAMDOC option can be abled to get warnings for \n"
-                 "functions that are documented, but have no documentation for their parameters \n"
-                 "or return value. If set to NO (the default) doxygen will only warn about \n"
-                 "wrong or incomplete parameter documentation, but not about the absence of \n"
+                 "This WARN_NO_PARAMDOC option can be abled to get warnings for\n"
+                 "functions that are documented, but have no documentation for their parameters\n"
+                 "or return value. If set to NO (the default) doxygen will only warn about\n"
+                 "wrong or incomplete parameter documentation, but not about the absence of\n"
                  "documentation.",
                  FALSE
                 );
   //----
   cs = cfg->addString(
                  "WARN_FORMAT",
-                 "The WARN_FORMAT tag determines the format of the warning messages that \n"
-                 "doxygen can produce. The string should contain the $file, $line, and $text \n"
-                 "tags, which will be replaced by the file and line number from which the \n"
-                 "warning originated and the warning text. Optionally the format may contain \n"
-                 "$version, which will be replaced by the version of the file (if it could \n"
+                 "The WARN_FORMAT tag determines the format of the warning messages that\n"
+                 "doxygen can produce. The string should contain the $file, $line, and $text\n"
+                 "tags, which will be replaced by the file and line number from which the\n"
+                 "warning originated and the warning text. Optionally the format may contain\n"
+                 "$version, which will be replaced by the version of the file (if it could\n"
                  "be obtained via FILE_VERSION_FILTER)"
                 );
   cs->setDefaultValue("$file:$line: $text");
   //----
   cs = cfg->addString(
                  "WARN_LOGFILE",
-                 "The WARN_LOGFILE tag can be used to specify a file to which warning \n"
-                 "and error messages should be written. If left blank the output is written \n"
+                 "The WARN_LOGFILE tag can be used to specify a file to which warning\n"
+                 "and error messages should be written. If left blank the output is written\n"
                  "to stderr."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -756,9 +756,9 @@ void addConfigOptions(Config *cfg)
   //----
   cl = cfg->addList(
                  "INPUT",
-                 "The INPUT tag can be used to specify the files and/or directories that contain \n"
-                 "documented source files. You may enter file names like \"myfile.cpp\" or \n"
-                 "directories like \"/usr/src/myproject\". Separate the files or directories \n"
+                 "The INPUT tag can be used to specify the files and/or directories that contain\n"
+                 "documented source files. You may enter file names like \"myfile.cpp\" or\n"
+                 "directories like \"/usr/src/myproject\". Separate the files or directories\n"
                  "with spaces."
                 );
   cl->addValue("/Users/dimitri/doxygen/mail/1.5.7/doxywizard");
@@ -766,21 +766,21 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "INPUT_ENCODING",
-                 "This tag can be used to specify the character encoding of the source files \n"
-                 "that doxygen parses. Internally doxygen uses the UTF-8 encoding, which is \n"
-                 "also the default input encoding. Doxygen uses libiconv (or the iconv built \n"
-                 "into libc) for the transcoding. See http://www.gnu.org/software/libiconv for \n"
+                 "This tag can be used to specify the character encoding of the source files\n"
+                 "that doxygen parses. Internally doxygen uses the UTF-8 encoding, which is\n"
+                 "also the default input encoding. Doxygen uses libiconv (or the iconv built\n"
+                 "into libc) for the transcoding. See http://www.gnu.org/software/libiconv for\n"
                  "the list of possible encodings."
                 );
   cs->setDefaultValue("UTF-8");
   //----
   cl = cfg->addList(
                  "FILE_PATTERNS",
-                 "If the value of the INPUT tag contains directories, you can use the \n"
-                 "FILE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp \n"
-                 "and *.h) to filter out the source-files in the directories. If left \n"
-                 "blank the following patterns are tested: \n"
-                 "*.c *.cc *.cxx *.cpp *.c++ *.java *.ii *.ixx *.ipp *.i++ *.inl *.h *.hh *.hxx \n"
+                 "If the value of the INPUT tag contains directories, you can use the\n"
+                 "FILE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp\n"
+                 "and *.h) to filter out the source-files in the directories. If left\n"
+                 "blank the following patterns are tested:\n"
+                 "*.c *.cc *.cxx *.cpp *.c++ *.java *.ii *.ixx *.ipp *.i++ *.inl *.h *.hh *.hxx\n"
                  "*.hpp *.h++ *.idl *.odl *.cs *.php *.php3 *.inc *.m *.mm *.py *.f90"
                 );
   cl->addValue("*.c");
@@ -817,110 +817,110 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "RECURSIVE",
-                 "The RECURSIVE tag can be used to turn specify whether or not subdirectories \n"
-                 "should be searched for input files as well. Possible values are YES and NO. \n"
+                 "The RECURSIVE tag can be used to turn specify whether or not subdirectories\n"
+                 "should be searched for input files as well. Possible values are YES and NO.\n"
                  "If left blank NO is used.",
                  FALSE
                 );
   //----
   cl = cfg->addList(
                  "EXCLUDE",
-                 "The EXCLUDE tag can be used to specify files and/or directories that should \n"
-                 "excluded from the INPUT source files. This way you can easily exclude a \n"
+                 "The EXCLUDE tag can be used to specify files and/or directories that should\n"
+                 "excluded from the INPUT source files. This way you can easily exclude a\n"
                  "subdirectory from a directory tree whose root is specified with the INPUT tag."
                 );
   cl->setWidgetType(ConfigList::FileAndDir);
   //----
   cb = cfg->addBool(
                  "EXCLUDE_SYMLINKS",
-                 "The EXCLUDE_SYMLINKS tag can be used select whether or not files or \n"
-                 "directories that are symbolic links (a Unix filesystem feature) are excluded \n"
+                 "The EXCLUDE_SYMLINKS tag can be used select whether or not files or\n"
+                 "directories that are symbolic links (a Unix filesystem feature) are excluded\n"
                  "from the input.",
                  FALSE
                 );
   //----
   cl = cfg->addList(
                  "EXCLUDE_PATTERNS",
-                 "If the value of the INPUT tag contains directories, you can use the \n"
-                 "EXCLUDE_PATTERNS tag to specify one or more wildcard patterns to exclude \n"
-                 "certain files from those directories. Note that the wildcards are matched \n"
-                 "against the file with absolute path, so to exclude all test directories \n"
+                 "If the value of the INPUT tag contains directories, you can use the\n"
+                 "EXCLUDE_PATTERNS tag to specify one or more wildcard patterns to exclude\n"
+                 "certain files from those directories. Note that the wildcards are matched\n"
+                 "against the file with absolute path, so to exclude all test directories\n"
                  "for example use the pattern */test/*"
                 );
   //----
   cl = cfg->addList(
                  "EXCLUDE_SYMBOLS",
-                 "The EXCLUDE_SYMBOLS tag can be used to specify one or more symbol names \n"
-                 "(namespaces, classes, functions, etc.) that should be excluded from the \n"
-                 "output. The symbol name can be a fully qualified name, a word, or if the \n"
-                 "wildcard * is used, a substring. Examples: ANamespace, AClass, \n"
+                 "The EXCLUDE_SYMBOLS tag can be used to specify one or more symbol names\n"
+                 "(namespaces, classes, functions, etc.) that should be excluded from the\n"
+                 "output. The symbol name can be a fully qualified name, a word, or if the\n"
+                 "wildcard * is used, a substring. Examples: ANamespace, AClass,\n"
                  "AClass::ANamespace, ANamespace::*Test"
                 );
   //----
   cl = cfg->addList(
                  "EXAMPLE_PATH",
-                 "The EXAMPLE_PATH tag can be used to specify one or more files or \n"
-                 "directories that contain example code fragments that are included (see \n"
+                 "The EXAMPLE_PATH tag can be used to specify one or more files or\n"
+                 "directories that contain example code fragments that are included (see\n"
                  "the \\include command)."
                 );
   cl->setWidgetType(ConfigList::Dir);
   //----
   cl = cfg->addList(
                  "EXAMPLE_PATTERNS",
-                 "If the value of the EXAMPLE_PATH tag contains directories, you can use the \n"
-                 "EXAMPLE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp \n"
-                 "and *.h) to filter out the source-files in the directories. If left \n"
+                 "If the value of the EXAMPLE_PATH tag contains directories, you can use the\n"
+                 "EXAMPLE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp\n"
+                 "and *.h) to filter out the source-files in the directories. If left\n"
                  "blank all files are included."
                 );
   cl->addValue("*");
   //----
   cb = cfg->addBool(
                  "EXAMPLE_RECURSIVE",
-                 "If the EXAMPLE_RECURSIVE tag is set to YES then subdirectories will be \n"
-                 "searched for input files to be used with the \\include or \\dontinclude \n"
-                 "commands irrespective of the value of the RECURSIVE tag. \n"
+                 "If the EXAMPLE_RECURSIVE tag is set to YES then subdirectories will be\n"
+                 "searched for input files to be used with the \\include or \\dontinclude\n"
+                 "commands irrespective of the value of the RECURSIVE tag.\n"
                  "Possible values are YES and NO. If left blank NO is used.",
                  FALSE
                 );
   //----
   cl = cfg->addList(
                  "IMAGE_PATH",
-                 "The IMAGE_PATH tag can be used to specify one or more files or \n"
-                 "directories that contain image that are included in the documentation (see \n"
+                 "The IMAGE_PATH tag can be used to specify one or more files or\n"
+                 "directories that contain image that are included in the documentation (see\n"
                  "the \\image command)."
                 );
   cl->setWidgetType(ConfigList::Dir);
   //----
   cs = cfg->addString(
                  "INPUT_FILTER",
-                 "The INPUT_FILTER tag can be used to specify a program that doxygen should \n"
-                 "invoke to filter for each input file. Doxygen will invoke the filter program \n"
-                 "by executing (via popen()) the command <filter> <input-file>, where <filter> \n"
-                 "is the value of the INPUT_FILTER tag, and <input-file> is the name of an \n"
-                 "input file. Doxygen will then use the output that the filter program writes \n"
-                 "to standard output. \n"
-                 "If FILTER_PATTERNS is specified, this tag will be \n"
+                 "The INPUT_FILTER tag can be used to specify a program that doxygen should\n"
+                 "invoke to filter for each input file. Doxygen will invoke the filter program\n"
+                 "by executing (via popen()) the command <filter> <input-file>, where <filter>\n"
+                 "is the value of the INPUT_FILTER tag, and <input-file> is the name of an\n"
+                 "input file. Doxygen will then use the output that the filter program writes\n"
+                 "to standard output.\n"
+                 "If FILTER_PATTERNS is specified, this tag will be\n"
                  "ignored."
                 );
   cs->setWidgetType(ConfigString::File);
   //----
   cl = cfg->addList(
                  "FILTER_PATTERNS",
-                 "The FILTER_PATTERNS tag can be used to specify filters on a per file pattern \n"
-                 "basis. \n"
-                 "Doxygen will compare the file name with each pattern and apply the \n"
-                 "filter if there is a match. \n"
-                 "The filters are a list of the form: \n"
-                 "pattern=filter (like *.cpp=my_cpp_filter). See INPUT_FILTER for further \n"
-                 "info on how filters are used. If FILTER_PATTERNS is empty, INPUT_FILTER \n"
+                 "The FILTER_PATTERNS tag can be used to specify filters on a per file pattern\n"
+                 "basis.\n"
+                 "Doxygen will compare the file name with each pattern and apply the\n"
+                 "filter if there is a match.\n"
+                 "The filters are a list of the form:\n"
+                 "pattern=filter (like *.cpp=my_cpp_filter). See INPUT_FILTER for further\n"
+                 "info on how filters are used. If FILTER_PATTERNS is empty, INPUT_FILTER\n"
                  "is applied to all files."
                 );
   cl->setWidgetType(ConfigList::File);
   //----
   cb = cfg->addBool(
                  "FILTER_SOURCE_FILES",
-                 "If the FILTER_SOURCE_FILES tag is set to YES, the input filter (if set using \n"
-                 "INPUT_FILTER) will be used to filter the input files when producing source \n"
+                 "If the FILTER_SOURCE_FILES tag is set to YES, the input filter (if set using\n"
+                 "INPUT_FILTER) will be used to filter the input files when producing source\n"
                  "files to browse (i.e. when SOURCE_BROWSER is set to YES).",
                  FALSE
                 );
@@ -931,60 +931,60 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "SOURCE_BROWSER",
-                 "If the SOURCE_BROWSER tag is set to YES then a list of source files will \n"
-                 "be generated. Documented entities will be cross-referenced with these sources. \n"
-                 "Note: To get rid of all source code in the generated output, make sure also \n"
+                 "If the SOURCE_BROWSER tag is set to YES then a list of source files will\n"
+                 "be generated. Documented entities will be cross-referenced with these sources.\n"
+                 "Note: To get rid of all source code in the generated output, make sure also\n"
                  "VERBATIM_HEADERS is set to NO.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "INLINE_SOURCES",
-                 "Setting the INLINE_SOURCES tag to YES will include the body \n"
+                 "Setting the INLINE_SOURCES tag to YES will include the body\n"
                  "of functions and classes directly in the documentation.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "STRIP_CODE_COMMENTS",
-                 "Setting the STRIP_CODE_COMMENTS tag to YES (the default) will instruct \n"
-                 "doxygen to hide any special comment blocks from generated source code \n"
+                 "Setting the STRIP_CODE_COMMENTS tag to YES (the default) will instruct\n"
+                 "doxygen to hide any special comment blocks from generated source code\n"
                  "fragments. Normal C and C++ comments will always remain visible.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "REFERENCED_BY_RELATION",
-                 "If the REFERENCED_BY_RELATION tag is set to YES \n"
-                 "then for each documented function all documented \n"
+                 "If the REFERENCED_BY_RELATION tag is set to YES\n"
+                 "then for each documented function all documented\n"
                  "functions referencing it will be listed.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "REFERENCES_RELATION",
-                 "If the REFERENCES_RELATION tag is set to YES \n"
-                 "then for each documented function all documented entities \n"
+                 "If the REFERENCES_RELATION tag is set to YES\n"
+                 "then for each documented function all documented entities\n"
                  "called/used by that function will be listed.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "REFERENCES_LINK_SOURCE",
-                 "If the REFERENCES_LINK_SOURCE tag is set to YES (the default) \n"
-                 "and SOURCE_BROWSER tag is set to YES, then the hyperlinks from \n"
-                 "functions in REFERENCES_RELATION and REFERENCED_BY_RELATION lists will \n"
-                 "link to the source code. \n"
+                 "If the REFERENCES_LINK_SOURCE tag is set to YES (the default)\n"
+                 "and SOURCE_BROWSER tag is set to YES, then the hyperlinks from\n"
+                 "functions in REFERENCES_RELATION and REFERENCED_BY_RELATION lists will\n"
+                 "link to the source code.\n"
                  "Otherwise they will link to the documentation.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "USE_HTAGS",
-                 "If the USE_HTAGS tag is set to YES then the references to source code \n"
-                 "will point to the HTML generated by the htags(1) tool instead of doxygen \n"
-                 "built-in source browser. The htags tool is part of GNU's global source \n"
-                 "tagging system (see http://www.gnu.org/software/global/global.html). You \n"
+                 "If the USE_HTAGS tag is set to YES then the references to source code\n"
+                 "will point to the HTML generated by the htags(1) tool instead of doxygen\n"
+                 "built-in source browser. The htags tool is part of GNU's global source\n"
+                 "tagging system (see http://www.gnu.org/software/global/global.html). You\n"
                  "will need version 4.8.6 or higher.",
                  FALSE
                 );
@@ -992,8 +992,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "VERBATIM_HEADERS",
-                 "If the VERBATIM_HEADERS tag is set to YES (the default) then Doxygen \n"
-                 "will generate a verbatim copy of the header file for each class for \n"
+                 "If the VERBATIM_HEADERS tag is set to YES (the default) then Doxygen\n"
+                 "will generate a verbatim copy of the header file for each class for\n"
                  "which an include is specified. Set to NO to disable this.",
                  TRUE
                 );
@@ -1004,25 +1004,25 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "ALPHABETICAL_INDEX",
-                 "If the ALPHABETICAL_INDEX tag is set to YES, an alphabetical index \n"
-                 "of all compounds will be generated. Enable this if the project \n"
+                 "If the ALPHABETICAL_INDEX tag is set to YES, an alphabetical index\n"
+                 "of all compounds will be generated. Enable this if the project\n"
                  "contains a lot of classes, structs, unions or interfaces.",
                  FALSE
                 );
   //----
   ci = cfg->addInt(
                  "COLS_IN_ALPHA_INDEX",
-                 "If the alphabetical index is enabled (see ALPHABETICAL_INDEX) then \n"
-                 "the COLS_IN_ALPHA_INDEX tag can be used to specify the number of columns \n"
+                 "If the alphabetical index is enabled (see ALPHABETICAL_INDEX) then\n"
+                 "the COLS_IN_ALPHA_INDEX tag can be used to specify the number of columns\n"
                  "in which this list will be split (can be a number in the range [1..20])",
                  1,20,5
                 );
   //----
   cl = cfg->addList(
                  "IGNORE_PREFIX",
-                 "In case all classes in a project start with a common prefix, all \n"
-                 "classes will be put under the same header in the alphabetical index. \n"
-                 "The IGNORE_PREFIX tag can be used to specify one or more prefixes that \n"
+                 "In case all classes in a project start with a common prefix, all\n"
+                 "classes will be put under the same header in the alphabetical index.\n"
+                 "The IGNORE_PREFIX tag can be used to specify one or more prefixes that\n"
                  "should be ignored while generating the index headers."
                 );
   //---------------------------------------------------------------------------
@@ -1032,15 +1032,15 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_HTML",
-                 "If the GENERATE_HTML tag is set to YES (the default) Doxygen will \n"
+                 "If the GENERATE_HTML tag is set to YES (the default) Doxygen will\n"
                  "generate HTML output.",
                  TRUE
                 );
   //----
   cs = cfg->addString(
                  "HTML_OUTPUT",
-                 "The HTML_OUTPUT tag is used to specify where the HTML docs will be put. \n"
-                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be \n"
+                 "The HTML_OUTPUT tag is used to specify where the HTML docs will be put.\n"
+                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be\n"
                  "put in front of it. If left blank `html' will be used as the default path."
                 );
   cs->setDefaultValue("html");
@@ -1049,8 +1049,8 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "HTML_FILE_EXTENSION",
-                 "The HTML_FILE_EXTENSION tag can be used to specify the file extension for \n"
-                 "each generated HTML page (for example: .htm,.php,.asp). If it is left blank \n"
+                 "The HTML_FILE_EXTENSION tag can be used to specify the file extension for\n"
+                 "each generated HTML page (for example: .htm,.php,.asp). If it is left blank\n"
                  "doxygen will generate files with .html extension."
                 );
   cs->setDefaultValue(".html");
@@ -1058,8 +1058,8 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "HTML_HEADER",
-                 "The HTML_HEADER tag can be used to specify a personal HTML header for \n"
-                 "each generated HTML page. If it is left blank doxygen will generate a \n"
+                 "The HTML_HEADER tag can be used to specify a personal HTML header for\n"
+                 "each generated HTML page. If it is left blank doxygen will generate a\n"
                  "standard header."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1067,8 +1067,8 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "HTML_FOOTER",
-                 "The HTML_FOOTER tag can be used to specify a personal HTML footer for \n"
-                 "each generated HTML page. If it is left blank doxygen will generate a \n"
+                 "The HTML_FOOTER tag can be used to specify a personal HTML footer for\n"
+                 "each generated HTML page. If it is left blank doxygen will generate a\n"
                  "standard footer."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1076,11 +1076,11 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "HTML_STYLESHEET",
-                 "The HTML_STYLESHEET tag can be used to specify a user-defined cascading \n"
-                 "style sheet that is used by each HTML page. It can be used to \n"
-                 "fine-tune the look of the HTML output. If the tag is left blank doxygen \n"
-                 "will generate a default style sheet. Note that doxygen will try to copy \n"
-                 "the style sheet file to the HTML output directory, so don't put your own \n"
+                 "The HTML_STYLESHEET tag can be used to specify a user-defined cascading\n"
+                 "style sheet that is used by each HTML page. It can be used to\n"
+                 "fine-tune the look of the HTML output. If the tag is left blank doxygen\n"
+                 "will generate a default style sheet. Note that doxygen will try to copy\n"
+                 "the style sheet file to the HTML output directory, so don't put your own\n"
                  "stylesheet in the HTML output directory as well, or it will be erased!"
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1088,8 +1088,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "HTML_ALIGN_MEMBERS",
-                 "If the HTML_ALIGN_MEMBERS tag is set to YES, the members of classes, \n"
-                 "files or namespaces will be aligned in HTML using tables. If set to \n"
+                 "If the HTML_ALIGN_MEMBERS tag is set to YES, the members of classes,\n"
+                 "files or namespaces will be aligned in HTML using tables. If set to\n"
                  "NO a bullet list will be used.",
                  TRUE
                 );
@@ -1097,10 +1097,10 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "HTML_DYNAMIC_SECTIONS",
-                 "If the HTML_DYNAMIC_SECTIONS tag is set to YES then the generated HTML \n"
-                 "documentation will contain sections that can be hidden and shown after the \n"
-                 "page has loaded. For this to work a browser that supports \n"
-                 "JavaScript and DHTML is required (for instance Mozilla 1.0+, Firefox \n"
+                 "If the HTML_DYNAMIC_SECTIONS tag is set to YES then the generated HTML\n"
+                 "documentation will contain sections that can be hidden and shown after the\n"
+                 "page has loaded. For this to work a browser that supports\n"
+                 "JavaScript and DHTML is required (for instance Mozilla 1.0+, Firefox\n"
                  "Netscape 6.0+, Internet explorer 5.0+, Konqueror, or Safari).",
                  FALSE
                 );
@@ -1108,14 +1108,14 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_DOCSET",
-                 "If the GENERATE_DOCSET tag is set to YES, additional index files \n"
-                 "will be generated that can be used as input for Apple's Xcode 3 \n"
-                 "integrated development environment, introduced with OSX 10.5 (Leopard). \n"
-                 "To create a documentation set, doxygen will generate a Makefile in the \n"
-                 "HTML output directory. Running make will produce the docset in that \n"
-                 "directory and running \"make install\" will install the docset in \n"
-                 "~/Library/Developer/Shared/Documentation/DocSets so that Xcode will find \n"
-                 "it at startup. \n"
+                 "If the GENERATE_DOCSET tag is set to YES, additional index files\n"
+                 "will be generated that can be used as input for Apple's Xcode 3\n"
+                 "integrated development environment, introduced with OSX 10.5 (Leopard).\n"
+                 "To create a documentation set, doxygen will generate a Makefile in the\n"
+                 "HTML output directory. Running make will produce the docset in that\n"
+                 "directory and running \"make install\" will install the docset in\n"
+                 "~/Library/Developer/Shared/Documentation/DocSets so that Xcode will find\n"
+                 "it at startup.\n"
                  "See http://developer.apple.com/tools/creatingdocsetswithdoxygen.html for more information.",
                  FALSE
                 );
@@ -1123,9 +1123,9 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "DOCSET_FEEDNAME",
-                 "When GENERATE_DOCSET tag is set to YES, this tag determines the name of the \n"
-                 "feed. A documentation feed provides an umbrella under which multiple \n"
-                 "documentation sets from a single provider (such as a company or product suite) \n"
+                 "When GENERATE_DOCSET tag is set to YES, this tag determines the name of the\n"
+                 "feed. A documentation feed provides an umbrella under which multiple\n"
+                 "documentation sets from a single provider (such as a company or product suite)\n"
                  "can be grouped."
                 );
   cs->setDefaultValue("Doxygen generated docs");
@@ -1133,9 +1133,9 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "DOCSET_BUNDLE_ID",
-                 "When GENERATE_DOCSET tag is set to YES, this tag specifies a string that \n"
-                 "should uniquely identify the documentation set bundle. This should be a \n"
-                 "reverse domain-name style string, e.g. com.mycompany.MyDocSet. Doxygen \n"
+                 "When GENERATE_DOCSET tag is set to YES, this tag specifies a string that\n"
+                 "should uniquely identify the documentation set bundle. This should be a\n"
+                 "reverse domain-name style string, e.g. com.mycompany.MyDocSet. Doxygen\n"
                  "will append .docset to the name."
                 );
   cs->setDefaultValue("org.doxygen.Project");
@@ -1143,9 +1143,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_HTMLHELP",
-                 "If the GENERATE_HTMLHELP tag is set to YES, additional index files \n"
-                 "will be generated that can be used as input for tools like the \n"
-                 "Microsoft HTML help workshop to generate a compiled HTML help file (.chm) \n"
+                 "If the GENERATE_HTMLHELP tag is set to YES, additional index files\n"
+                 "will be generated that can be used as input for tools like the\n"
+                 "Microsoft HTML help workshop to generate a compiled HTML help file (.chm)\n"
                  "of the generated HTML documentation.",
                  FALSE
                 );
@@ -1153,9 +1153,9 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "CHM_FILE",
-                 "If the GENERATE_HTMLHELP tag is set to YES, the CHM_FILE tag can \n"
-                 "be used to specify the file name of the resulting .chm file. You \n"
-                 "can add a path in front of the file if the result should not be \n"
+                 "If the GENERATE_HTMLHELP tag is set to YES, the CHM_FILE tag can\n"
+                 "be used to specify the file name of the resulting .chm file. You\n"
+                 "can add a path in front of the file if the result should not be\n"
                  "written to the html output directory."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1163,9 +1163,9 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "HHC_LOCATION",
-                 "If the GENERATE_HTMLHELP tag is set to YES, the HHC_LOCATION tag can \n"
-                 "be used to specify the location (absolute path including file name) of \n"
-                 "the HTML help compiler (hhc.exe). If non-empty doxygen will try to run \n"
+                 "If the GENERATE_HTMLHELP tag is set to YES, the HHC_LOCATION tag can\n"
+                 "be used to specify the location (absolute path including file name) of\n"
+                 "the HTML help compiler (hhc.exe). If non-empty doxygen will try to run\n"
                  "the HTML help compiler on the generated index.hhp."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1173,8 +1173,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_CHI",
-                 "If the GENERATE_HTMLHELP tag is set to YES, the GENERATE_CHI flag \n"
-                 "controls if a separate .chi index file is generated (YES) or that \n"
+                 "If the GENERATE_HTMLHELP tag is set to YES, the GENERATE_CHI flag\n"
+                 "controls if a separate .chi index file is generated (YES) or that\n"
                  "it should be included in the master .chm file (NO).",
                  FALSE
                 );
@@ -1182,16 +1182,16 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "CHM_INDEX_ENCODING",
-                 "If the GENERATE_HTMLHELP tag is set to YES, the CHM_INDEX_ENCODING \n"
-                 "is used to encode HtmlHelp index (hhk), content (hhc) and project file \n"
+                 "If the GENERATE_HTMLHELP tag is set to YES, the CHM_INDEX_ENCODING\n"
+                 "is used to encode HtmlHelp index (hhk), content (hhc) and project file\n"
                  "content."
                 );
   cs->addDependency("GENERATE_HTMLHELP");
   //----
   cb = cfg->addBool(
                  "BINARY_TOC",
-                 "If the GENERATE_HTMLHELP tag is set to YES, the BINARY_TOC flag \n"
-                 "controls whether a binary table of contents is generated (YES) or a \n"
+                 "If the GENERATE_HTMLHELP tag is set to YES, the BINARY_TOC flag\n"
+                 "controls whether a binary table of contents is generated (YES) or a\n"
                  "normal table of contents (NO) in the .chm file.",
                  FALSE
                 );
@@ -1199,7 +1199,7 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "TOC_EXPAND",
-                 "The TOC_EXPAND flag can be set to YES to add extra items for group members \n"
+                 "The TOC_EXPAND flag can be set to YES to add extra items for group members\n"
                  "to the contents of the HTML help documentation and to the tree view.",
                  FALSE
                 );
@@ -1207,9 +1207,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_QHP",
-                 "If the GENERATE_QHP tag is set to YES and both QHP_NAMESPACE and QHP_VIRTUAL_FOLDER \n"
-                 "are set, an additional index file will be generated that can be used as input for \n"
-                 "Qt's qhelpgenerator to generate a Qt Compressed Help (.qch) of the generated \n"
+                 "If the GENERATE_QHP tag is set to YES and both QHP_NAMESPACE and QHP_VIRTUAL_FOLDER\n"
+                 "are set, an additional index file will be generated that can be used as input for\n"
+                 "Qt's qhelpgenerator to generate a Qt Compressed Help (.qch) of the generated\n"
                  "HTML documentation.",
                  FALSE
                 );
@@ -1217,8 +1217,8 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "QCH_FILE",
-                 "If the QHG_LOCATION tag is specified, the QCH_FILE tag can \n"
-                 "be used to specify the file name of the resulting .qch file. \n"
+                 "If the QHG_LOCATION tag is specified, the QCH_FILE tag can\n"
+                 "be used to specify the file name of the resulting .qch file.\n"
                  "The path specified is relative to the HTML output folder."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1226,16 +1226,16 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "QHP_NAMESPACE",
-                 "The QHP_NAMESPACE tag specifies the namespace to use when generating \n"
-                 "Qt Help Project output. For more information please see \n"
+                 "The QHP_NAMESPACE tag specifies the namespace to use when generating\n"
+                 "Qt Help Project output. For more information please see\n"
                  "http://doc.trolltech.com/qthelpproject.html#namespace"
                 );
   cs->addDependency("GENERATE_QHP");
   //----
   cs = cfg->addString(
                  "QHP_VIRTUAL_FOLDER",
-                 "The QHP_VIRTUAL_FOLDER tag specifies the namespace to use when generating \n"
-                 "Qt Help Project output. For more information please see \n"
+                 "The QHP_VIRTUAL_FOLDER tag specifies the namespace to use when generating\n"
+                 "Qt Help Project output. For more information please see\n"
                  "http://doc.trolltech.com/qthelpproject.html#virtual-folders"
                 );
   cs->setDefaultValue("doc");
@@ -1243,32 +1243,32 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "QHP_CUST_FILTER_NAME",
-                 "If QHP_CUST_FILTER_NAME is set, it specifies the name of a custom filter to add. \n"
-                 "For more information please see \n"
+                 "If QHP_CUST_FILTER_NAME is set, it specifies the name of a custom filter to add.\n"
+                 "For more information please see\n"
                  "http://doc.trolltech.com/qthelpproject.html#custom-filters"
                 );
   cs->addDependency("GENERATE_QHP");
   //----
   cs = cfg->addString(
                  "QHP_CUST_FILTER_ATTRS",
-                 "The QHP_CUST_FILT_ATTRS tag specifies the list of the attributes of the custom filter to add.For more information please see \n"
+                 "The QHP_CUST_FILT_ATTRS tag specifies the list of the attributes of the custom filter to add.For more information please see\n"
                  "<a href=\"http://doc.trolltech.com/qthelpproject.html#custom-filters\">Qt Help Project / Custom Filters</a>."
                 );
   cs->addDependency("GENERATE_QHP");
   //----
   cs = cfg->addString(
                  "QHP_SECT_FILTER_ATTRS",
-                 "The QHP_SECT_FILTER_ATTRS tag specifies the list of the attributes this project's \n"
-                 "filter section matches. \n"
+                 "The QHP_SECT_FILTER_ATTRS tag specifies the list of the attributes this project's\n"
+                 "filter section matches.\n"
                  "<a href=\"http://doc.trolltech.com/qthelpproject.html#filter-attributes\">Qt Help Project / Filter Attributes</a>."
                 );
   cs->addDependency("GENERATE_QHP");
   //----
   cs = cfg->addString(
                  "QHG_LOCATION",
-                 "If the GENERATE_QHP tag is set to YES, the QHG_LOCATION tag can \n"
-                 "be used to specify the location of Qt's qhelpgenerator. \n"
-                 "If non-empty doxygen will try to run qhelpgenerator on the generated \n"
+                 "If the GENERATE_QHP tag is set to YES, the QHG_LOCATION tag can\n"
+                 "be used to specify the location of Qt's qhelpgenerator.\n"
+                 "If non-empty doxygen will try to run qhelpgenerator on the generated\n"
                  ".qhp file."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1276,8 +1276,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "DISABLE_INDEX",
-                 "The DISABLE_INDEX tag can be used to turn on/off the condensed index at \n"
-                 "top of each HTML page. The value NO (the default) enables the index and \n"
+                 "The DISABLE_INDEX tag can be used to turn on/off the condensed index at\n"
+                 "top of each HTML page. The value NO (the default) enables the index and\n"
                  "the value YES disables it.",
                  FALSE
                 );
@@ -1285,7 +1285,7 @@ void addConfigOptions(Config *cfg)
   //----
   ci = cfg->addInt(
                  "ENUM_VALUES_PER_LINE",
-                 "This tag can be used to set the number of enum values (range [1..20]) \n"
+                 "This tag can be used to set the number of enum values (range [1..20])\n"
                  "that doxygen will group on one line in the generated HTML documentation.",
                  1,20,4
                 );
@@ -1293,19 +1293,19 @@ void addConfigOptions(Config *cfg)
   //----
   ce = cfg->addEnum(
                  "GENERATE_TREEVIEW",
-                 "The GENERATE_TREEVIEW tag is used to specify whether a tree-like index \n"
-                 "structure should be generated to display hierarchical information. \n"
-                 "If the tag value is set to FRAME, a side panel will be generated \n"
-                 "containing a tree-like index structure (just like the one that \n"
-                 "is generated for HTML Help). For this to work a browser that supports \n"
-                 "JavaScript, DHTML, CSS and frames is required (for instance Mozilla 1.0+, \n"
-                 "Netscape 6.0+, Internet explorer 5.0+, or Konqueror). Windows users are \n"
-                 "probably better off using the HTML help feature. Other possible values \n"
-                 "for this tag are: HIERARCHIES, which will generate the Groups, Directories, \n"
-                 "and Class Hierarchy pages using a tree view instead of an ordered list; \n"
-                 "ALL, which combines the behavior of FRAME and HIERARCHIES; and NONE, which \n"
-                 "disables this behavior completely. For backwards compatibility with previous \n"
-                 "releases of Doxygen, the values YES and NO are equivalent to FRAME and NONE \n"
+                 "The GENERATE_TREEVIEW tag is used to specify whether a tree-like index\n"
+                 "structure should be generated to display hierarchical information.\n"
+                 "If the tag value is set to FRAME, a side panel will be generated\n"
+                 "containing a tree-like index structure (just like the one that\n"
+                 "is generated for HTML Help). For this to work a browser that supports\n"
+                 "JavaScript, DHTML, CSS and frames is required (for instance Mozilla 1.0+,\n"
+                 "Netscape 6.0+, Internet explorer 5.0+, or Konqueror). Windows users are\n"
+                 "probably better off using the HTML help feature. Other possible values\n"
+                 "for this tag are: HIERARCHIES, which will generate the Groups, Directories,\n"
+                 "and Class Hierarchy pages using a tree view instead of an ordered list;\n"
+                 "ALL, which combines the behavior of FRAME and HIERARCHIES; and NONE, which\n"
+                 "disables this behavior completely. For backwards compatibility with previous\n"
+                 "releases of Doxygen, the values YES and NO are equivalent to FRAME and NONE\n"
                  "respectively.",
                  "NONE"
                 );
@@ -1317,8 +1317,8 @@ void addConfigOptions(Config *cfg)
   //----
   ci = cfg->addInt(
                  "TREEVIEW_WIDTH",
-                 "If the treeview is enabled (see GENERATE_TREEVIEW) then this tag can be \n"
-                 "used to set the initial width (in pixels) of the frame in which the tree \n"
+                 "If the treeview is enabled (see GENERATE_TREEVIEW) then this tag can be\n"
+                 "used to set the initial width (in pixels) of the frame in which the tree\n"
                  "is shown.",
                  0,1500,250
                 );
@@ -1326,10 +1326,10 @@ void addConfigOptions(Config *cfg)
   //----
   ci = cfg->addInt(
                  "FORMULA_FONTSIZE",
-                 "Use this tag to change the font size of Latex formulas included \n"
-                 "as images in the HTML documentation. The default is 10. Note that \n"
-                 "when you change the font size after a successful doxygen run you need \n"
-                 "to manually remove any form_*.png images from the HTML output directory \n"
+                 "Use this tag to change the font size of Latex formulas included\n"
+                 "as images in the HTML documentation. The default is 10. Note that\n"
+                 "when you change the font size after a successful doxygen run you need\n"
+                 "to manually remove any form_*.png images from the HTML output directory\n"
                  "to force them to be regenerated.",
                  8,50,10
                 );
@@ -1341,15 +1341,15 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_LATEX",
-                 "If the GENERATE_LATEX tag is set to YES (the default) Doxygen will \n"
+                 "If the GENERATE_LATEX tag is set to YES (the default) Doxygen will\n"
                  "generate Latex output.",
                  TRUE
                 );
   //----
   cs = cfg->addString(
                  "LATEX_OUTPUT",
-                 "The LATEX_OUTPUT tag is used to specify where the LaTeX docs will be put. \n"
-                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be \n"
+                 "The LATEX_OUTPUT tag is used to specify where the LaTeX docs will be put.\n"
+                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be\n"
                  "put in front of it. If left blank `latex' will be used as the default path."
                 );
   cs->setDefaultValue("latex");
@@ -1358,7 +1358,7 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "LATEX_CMD_NAME",
-                 "The LATEX_CMD_NAME tag can be used to specify the LaTeX command name to be \n"
+                 "The LATEX_CMD_NAME tag can be used to specify the LaTeX command name to be\n"
                  "invoked. If left blank `latex' will be used as the default command name."
                 );
   cs->setDefaultValue("latex");
@@ -1367,8 +1367,8 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "MAKEINDEX_CMD_NAME",
-                 "The MAKEINDEX_CMD_NAME tag can be used to specify the command name to \n"
-                 "generate index for LaTeX. If left blank `makeindex' will be used as the \n"
+                 "The MAKEINDEX_CMD_NAME tag can be used to specify the command name to\n"
+                 "generate index for LaTeX. If left blank `makeindex' will be used as the\n"
                  "default command name."
                 );
   cs->setDefaultValue("makeindex");
@@ -1377,8 +1377,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "COMPACT_LATEX",
-                 "If the COMPACT_LATEX tag is set to YES Doxygen generates more compact \n"
-                 "LaTeX documents. This may be useful for small projects and may help to \n"
+                 "If the COMPACT_LATEX tag is set to YES Doxygen generates more compact\n"
+                 "LaTeX documents. This may be useful for small projects and may help to\n"
                  "save some trees in general.",
                  FALSE
                 );
@@ -1386,8 +1386,8 @@ void addConfigOptions(Config *cfg)
   //----
   ce = cfg->addEnum(
                  "PAPER_TYPE",
-                 "The PAPER_TYPE tag can be used to set the paper type that is used \n"
-                 "by the printer. Possible values are: a4, a4wide, letter, legal and \n"
+                 "The PAPER_TYPE tag can be used to set the paper type that is used\n"
+                 "by the printer. Possible values are: a4, a4wide, letter, legal and\n"
                  "executive. If left blank a4wide will be used.",
                  "a4wide"
                 );
@@ -1400,16 +1400,16 @@ void addConfigOptions(Config *cfg)
   //----
   cl = cfg->addList(
                  "EXTRA_PACKAGES",
-                 "The EXTRA_PACKAGES tag can be to specify one or more names of LaTeX \n"
+                 "The EXTRA_PACKAGES tag can be to specify one or more names of LaTeX\n"
                  "packages that should be included in the LaTeX output."
                 );
   cl->addDependency("GENERATE_LATEX");
   //----
   cs = cfg->addString(
                  "LATEX_HEADER",
-                 "The LATEX_HEADER tag can be used to specify a personal LaTeX header for \n"
-                 "the generated latex document. The header should contain everything until \n"
-                 "the first chapter. If it is left blank doxygen will generate a \n"
+                 "The LATEX_HEADER tag can be used to specify a personal LaTeX header for\n"
+                 "the generated latex document. The header should contain everything until\n"
+                 "the first chapter. If it is left blank doxygen will generate a\n"
                  "standard header. Notice: only use this tag if you know what you are doing!"
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1417,9 +1417,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "PDF_HYPERLINKS",
-                 "If the PDF_HYPERLINKS tag is set to YES, the LaTeX that is generated \n"
-                 "is prepared for conversion to pdf (using ps2pdf). The pdf file will \n"
-                 "contain links (just like the HTML output) instead of page references \n"
+                 "If the PDF_HYPERLINKS tag is set to YES, the LaTeX that is generated\n"
+                 "is prepared for conversion to pdf (using ps2pdf). The pdf file will\n"
+                 "contain links (just like the HTML output) instead of page references\n"
                  "This makes the output suitable for online browsing using a pdf viewer.",
                  TRUE
                 );
@@ -1427,8 +1427,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "USE_PDFLATEX",
-                 "If the USE_PDFLATEX tag is set to YES, pdflatex will be used instead of \n"
-                 "plain latex in the generated Makefile. Set this option to YES to get a \n"
+                 "If the USE_PDFLATEX tag is set to YES, pdflatex will be used instead of\n"
+                 "plain latex in the generated Makefile. Set this option to YES to get a\n"
                  "higher quality PDF documentation.",
                  TRUE
                 );
@@ -1436,9 +1436,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "LATEX_BATCHMODE",
-                 "If the LATEX_BATCHMODE tag is set to YES, doxygen will add the \\\\batchmode. \n"
-                 "command to the generated LaTeX files. This will instruct LaTeX to keep \n"
-                 "running if errors occur, instead of asking the user for help. \n"
+                 "If the LATEX_BATCHMODE tag is set to YES, doxygen will add the \\\\batchmode.\n"
+                 "command to the generated LaTeX files. This will instruct LaTeX to keep\n"
+                 "running if errors occur, instead of asking the user for help.\n"
                  "This option is also used when generating formulas in HTML.",
                  FALSE
                 );
@@ -1446,8 +1446,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "LATEX_HIDE_INDICES",
-                 "If LATEX_HIDE_INDICES is set to YES then doxygen will not \n"
-                 "include the index chapters (such as File Index, Compound Index, etc.) \n"
+                 "If LATEX_HIDE_INDICES is set to YES then doxygen will not\n"
+                 "include the index chapters (such as File Index, Compound Index, etc.)\n"
                  "in the output.",
                  FALSE
                 );
@@ -1466,16 +1466,16 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_RTF",
-                 "If the GENERATE_RTF tag is set to YES Doxygen will generate RTF output \n"
-                 "The RTF output is optimized for Word 97 and may not look very pretty with \n"
+                 "If the GENERATE_RTF tag is set to YES Doxygen will generate RTF output\n"
+                 "The RTF output is optimized for Word 97 and may not look very pretty with\n"
                  "other RTF readers or editors.",
                  FALSE
                 );
   //----
   cs = cfg->addString(
                  "RTF_OUTPUT",
-                 "The RTF_OUTPUT tag is used to specify where the RTF docs will be put. \n"
-                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be \n"
+                 "The RTF_OUTPUT tag is used to specify where the RTF docs will be put.\n"
+                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be\n"
                  "put in front of it. If left blank `rtf' will be used as the default path."
                 );
   cs->setDefaultValue("rtf");
@@ -1484,8 +1484,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "COMPACT_RTF",
-                 "If the COMPACT_RTF tag is set to YES Doxygen generates more compact \n"
-                 "RTF documents. This may be useful for small projects and may help to \n"
+                 "If the COMPACT_RTF tag is set to YES Doxygen generates more compact\n"
+                 "RTF documents. This may be useful for small projects and may help to\n"
                  "save some trees in general.",
                  FALSE
                 );
@@ -1493,11 +1493,11 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "RTF_HYPERLINKS",
-                 "If the RTF_HYPERLINKS tag is set to YES, the RTF that is generated \n"
-                 "will contain hyperlink fields. The RTF file will \n"
-                 "contain links (just like the HTML output) instead of page references. \n"
-                 "This makes the output suitable for online browsing using WORD or other \n"
-                 "programs which support those fields. \n"
+                 "If the RTF_HYPERLINKS tag is set to YES, the RTF that is generated\n"
+                 "will contain hyperlink fields. The RTF file will\n"
+                 "contain links (just like the HTML output) instead of page references.\n"
+                 "This makes the output suitable for online browsing using WORD or other\n"
+                 "programs which support those fields.\n"
                  "Note: wordpad (write) and others do not support links.",
                  FALSE
                 );
@@ -1505,8 +1505,8 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "RTF_STYLESHEET_FILE",
-                 "Load stylesheet definitions from file. Syntax is similar to doxygen's \n"
-                 "config file, i.e. a series of assignments. You only have to provide \n"
+                 "Load stylesheet definitions from file. Syntax is similar to doxygen's\n"
+                 "config file, i.e. a series of assignments. You only have to provide\n"
                  "replacements, missing definitions are set to their default value."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1514,7 +1514,7 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "RTF_EXTENSIONS_FILE",
-                 "Set optional variables used in the generation of an rtf document. \n"
+                 "Set optional variables used in the generation of an rtf document.\n"
                  "Syntax is similar to doxygen's config file."
                 );
   cs->setWidgetType(ConfigString::File);
@@ -1526,15 +1526,15 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_MAN",
-                 "If the GENERATE_MAN tag is set to YES (the default) Doxygen will \n"
+                 "If the GENERATE_MAN tag is set to YES (the default) Doxygen will\n"
                  "generate man pages",
                  FALSE
                 );
   //----
   cs = cfg->addString(
                  "MAN_OUTPUT",
-                 "The MAN_OUTPUT tag is used to specify where the man pages will be put. \n"
-                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be \n"
+                 "The MAN_OUTPUT tag is used to specify where the man pages will be put.\n"
+                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be\n"
                  "put in front of it. If left blank `man' will be used as the default path."
                 );
   cs->setDefaultValue("man");
@@ -1543,7 +1543,7 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "MAN_EXTENSION",
-                 "The MAN_EXTENSION tag determines the extension that is added to \n"
+                 "The MAN_EXTENSION tag determines the extension that is added to\n"
                  "the generated man pages (default is the subroutine's section .3)"
                 );
   cs->setDefaultValue(".3");
@@ -1551,10 +1551,10 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "MAN_LINKS",
-                 "If the MAN_LINKS tag is set to YES and Doxygen generates man output, \n"
-                 "then it will generate one additional man file for each entity \n"
-                 "documented in the real man page(s). These additional files \n"
-                 "only source the real man page, but without them the man command \n"
+                 "If the MAN_LINKS tag is set to YES and Doxygen generates man output,\n"
+                 "then it will generate one additional man file for each entity\n"
+                 "documented in the real man page(s). These additional files\n"
+                 "only source the real man page, but without them the man command\n"
                  "would be unable to find the correct page. The default is NO.",
                  FALSE
                 );
@@ -1566,16 +1566,16 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_XML",
-                 "If the GENERATE_XML tag is set to YES Doxygen will \n"
-                 "generate an XML file that captures the structure of \n"
+                 "If the GENERATE_XML tag is set to YES Doxygen will\n"
+                 "generate an XML file that captures the structure of\n"
                  "the code including all documentation.",
                  FALSE
                 );
   //----
   cs = cfg->addString(
                  "XML_OUTPUT",
-                 "The XML_OUTPUT tag is used to specify where the XML pages will be put. \n"
-                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be \n"
+                 "The XML_OUTPUT tag is used to specify where the XML pages will be put.\n"
+                 "If a relative path is entered the value of OUTPUT_DIRECTORY will be\n"
                  "put in front of it. If left blank `xml' will be used as the default path."
                 );
   cs->setDefaultValue("xml");
@@ -1584,25 +1584,25 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "XML_SCHEMA",
-                 "The XML_SCHEMA tag can be used to specify an XML schema, \n"
-                 "which can be used by a validating XML parser to check the \n"
+                 "The XML_SCHEMA tag can be used to specify an XML schema,\n"
+                 "which can be used by a validating XML parser to check the\n"
                  "syntax of the XML files."
                 );
   cs->addDependency("GENERATE_XML");
   //----
   cs = cfg->addString(
                  "XML_DTD",
-                 "The XML_DTD tag can be used to specify an XML DTD, \n"
-                 "which can be used by a validating XML parser to check the \n"
+                 "The XML_DTD tag can be used to specify an XML DTD,\n"
+                 "which can be used by a validating XML parser to check the\n"
                  "syntax of the XML files."
                 );
   cs->addDependency("GENERATE_XML");
   //----
   cb = cfg->addBool(
                  "XML_PROGRAMLISTING",
-                 "If the XML_PROGRAMLISTING tag is set to YES Doxygen will \n"
-                 "dump the program listings (including syntax highlighting \n"
-                 "and cross-referencing information) to the XML output. Note that \n"
+                 "If the XML_PROGRAMLISTING tag is set to YES Doxygen will\n"
+                 "dump the program listings (including syntax highlighting\n"
+                 "and cross-referencing information) to the XML output. Note that\n"
                  "enabling this will significantly increase the size of the XML output.",
                  TRUE
                 );
@@ -1614,10 +1614,10 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_AUTOGEN_DEF",
-                 "If the GENERATE_AUTOGEN_DEF tag is set to YES Doxygen will \n"
-                 "generate an AutoGen Definitions (see autogen.sf.net) file \n"
-                 "that captures the structure of the code including all \n"
-                 "documentation. Note that this feature is still experimental \n"
+                 "If the GENERATE_AUTOGEN_DEF tag is set to YES Doxygen will\n"
+                 "generate an AutoGen Definitions (see autogen.sf.net) file\n"
+                 "that captures the structure of the code including all\n"
+                 "documentation. Note that this feature is still experimental\n"
                  "and incomplete at the moment.",
                  FALSE
                 );
@@ -1628,18 +1628,18 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_PERLMOD",
-                 "If the GENERATE_PERLMOD tag is set to YES Doxygen will \n"
-                 "generate a Perl module file that captures the structure of \n"
-                 "the code including all documentation. Note that this \n"
-                 "feature is still experimental and incomplete at the \n"
+                 "If the GENERATE_PERLMOD tag is set to YES Doxygen will\n"
+                 "generate a Perl module file that captures the structure of\n"
+                 "the code including all documentation. Note that this\n"
+                 "feature is still experimental and incomplete at the\n"
                  "moment.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "PERLMOD_LATEX",
-                 "If the PERLMOD_LATEX tag is set to YES Doxygen will generate \n"
-                 "the necessary Makefile rules, Perl scripts and LaTeX code to be able \n"
+                 "If the PERLMOD_LATEX tag is set to YES Doxygen will generate\n"
+                 "the necessary Makefile rules, Perl scripts and LaTeX code to be able\n"
                  "to generate PDF and DVI output from the Perl module output.",
                  FALSE
                 );
@@ -1647,12 +1647,12 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "PERLMOD_PRETTY",
-                 "If the PERLMOD_PRETTY tag is set to YES the Perl module output will be \n"
-                 "nicely formatted so it can be parsed by a human reader. \n"
-                 "This is useful \n"
-                 "if you want to understand what is going on. \n"
-                 "On the other hand, if this \n"
-                 "tag is set to NO the size of the Perl module output will be much smaller \n"
+                 "If the PERLMOD_PRETTY tag is set to YES the Perl module output will be\n"
+                 "nicely formatted so it can be parsed by a human reader.\n"
+                 "This is useful\n"
+                 "if you want to understand what is going on.\n"
+                 "On the other hand, if this\n"
+                 "tag is set to NO the size of the Perl module output will be much smaller\n"
                  "and Perl will parse it just the same.",
                  TRUE
                 );
@@ -1660,30 +1660,30 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "PERLMOD_MAKEVAR_PREFIX",
-                 "The names of the make variables in the generated doxyrules.make file \n"
-                 "are prefixed with the string contained in PERLMOD_MAKEVAR_PREFIX. \n"
-                 "This is useful so different doxyrules.make files included by the same \n"
+                 "The names of the make variables in the generated doxyrules.make file\n"
+                 "are prefixed with the string contained in PERLMOD_MAKEVAR_PREFIX.\n"
+                 "This is useful so different doxyrules.make files included by the same\n"
                  "Makefile don't overwrite each other's variables."
                 );
   cs->addDependency("GENERATE_PERLMOD");
   //---------------------------------------------------------------------------
-  cfg->addInfo("Preprocessor","Configuration options related to the preprocessor   ");
+  cfg->addInfo("Preprocessor","Configuration options related to the preprocessor");
   //---------------------------------------------------------------------------
 
   //----
   cb = cfg->addBool(
                  "ENABLE_PREPROCESSING",
-                 "If the ENABLE_PREPROCESSING tag is set to YES (the default) Doxygen will \n"
-                 "evaluate all C-preprocessor directives found in the sources and include \n"
+                 "If the ENABLE_PREPROCESSING tag is set to YES (the default) Doxygen will\n"
+                 "evaluate all C-preprocessor directives found in the sources and include\n"
                  "files.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "MACRO_EXPANSION",
-                 "If the MACRO_EXPANSION tag is set to YES Doxygen will expand all macro \n"
-                 "names in the source code. If set to NO (the default) only conditional \n"
-                 "compilation will be performed. Macro expansion can be done in a controlled \n"
+                 "If the MACRO_EXPANSION tag is set to YES Doxygen will expand all macro\n"
+                 "names in the source code. If set to NO (the default) only conditional\n"
+                 "compilation will be performed. Macro expansion can be done in a controlled\n"
                  "way by setting EXPAND_ONLY_PREDEF to YES.",
                  FALSE
                 );
@@ -1691,8 +1691,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "EXPAND_ONLY_PREDEF",
-                 "If the EXPAND_ONLY_PREDEF and MACRO_EXPANSION tags are both set to YES \n"
-                 "then the macro expansion is limited to the macros specified with the \n"
+                 "If the EXPAND_ONLY_PREDEF and MACRO_EXPANSION tags are both set to YES\n"
+                 "then the macro expansion is limited to the macros specified with the\n"
                  "PREDEFINED and EXPAND_AS_DEFINED tags.",
                  FALSE
                 );
@@ -1700,7 +1700,7 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "SEARCH_INCLUDES",
-                 "If the SEARCH_INCLUDES tag is set to YES (the default) the includes files \n"
+                 "If the SEARCH_INCLUDES tag is set to YES (the default) the includes files\n"
                  "in the INCLUDE_PATH (see below) will be search if a #include is found.",
                  TRUE
                 );
@@ -1708,8 +1708,8 @@ void addConfigOptions(Config *cfg)
   //----
   cl = cfg->addList(
                  "INCLUDE_PATH",
-                 "The INCLUDE_PATH tag can be used to specify one or more directories that \n"
-                 "contain include files that are not input files but should be processed by \n"
+                 "The INCLUDE_PATH tag can be used to specify one or more directories that\n"
+                 "contain include files that are not input files but should be processed by\n"
                  "the preprocessor."
                 );
   cl->addDependency("ENABLE_PREPROCESSING");
@@ -1717,152 +1717,152 @@ void addConfigOptions(Config *cfg)
   //----
   cl = cfg->addList(
                  "INCLUDE_FILE_PATTERNS",
-                 "You can use the INCLUDE_FILE_PATTERNS tag to specify one or more wildcard \n"
-                 "patterns (like *.h and *.hpp) to filter out the header-files in the \n"
-                 "directories. If left blank, the patterns specified with FILE_PATTERNS will \n"
+                 "You can use the INCLUDE_FILE_PATTERNS tag to specify one or more wildcard\n"
+                 "patterns (like *.h and *.hpp) to filter out the header-files in the\n"
+                 "directories. If left blank, the patterns specified with FILE_PATTERNS will\n"
                  "be used."
                 );
   cl->addDependency("ENABLE_PREPROCESSING");
   //----
   cl = cfg->addList(
                  "PREDEFINED",
-                 "The PREDEFINED tag can be used to specify one or more macro names that \n"
-                 "are defined before the preprocessor is started (similar to the -D option of \n"
-                 "gcc). The argument of the tag is a list of macros of the form: name \n"
-                 "or name=definition (no spaces). If the definition and the = are \n"
-                 "omitted =1 is assumed. To prevent a macro definition from being \n"
-                 "undefined via #undef or recursively expanded use the := operator \n"
+                 "The PREDEFINED tag can be used to specify one or more macro names that\n"
+                 "are defined before the preprocessor is started (similar to the -D option of\n"
+                 "gcc). The argument of the tag is a list of macros of the form: name\n"
+                 "or name=definition (no spaces). If the definition and the = are\n"
+                 "omitted =1 is assumed. To prevent a macro definition from being\n"
+                 "undefined via #undef or recursively expanded use the := operator\n"
                  "instead of the = operator."
                 );
   cl->addDependency("ENABLE_PREPROCESSING");
   //----
   cl = cfg->addList(
                  "EXPAND_AS_DEFINED",
-                 "If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then \n"
-                 "this tag can be used to specify a list of macro names that should be expanded. \n"
-                 "The macro definition that is found in the sources will be used. \n"
+                 "If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then\n"
+                 "this tag can be used to specify a list of macro names that should be expanded.\n"
+                 "The macro definition that is found in the sources will be used.\n"
                  "Use the PREDEFINED tag if you want to use a different macro definition."
                 );
   cl->addDependency("ENABLE_PREPROCESSING");
   //----
   cb = cfg->addBool(
                  "SKIP_FUNCTION_MACROS",
-                 "If the SKIP_FUNCTION_MACROS tag is set to YES (the default) then \n"
-                 "doxygen's preprocessor will remove all function-like macros that are alone \n"
-                 "on a line, have an all uppercase name, and do not end with a semicolon. Such \n"
-                 "function macros are typically used for boiler-plate code, and will confuse \n"
+                 "If the SKIP_FUNCTION_MACROS tag is set to YES (the default) then\n"
+                 "doxygen's preprocessor will remove all function-like macros that are alone\n"
+                 "on a line, have an all uppercase name, and do not end with a semicolon. Such\n"
+                 "function macros are typically used for boiler-plate code, and will confuse\n"
                  "the parser if not removed.",
                  TRUE
                 );
   cb->addDependency("ENABLE_PREPROCESSING");
   //---------------------------------------------------------------------------
-  cfg->addInfo("External","Configuration::additions related to external references   ");
+  cfg->addInfo("External","Configuration::additions related to external references");
   //---------------------------------------------------------------------------
 
   //----
   cl = cfg->addList(
                  "TAGFILES",
-                 "The TAGFILES option can be used to specify one or more tagfiles. \n"
-                 "Optionally an initial location of the external documentation \n"
-                 "can be added for each tagfile. The format of a tag file without \n"
-                 "this location is as follows: \n"
-                 " \n"
-                 "TAGFILES = file1 file2 ... \n"
-                 "Adding location for the tag files is done as follows: \n"
-                 " \n"
-                 "TAGFILES = file1=loc1 \"file2 = loc2\" ... \n"
-                 "where \"loc1\" and \"loc2\" can be relative or absolute paths or \n"
-                 "URLs. If a location is present for each tag, the installdox tool \n"
-                 "does not have to be run to correct the links. \n"
-                 "Note that each tag file must have a unique name \n"
-                 "(where the name does NOT include the path) \n"
-                 "If a tag file is not located in the directory in which doxygen \n"
+                 "The TAGFILES option can be used to specify one or more tagfiles.\n"
+                 "Optionally an initial location of the external documentation\n"
+                 "can be added for each tagfile. The format of a tag file without\n"
+                 "this location is as follows:\n"
+                 "\n"
+                 "TAGFILES = file1 file2 ...\n"
+                 "Adding location for the tag files is done as follows:\n"
+                 "\n"
+                 "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
+                 "where \"loc1\" and \"loc2\" can be relative or absolute paths or\n"
+                 "URLs. If a location is present for each tag, the installdox tool\n"
+                 "does not have to be run to correct the links.\n"
+                 "Note that each tag file must have a unique name\n"
+                 "(where the name does NOT include the path)\n"
+                 "If a tag file is not located in the directory in which doxygen\n"
                  "is run, you must also specify the path to the tagfile here."
                 );
   cl->setWidgetType(ConfigList::File);
   //----
   cs = cfg->addString(
                  "GENERATE_TAGFILE",
-                 "When a file name is specified after GENERATE_TAGFILE, doxygen will create \n"
+                 "When a file name is specified after GENERATE_TAGFILE, doxygen will create\n"
                  "a tag file that is based on the input files it reads."
                 );
   cs->setWidgetType(ConfigString::File);
   //----
   cb = cfg->addBool(
                  "ALLEXTERNALS",
-                 "If the ALLEXTERNALS tag is set to YES all external classes will be listed \n"
-                 "in the class index. If set to NO only the inherited external classes \n"
+                 "If the ALLEXTERNALS tag is set to YES all external classes will be listed\n"
+                 "in the class index. If set to NO only the inherited external classes\n"
                  "will be listed.",
                  FALSE
                 );
   //----
   cb = cfg->addBool(
                  "EXTERNAL_GROUPS",
-                 "If the EXTERNAL_GROUPS tag is set to YES all external groups will be listed \n"
-                 "in the modules index. If set to NO, only the current project's groups will \n"
+                 "If the EXTERNAL_GROUPS tag is set to YES all external groups will be listed\n"
+                 "in the modules index. If set to NO, only the current project's groups will\n"
                  "be listed.",
                  TRUE
                 );
   //----
   cs = cfg->addString(
                  "PERL_PATH",
-                 "The PERL_PATH should be the absolute path and name of the perl script \n"
+                 "The PERL_PATH should be the absolute path and name of the perl script\n"
                  "interpreter (i.e. the result of `which perl')."
                 );
   cs->setDefaultValue("/usr/bin/perl");
   cs->setWidgetType(ConfigString::Dir);
   //---------------------------------------------------------------------------
-  cfg->addInfo("Dot","Configuration options related to the dot tool   ");
+  cfg->addInfo("Dot","Configuration options related to the dot tool");
   //---------------------------------------------------------------------------
 
   //----
   cb = cfg->addBool(
                  "CLASS_DIAGRAMS",
-                 "If the CLASS_DIAGRAMS tag is set to YES (the default) Doxygen will \n"
-                 "generate a inheritance diagram (in HTML, RTF and LaTeX) for classes with base \n"
-                 "or super classes. Setting the tag to NO turns the diagrams off. Note that \n"
-                 "this option is superseded by the HAVE_DOT option below. This is only a \n"
-                 "fallback. It is recommended to install and use dot, since it yields more \n"
+                 "If the CLASS_DIAGRAMS tag is set to YES (the default) Doxygen will\n"
+                 "generate a inheritance diagram (in HTML, RTF and LaTeX) for classes with base\n"
+                 "or super classes. Setting the tag to NO turns the diagrams off. Note that\n"
+                 "this option is superseded by the HAVE_DOT option below. This is only a\n"
+                 "fallback. It is recommended to install and use dot, since it yields more\n"
                  "powerful graphs.",
                  TRUE
                 );
   //----
   cs = cfg->addString(
                  "MSCGEN_PATH",
-                 "You can define message sequence charts within doxygen comments using the \\msc \n"
-                 "command. Doxygen will then run the mscgen tool (see \n"
-                 "http://www.mcternan.me.uk/mscgen/) to produce the chart and insert it in the \n"
-                 "documentation. The MSCGEN_PATH tag allows you to specify the directory where \n"
-                 "the mscgen tool resides. If left empty the tool is assumed to be found in the \n"
+                 "You can define message sequence charts within doxygen comments using the \\msc\n"
+                 "command. Doxygen will then run the mscgen tool (see\n"
+                 "http://www.mcternan.me.uk/mscgen/) to produce the chart and insert it in the\n"
+                 "documentation. The MSCGEN_PATH tag allows you to specify the directory where\n"
+                 "the mscgen tool resides. If left empty the tool is assumed to be found in the\n"
                  "default search path."
                 );
   //----
   cb = cfg->addBool(
                  "HIDE_UNDOC_RELATIONS",
-                 "If set to YES, the inheritance and collaboration graphs will hide \n"
-                 "inheritance and usage relations if the target is undocumented \n"
+                 "If set to YES, the inheritance and collaboration graphs will hide\n"
+                 "inheritance and usage relations if the target is undocumented\n"
                  "or is not a class.",
                  TRUE
                 );
   //----
   cb = cfg->addBool(
                  "HAVE_DOT",
-                 "If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is \n"
-                 "available from the path. This tool is part of Graphviz, a graph visualization \n"
-                 "toolkit from AT&T and Lucent Bell Labs. The other options in this section \n"
+                 "If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is\n"
+                 "available from the path. This tool is part of Graphviz, a graph visualization\n"
+                 "toolkit from AT&T and Lucent Bell Labs. The other options in this section\n"
                  "have no effect if this option is set to NO (the default)",
                  FALSE
                 );
   //----
   cs = cfg->addString(
                  "DOT_FONTNAME",
-                 "By default doxygen will write a font called FreeSans.ttf to the output \n"
-                 "directory and reference it in all dot files that doxygen generates. This \n"
-                 "font does not include all possible unicode characters however, so when you need \n"
-                 "these (or just want a differently looking font) you can specify the font name \n"
-                 "using DOT_FONTNAME. You need need to make sure dot is able to find the font, \n"
-                 "which can be done by putting it in a standard location or by setting the \n"
-                 "DOTFONTPATH environment variable or by setting DOT_FONTPATH to the directory \n"
+                 "By default doxygen will write a font called FreeSans.ttf to the output\n"
+                 "directory and reference it in all dot files that doxygen generates. This\n"
+                 "font does not include all possible unicode characters however, so when you need\n"
+                 "these (or just want a differently looking font) you can specify the font name\n"
+                 "using DOT_FONTNAME. You need need to make sure dot is able to find the font,\n"
+                 "which can be done by putting it in a standard location or by setting the\n"
+                 "DOTFONTPATH environment variable or by setting DOT_FONTPATH to the directory\n"
                  "containing the font."
                 );
   cs->setDefaultValue("FreeSans");
@@ -1870,7 +1870,7 @@ void addConfigOptions(Config *cfg)
   //----
   ci = cfg->addInt(
                  "DOT_FONTSIZE",
-                 "The DOT_FONTSIZE tag can be used to set the size of the font of dot graphs. \n"
+                 "The DOT_FONTSIZE tag can be used to set the size of the font of dot graphs.\n"
                  "The default size is 10pt.",
                  4,24,10
                 );
@@ -1878,18 +1878,18 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "DOT_FONTPATH",
-                 "By default doxygen will tell dot to use the output directory to look for the \n"
-                 "FreeSans.ttf font (which doxygen will put there itself). If you specify a \n"
-                 "different font using DOT_FONTNAME you can set the path where dot \n"
+                 "By default doxygen will tell dot to use the output directory to look for the\n"
+                 "FreeSans.ttf font (which doxygen will put there itself). If you specify a\n"
+                 "different font using DOT_FONTNAME you can set the path where dot\n"
                  "can find it using this tag."
                 );
   cs->addDependency("HAVE_DOT");
   //----
   cb = cfg->addBool(
                  "CLASS_GRAPH",
-                 "If the CLASS_GRAPH and HAVE_DOT tags are set to YES then doxygen \n"
-                 "will generate a graph for each documented class showing the direct and \n"
-                 "indirect inheritance relations. Setting this tag to YES will force the \n"
+                 "If the CLASS_GRAPH and HAVE_DOT tags are set to YES then doxygen\n"
+                 "will generate a graph for each documented class showing the direct and\n"
+                 "indirect inheritance relations. Setting this tag to YES will force the\n"
                  "the CLASS_DIAGRAMS tag to NO.",
                  TRUE
                 );
@@ -1897,9 +1897,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "COLLABORATION_GRAPH",
-                 "If the COLLABORATION_GRAPH and HAVE_DOT tags are set to YES then doxygen \n"
-                 "will generate a graph for each documented class showing the direct and \n"
-                 "indirect implementation dependencies (inheritance, containment, and \n"
+                 "If the COLLABORATION_GRAPH and HAVE_DOT tags are set to YES then doxygen\n"
+                 "will generate a graph for each documented class showing the direct and\n"
+                 "indirect implementation dependencies (inheritance, containment, and\n"
                  "class references variables) of the class with other documented classes.",
                  TRUE
                 );
@@ -1907,7 +1907,7 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GROUP_GRAPHS",
-                 "If the GROUP_GRAPHS and HAVE_DOT tags are set to YES then doxygen \n"
+                 "If the GROUP_GRAPHS and HAVE_DOT tags are set to YES then doxygen\n"
                  "will generate a graph for groups, showing the direct groups dependencies",
                  TRUE
                 );
@@ -1915,8 +1915,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "UML_LOOK",
-                 "If the UML_LOOK tag is set to YES doxygen will generate inheritance and \n"
-                 "collaboration diagrams in a style similar to the OMG's Unified Modeling \n"
+                 "If the UML_LOOK tag is set to YES doxygen will generate inheritance and\n"
+                 "collaboration diagrams in a style similar to the OMG's Unified Modeling\n"
                  "Language.",
                  FALSE
                 );
@@ -1924,7 +1924,7 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "TEMPLATE_RELATIONS",
-                 "If set to YES, the inheritance and collaboration graphs will show the \n"
+                 "If set to YES, the inheritance and collaboration graphs will show the\n"
                  "relations between templates and their instances.",
                  FALSE
                 );
@@ -1932,9 +1932,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "INCLUDE_GRAPH",
-                 "If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDE_GRAPH, and HAVE_DOT \n"
-                 "tags are set to YES then doxygen will generate a graph for each documented \n"
-                 "file showing the direct and indirect include dependencies of the file with \n"
+                 "If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDE_GRAPH, and HAVE_DOT\n"
+                 "tags are set to YES then doxygen will generate a graph for each documented\n"
+                 "file showing the direct and indirect include dependencies of the file with\n"
                  "other documented files.",
                  TRUE
                 );
@@ -1942,9 +1942,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "INCLUDED_BY_GRAPH",
-                 "If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDED_BY_GRAPH, and \n"
-                 "HAVE_DOT tags are set to YES then doxygen will generate a graph for each \n"
-                 "documented header file showing the documented files that directly or \n"
+                 "If the ENABLE_PREPROCESSING, SEARCH_INCLUDES, INCLUDED_BY_GRAPH, and\n"
+                 "HAVE_DOT tags are set to YES then doxygen will generate a graph for each\n"
+                 "documented header file showing the documented files that directly or\n"
                  "indirectly include this file.",
                  TRUE
                 );
@@ -1952,10 +1952,10 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "CALL_GRAPH",
-                 "If the CALL_GRAPH and HAVE_DOT options are set to YES then \n"
-                 "doxygen will generate a call dependency graph for every global function \n"
-                 "or class method. Note that enabling this option will significantly increase \n"
-                 "the time of a run. So in most cases it will be better to enable call graphs \n"
+                 "If the CALL_GRAPH and HAVE_DOT options are set to YES then\n"
+                 "doxygen will generate a call dependency graph for every global function\n"
+                 "or class method. Note that enabling this option will significantly increase\n"
+                 "the time of a run. So in most cases it will be better to enable call graphs\n"
                  "for selected functions only using the \\callgraph command.",
                  FALSE
                 );
@@ -1963,10 +1963,10 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "CALLER_GRAPH",
-                 "If the CALLER_GRAPH and HAVE_DOT tags are set to YES then \n"
-                 "doxygen will generate a caller dependency graph for every global function \n"
-                 "or class method. Note that enabling this option will significantly increase \n"
-                 "the time of a run. So in most cases it will be better to enable caller \n"
+                 "If the CALLER_GRAPH and HAVE_DOT tags are set to YES then\n"
+                 "doxygen will generate a caller dependency graph for every global function\n"
+                 "or class method. Note that enabling this option will significantly increase\n"
+                 "the time of a run. So in most cases it will be better to enable caller\n"
                  "graphs for selected functions only using the \\callergraph command.",
                  FALSE
                 );
@@ -1974,7 +1974,7 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GRAPHICAL_HIERARCHY",
-                 "If the GRAPHICAL_HIERARCHY and HAVE_DOT tags are set to YES then doxygen \n"
+                 "If the GRAPHICAL_HIERARCHY and HAVE_DOT tags are set to YES then doxygen\n"
                  "will graphical hierarchy of all classes instead of a textual one.",
                  TRUE
                 );
@@ -1982,9 +1982,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "DIRECTORY_GRAPH",
-                 "If the DIRECTORY_GRAPH, SHOW_DIRECTORIES and HAVE_DOT tags are set to YES \n"
-                 "then doxygen will show the dependencies a directory has on other directories \n"
-                 "in a graphical way. The dependency relations are determined by the #include \n"
+                 "If the DIRECTORY_GRAPH, SHOW_DIRECTORIES and HAVE_DOT tags are set to YES\n"
+                 "then doxygen will show the dependencies a directory has on other directories\n"
+                 "in a graphical way. The dependency relations are determined by the #include\n"
                  "relations between the files in the directories.",
                  TRUE
                 );
@@ -1992,8 +1992,8 @@ void addConfigOptions(Config *cfg)
   //----
   ce = cfg->addEnum(
                  "DOT_IMAGE_FORMAT",
-                 "The DOT_IMAGE_FORMAT tag can be used to set the image format of the images \n"
-                 "generated by dot. Possible values are png, jpg, or gif \n"
+                 "The DOT_IMAGE_FORMAT tag can be used to set the image format of the images\n"
+                 "generated by dot. Possible values are png, jpg, or gif\n"
                  "If left blank png will be used.",
                  "png"
                 );
@@ -2004,7 +2004,7 @@ void addConfigOptions(Config *cfg)
   //----
   cs = cfg->addString(
                  "DOT_PATH",
-                 "The tag DOT_PATH can be used to specify the path where the dot tool can be \n"
+                 "The tag DOT_PATH can be used to specify the path where the dot tool can be\n"
                  "found. If left blank, it is assumed the dot tool can be found in the path."
                 );
   cs->setWidgetType(ConfigString::Dir);
@@ -2012,8 +2012,8 @@ void addConfigOptions(Config *cfg)
   //----
   cl = cfg->addList(
                  "DOTFILE_DIRS",
-                 "The DOTFILE_DIRS tag can be used to specify one or more directories that \n"
-                 "contain dot files that are included in the documentation (see the \n"
+                 "The DOTFILE_DIRS tag can be used to specify one or more directories that\n"
+                 "contain dot files that are included in the documentation (see the\n"
                  "\\dotfile command)."
                 );
   cl->addDependency("HAVE_DOT");
@@ -2021,12 +2021,12 @@ void addConfigOptions(Config *cfg)
   //----
   ci = cfg->addInt(
                  "DOT_GRAPH_MAX_NODES",
-                 "The DOT_GRAPH_MAX_NODES tag can be used to set the maximum number of \n"
-                 "nodes that will be shown in the graph. If the number of nodes in a graph \n"
-                 "becomes larger than this value, doxygen will truncate the graph, which is \n"
-                 "visualized by representing a node as a red box. Note that doxygen if the \n"
-                 "number of direct children of the root node in a graph is already larger than \n"
-                 "DOT_GRAPH_MAX_NODES then the graph will not be shown at all. Also note \n"
+                 "The DOT_GRAPH_MAX_NODES tag can be used to set the maximum number of\n"
+                 "nodes that will be shown in the graph. If the number of nodes in a graph\n"
+                 "becomes larger than this value, doxygen will truncate the graph, which is\n"
+                 "visualized by representing a node as a red box. Note that doxygen if the\n"
+                 "number of direct children of the root node in a graph is already larger than\n"
+                 "DOT_GRAPH_MAX_NODES then the graph will not be shown at all. Also note\n"
                  "that the size of a graph can be further restricted by MAX_DOT_GRAPH_DEPTH.",
                  0,10000,50
                 );
@@ -2034,12 +2034,12 @@ void addConfigOptions(Config *cfg)
   //----
   ci = cfg->addInt(
                  "MAX_DOT_GRAPH_DEPTH",
-                 "The MAX_DOT_GRAPH_DEPTH tag can be used to set the maximum depth of the \n"
-                 "graphs generated by dot. A depth value of 3 means that only nodes reachable \n"
-                 "from the root by following a path via at most 3 edges will be shown. Nodes \n"
-                 "that lay further from the root node will be omitted. Note that setting this \n"
-                 "option to 1 or 2 may greatly reduce the computation time needed for large \n"
-                 "code bases. Also note that the size of a graph can be further restricted by \n"
+                 "The MAX_DOT_GRAPH_DEPTH tag can be used to set the maximum depth of the\n"
+                 "graphs generated by dot. A depth value of 3 means that only nodes reachable\n"
+                 "from the root by following a path via at most 3 edges will be shown. Nodes\n"
+                 "that lay further from the root node will be omitted. Note that setting this\n"
+                 "option to 1 or 2 may greatly reduce the computation time needed for large\n"
+                 "code bases. Also note that the size of a graph can be further restricted by\n"
                  "DOT_GRAPH_MAX_NODES. Using a depth of 0 means no depth restriction.",
                  0,1000,0
                 );
@@ -2047,10 +2047,10 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "DOT_TRANSPARENT",
-                 "Set the DOT_TRANSPARENT tag to YES to generate images with a transparent \n"
-                 "background. This is disabled by default, because dot on Windows does not \n"
-                 "seem to support this out of the box. Warning: Depending on the platform used, \n"
-                 "enabling this option may lead to badly anti-aliased labels on the edges of \n"
+                 "Set the DOT_TRANSPARENT tag to YES to generate images with a transparent\n"
+                 "background. This is disabled by default, because dot on Windows does not\n"
+                 "seem to support this out of the box. Warning: Depending on the platform used,\n"
+                 "enabling this option may lead to badly anti-aliased labels on the edges of\n"
                  "a graph (i.e. they become hard to read).",
                  FALSE
                 );
@@ -2058,9 +2058,9 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "DOT_MULTI_TARGETS",
-                 "Set the DOT_MULTI_TARGETS tag to YES allow dot to generate multiple output \n"
-                 "files in one run (i.e. multiple -o and -T options on the command line). This \n"
-                 "makes dot run faster, but since only newer versions of dot (>1.8.10) \n"
+                 "Set the DOT_MULTI_TARGETS tag to YES allow dot to generate multiple output\n"
+                 "files in one run (i.e. multiple -o and -T options on the command line). This\n"
+                 "makes dot run faster, but since only newer versions of dot (>1.8.10)\n"
                  "support this, this feature is disabled by default.",
                  FALSE
                 );
@@ -2068,8 +2068,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "GENERATE_LEGEND",
-                 "If the GENERATE_LEGEND tag is set to YES (the default) Doxygen will \n"
-                 "generate a legend page explaining the meaning of the various boxes and \n"
+                 "If the GENERATE_LEGEND tag is set to YES (the default) Doxygen will\n"
+                 "generate a legend page explaining the meaning of the various boxes and\n"
                  "arrows in the dot generated graphs.",
                  TRUE
                 );
@@ -2077,8 +2077,8 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "DOT_CLEANUP",
-                 "If the DOT_CLEANUP tag is set to YES (the default) Doxygen will \n"
-                 "remove the intermediate dot files that are used to generate \n"
+                 "If the DOT_CLEANUP tag is set to YES (the default) Doxygen will\n"
+                 "remove the intermediate dot files that are used to generate\n"
                  "the various graphs.",
                  TRUE
                 );
@@ -2090,7 +2090,7 @@ void addConfigOptions(Config *cfg)
   //----
   cb = cfg->addBool(
                  "SEARCHENGINE",
-                 "The SEARCHENGINE tag specifies whether or not a search engine should be \n"
+                 "The SEARCHENGINE tag specifies whether or not a search engine should be\n"
                  "used. If set to NO the values of all tags below this one will be ignored.",
                  FALSE
                 );
